USE teachcloud_db;

-- ----------------------------
-- Table structure for basic_attachment
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_attachment` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `name` varchar(100) NOT NULL COMMENT '文件名',
  `type` varchar(10) NOT NULL COMMENT '文件类型',
  `size` int NOT NULL COMMENT '单位（KB）',
  `md5` varchar(32) NOT NULL COMMENT '文件md5值',
  `path` varchar(2000) NOT NULL COMMENT '存储路径',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `obj_id` bigint DEFAULT NULL COMMENT '关联业务id',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='所有附件记录表';

-- ----------------------------
-- Table structure for basic_campus
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_campus` (
  `id` bigint NOT NULL COMMENT '校区id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `campus_name` varchar(64) DEFAULT NULL COMMENT '校区名称',
  `campus_code` varchar(64) DEFAULT NULL COMMENT '校区编码',
  `print_house_id` bigint DEFAULT NULL COMMENT '印刷室id',
  `enable` tinyint DEFAULT '1' COMMENT '是否可用',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `campus_schoolId_code_idx` (`school_id`,`campus_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础校区表';


-- ----------------------------
-- Table structure for basic_card_rule
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_card_rule` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `name` varchar(100) NOT NULL COMMENT '题卡规则名称',
  `exam_number_style` varchar(5) NOT NULL COMMENT 'PRINT-印刷条码，PASTE-粘贴条码，FILL-卡号填涂',
  `exam_number_digit` int DEFAULT NULL COMMENT '考号位数',
  `paper_type` varchar(5) NOT NULL COMMENT 'PRINT-印刷条码，FILL-卡号填涂',
  `exam_absent` tinyint NOT NULL COMMENT '0-禁用，1-启用',
  `write_sign` tinyint NOT NULL COMMENT '0-禁用，1-启用',
  `discipline` tinyint(1) DEFAULT NULL COMMENT '违纪填涂（1：是，0：否）',
  `undertaking_enable` tinyint(1) DEFAULT NULL COMMENT '启用考生承诺书',
  `undertaking_body` varchar(300) DEFAULT NULL COMMENT '考生承诺书内容',
  `required_fields` text NOT NULL COMMENT '必选字段',
  `extend_fields` text NOT NULL COMMENT '扩展字段',
  `fill_fields` varchar(500) DEFAULT NULL COMMENT '变量信息填充字段',
  `title_rule` varchar(200) NOT NULL COMMENT '题卡标题规则',
  `attention` text NOT NULL COMMENT '注意事项',
  `objective_attention` text COMMENT '客观题注意事项',
  `subjective_attention` text COMMENT '主观题注意事项',
  `enable` tinyint NOT NULL COMMENT '0-禁用，1-启用',
  `remark` varchar(200) DEFAULT NULL COMMENT '备注',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `fill_number` tinyint DEFAULT NULL COMMENT '卡号填涂位数',
  `first_level_subheading` varchar(200) DEFAULT NULL COMMENT '一级副标题',
  `second_level_subheading` varchar(200) DEFAULT NULL COMMENT '二级副标题',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡规则';


-- ----------------------------
-- Table structure for basic_clazz
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_clazz` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `major_id` bigint NOT NULL COMMENT '专业id',
  `clazz_code` varchar(50) DEFAULT NULL COMMENT '班级编号',
  `short_code` varchar(10) DEFAULT NULL COMMENT '简码',
  `clazz_name` varchar(50) DEFAULT NULL COMMENT '班级名称',
  `enable` tinyint(1) DEFAULT NULL COMMENT '是否可用',
  `org_id` bigint DEFAULT NULL COMMENT '权限机构id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `clazz_schoolId_name_idx` (`school_id`,`major_id`,`clazz_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础班级表';

-- ----------------------------
-- Table structure for basic_college
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_college` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL,
  `college_name` varchar(50) NOT NULL COMMENT '学院名称',
  `org_id` bigint NOT NULL COMMENT '数据权限机构id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `college_schoolId_name_idx` (`school_id`,`college_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学生学院表';

-- ----------------------------
-- Table structure for basic_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_course` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `code` varchar(100) NOT NULL COMMENT '课程编码',
  `short_code` varchar(10) DEFAULT NULL COMMENT '简码',
  `name` varchar(50) NOT NULL COMMENT '课程名称',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '修改人',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `teaching_room_id` bigint DEFAULT NULL COMMENT '教研室id',
  `enable` tinyint DEFAULT NULL,
  `historic_name` varchar(100) DEFAULT NULL COMMENT '历史课程名称',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `course_schoolId_code_idx` (`school_id`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程表';

-- ----------------------------
-- Table structure for basic_exam
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_exam` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL,
  `org_id` bigint NOT NULL,
  `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
  `short_code` varchar(10) DEFAULT NULL COMMENT '简码',
  `name` varchar(100) DEFAULT NULL COMMENT '考试名称',
  `category` varchar(45) DEFAULT NULL COMMENT '考试类型（ONLINE：线上，OFFLINE：线下）',
  `exam_model` varchar(45) DEFAULT NULL COMMENT '业务模式（MODEL1：电子交卷环节需要提交考务数据，MODEL2：电子交卷环节不需要提交考务数据，只输入印刷份数即可，MODEL3：电子交卷环节不需要提交考务数据）',
  `review` tinyint DEFAULT NULL COMMENT '是否启用入库审核：0-禁用，1-启用',
  `print_method` varchar(6) DEFAULT NULL COMMENT 'AUTO-自动，MANUAL-手动',
  `enable` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1启用/0禁用',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考试表';

-- ----------------------------
-- Table structure for basic_exam_rule
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_exam_rule` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `required_fields` text COMMENT '必选字段',
  `extend_fields` text NOT NULL COMMENT '扩展字段',
  `exam_number_digit` int DEFAULT NULL COMMENT '考号位数',
  `sign_scope` text COMMENT '签到表字段可选范围',
  `package_scope` text COMMENT '卷袋贴字段可选范围',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务规则';

-- ----------------------------
-- Table structure for basic_exam_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_exam_student` (
  `id` bigint NOT NULL COMMENT 'id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `semester_id` bigint NOT NULL COMMENT '学期id',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `course_code` varchar(20) NOT NULL COMMENT '课程编号',
  `clazz_id` bigint NOT NULL COMMENT '教学班id（basic_teach_clazz）',
  `paper_number` varchar(30) DEFAULT NULL COMMENT '试卷编号',
  `student_name` varchar(50) NOT NULL COMMENT '姓名',
  `student_code` varchar(50) NOT NULL COMMENT '学号',
  `college` varchar(50) DEFAULT NULL COMMENT '学院',
  `major` varchar(50) DEFAULT NULL COMMENT '专业',
  `teacher_id` bigint DEFAULT NULL COMMENT '任课教师id',
  `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始时间',
  `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束时间',
  `exam_place` varchar(50) DEFAULT NULL COMMENT '考点',
  `exam_room` varchar(50) DEFAULT NULL COMMENT '考场',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `basic_exam_student_unique` (`school_id`,`exam_id`,`course_code`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考生字典表';

-- ----------------------------
-- Table structure for basic_major
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_major` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `belong_org_id` bigint NOT NULL COMMENT '所属机构id',
  `name` varchar(100) NOT NULL COMMENT '专业名称',
  `code` varchar(100) DEFAULT NULL COMMENT '专业编码',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `major_schoolId_name_idx` (`school_id`,`name`,`belong_org_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='专业字典表';

-- ----------------------------
-- Table structure for basic_message
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_message` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `user_id` bigint NOT NULL COMMENT '消息接收人用户',
  `user_name` varchar(100) DEFAULT NULL COMMENT '用户名称',
  `mobile_number` varchar(11) DEFAULT NULL COMMENT '电话号码',
  `paper_number` varchar(50) DEFAULT NULL COMMENT '试卷编号',
  `course_code` varchar(50) DEFAULT NULL COMMENT '课程代码',
  `message_type` varchar(45) DEFAULT NULL COMMENT '消息类型',
  `business_operate` varchar(45) NOT NULL COMMENT '业务操作',
  `business_id` bigint DEFAULT NULL COMMENT '业务id',
  `template_code` varchar(45) NOT NULL COMMENT '消息模板代码',
  `variable_params` text COMMENT '变量参数内容',
  `template_content` mediumtext COMMENT '模板内容',
  `send_status` varchar(45) DEFAULT NULL COMMENT '消息发送状态',
  `send_result` varchar(200) DEFAULT NULL COMMENT '消息发送结果',
  `remark` text COMMENT '备注',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `resend_count` int DEFAULT NULL COMMENT '重试次数',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for basic_operation_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_operation_log` (
  `id` bigint NOT NULL COMMENT 'id',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `user_id` bigint NOT NULL COMMENT '用户对象id',
  `ip` varchar(32) NOT NULL COMMENT 'ip地址',
  `privilege_id` bigint DEFAULT NULL COMMENT '权限菜单id',
  `operation_type` varchar(32) NOT NULL COMMENT '自定义记录日志操作类型（LOGIN("用户登录"),LOGOUT("用户登出"),ADD("新增"),DELETE("删除"),UPDATE("修改"),IMPORT("导入"),EXPORT("导出"),UN_KNOW("未知")）',
  `detail` mediumtext COMMENT '日志详情',
  `function_name` varchar(100) DEFAULT NULL COMMENT '功能名称',
  `url` varchar(64) DEFAULT NULL COMMENT '请求地址url',
  `args` mediumtext COMMENT '参数',
  `run_status` varchar(32) DEFAULT NULL COMMENT '方法运行状态',
  `create_time` bigint DEFAULT NULL COMMENT '日志记录时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `operation_log_idx` (`school_id`,`user_id`,`privilege_id`,`operation_type`,`create_time`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础日志记录表';

-- ----------------------------
-- Table structure for basic_print_config
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_print_config` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校ID',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `exam_id` bigint DEFAULT NULL COMMENT '考试ID',
  `enable` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1启用/0禁用',
  `card_rule_id` bigint DEFAULT NULL COMMENT '题卡规则（-1代表通卡）',
  `print_content` varchar(255) DEFAULT NULL COMMENT '试卷、题卡',
  `backup_method` varchar(10) DEFAULT NULL COMMENT '试卷题卡备份方式（ROOM按考场）',
  `backup_count` double DEFAULT NULL COMMENT '试卷、题卡备份数量（0-1为按比例，大于等于1为按数量）',
  `draw_rule` varchar(10) DEFAULT NULL COMMENT '抽卷规则（ONE只抽一次，CIRCLE循环抽取）',
  `variable_content` mediumtext COMMENT '变量印品参数json',
  `ordinary_content` mediumtext COMMENT '普通印品参数json',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  `review` tinyint DEFAULT NULL COMMENT '是否启用入库审核：0-禁用，1-启用',
  `audit_content` varchar(45) DEFAULT NULL COMMENT '[PAPER,CARD]',
  `print_method` varchar(6) DEFAULT NULL COMMENT 'AUTO-自动，MANUAL-手动',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='印品配置表';

-- ----------------------------
-- Table structure for basic_professional
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_professional` (
  `id` bigint NOT NULL,
  `school_id` bigint DEFAULT NULL COMMENT '学校ID',
  `name` varchar(80) DEFAULT NULL COMMENT '专业名称',
  `org_id` bigint DEFAULT NULL COMMENT '所属学院ID',
  `create_id` bigint DEFAULT NULL COMMENT '创建人ID',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人ID',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='专业表';

-- ----------------------------
-- Table structure for basic_role_data_permission
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_role_data_permission` (
  `id` bigint NOT NULL COMMENT 'id',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `role_id` bigint NOT NULL COMMENT '角色id',
  `privilege_id` bigint NOT NULL COMMENT '权限id',
  `data_permission_type` varchar(45) NOT NULL COMMENT '数据权限类型',
  `org_scope` varchar(45) DEFAULT NULL COMMENT '数据权限机构权限组',
  `org_id` bigint DEFAULT NULL COMMENT '创建人机构id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `role_data_permission_idx` (`role_id`,`privilege_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色数据权限表';

-- ----------------------------
-- Records of basic_role_data_permission
-- ----------------------------
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (502406320033370112, NULL, 6, 970, 'SELF_ORG_BELOW', NULL, NULL, 1, 1710723800954, NULL, 1710723800954);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (511229095439241216, NULL, 7, 491, 'SELF', NULL, NULL, 1, 1712827314530, NULL, 1712827314530);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425280, NULL, 9, 2036, 'SELF_ORG_BELOW', NULL, NULL, 1, 1718590118570, NULL, 1718590118570);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425281, NULL, 9, 3000, 'SELF', NULL, NULL, 1, 1718590118572, NULL, 1718590118572);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425282, NULL, 9, 3001, 'SELF', NULL, NULL, 1, 1718590118572, NULL, 1718590118572);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425283, NULL, 9, 2070, 'SELF', NULL, NULL, 1, 1718590118572, NULL, 1718590118572);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425284, NULL, 9, 2002, 'SELF', NULL, NULL, 1, 1718590118573, NULL, 1718590118573);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425285, NULL, 9, 2080, 'SELF', NULL, NULL, 1, 1718590118573, NULL, 1718590118573);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400047475425286, NULL, 9, 2001, 'SELF', NULL, NULL, 1, 1718590118574, NULL, 1718590118574);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109696, NULL, 12, 2036, 'SELF', NULL, NULL, 1, 1718590144751, NULL, 1718590144751);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109697, NULL, 12, 3000, 'SELF', NULL, NULL, 1, 1718590144753, NULL, 1718590144753);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109698, NULL, 12, 3001, 'SELF', NULL, NULL, 1, 1718590144754, NULL, 1718590144754);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109699, NULL, 12, 2070, 'SELF', NULL, NULL, 1, 1718590144754, NULL, 1718590144754);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109700, NULL, 12, 2002, 'SELF', NULL, NULL, 1, 1718590144755, NULL, 1718590144755);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109701, NULL, 12, 2080, 'SELF', NULL, NULL, 1, 1718590144755, NULL, 1718590144755);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (535400157278109702, NULL, 12, 2001, 'SELF', NULL, NULL, 1, 1718590144756, NULL, 1718590144756);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385472, NULL, 3, 576, 'SELF', NULL, NULL, 1, 1718948497020, NULL, 1718948497020);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385473, NULL, 3, 491, 'SELF', NULL, NULL, 1, 1718948497023, NULL, 1718948497023);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385474, NULL, 3, 897, 'SELF', NULL, NULL, 1, 1718948497023, NULL, 1718948497023);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385475, NULL, 3, 917, 'SELF', NULL, NULL, 1, 1718948497024, NULL, 1718948497024);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385476, NULL, 3, 946, 'SELF', NULL, NULL, 1, 1718948497024, NULL, 1718948497024);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385477, NULL, 3, 487, 'SELF', NULL, NULL, 1, 1718948497024, NULL, 1718948497024);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385478, NULL, 3, 577, 'SELF', NULL, NULL, 1, 1718948497025, NULL, 1718948497025);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903195633385479, NULL, 3, 970, 'SELF', NULL, NULL, 1, 1718948497025, NULL, 1718948497025);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903260217278464, NULL, 4, 576, 'SELF_ORG_BELOW', NULL, NULL, 1, 1718948512416, NULL, 1718948512416);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903260217278465, NULL, 4, 39, 'SELF_ORG_BELOW', NULL, NULL, 1, 1718948512418, NULL, 1718948512418);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903260217278466, NULL, 4, 42, 'SELF_ORG_BELOW', NULL, NULL, 1, 1718948512418, NULL, 1718948512418);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081664, NULL, 2, 4, 'ALL', NULL, NULL, 1, 1718948571967, NULL, 1718948571967);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081665, NULL, 2, 5, 'ALL', NULL, NULL, 1, 1718948571969, NULL, 1718948571969);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081666, NULL, 2, 6, 'ALL', NULL, NULL, 1, 1718948571970, NULL, 1718948571970);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081667, NULL, 2, 8, 'ALL', NULL, NULL, 1, 1718948571970, NULL, 1718948571970);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081668, NULL, 2, 9, 'ALL', NULL, NULL, 1, 1718948571970, NULL, 1718948571970);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081669, NULL, 2, 624, 'ALL', NULL, NULL, 1, 1718948571971, NULL, 1718948571971);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081670, NULL, 2, 11, 'ALL', NULL, NULL, 1, 1718948571971, NULL, 1718948571971);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081671, NULL, 2, 402, 'ALL', NULL, NULL, 1, 1718948571972, NULL, 1718948571972);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081672, NULL, 2, 403, 'ALL', NULL, NULL, 1, 1718948571972, NULL, 1718948571972);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081673, NULL, 2, 510, 'ALL', NULL, NULL, 1, 1718948571973, NULL, 1718948571973);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081674, NULL, 2, 609, 'ALL', NULL, NULL, 1, 1718948571973, NULL, 1718948571973);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081675, NULL, 2, 515, 'ALL', NULL, NULL, 1, 1718948571973, NULL, 1718948571973);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081676, NULL, 2, 13, 'ALL', NULL, NULL, 1, 1718948571974, NULL, 1718948571974);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081677, NULL, 2, 1100, 'ALL', NULL, NULL, 1, 1718948571974, NULL, 1718948571974);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081678, NULL, 2, 113, 'ALL', NULL, NULL, 1, 1718948571975, NULL, 1718948571975);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081679, NULL, 2, 115, 'ALL', NULL, NULL, 1, 1718948571975, NULL, 1718948571975);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081680, NULL, 2, 521, 'ALL', NULL, NULL, 1, 1718948571975, NULL, 1718948571975);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081681, NULL, 2, 549, 'ALL', NULL, NULL, 1, 1718948571976, NULL, 1718948571976);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081682, NULL, 2, 653, 'ALL', NULL, NULL, 1, 1718948571976, NULL, 1718948571976);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081683, NULL, 2, 782, 'ALL', NULL, NULL, 1, 1718948571977, NULL, 1718948571977);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081684, NULL, 2, 576, 'ALL', NULL, NULL, 1, 1718948571977, NULL, 1718948571977);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081685, NULL, 2, 39, 'ALL', NULL, NULL, 1, 1718948571978, NULL, 1718948571978);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081686, NULL, 2, 42, 'ALL', NULL, NULL, 1, 1718948571978, NULL, 1718948571978);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081687, NULL, 2, 43, 'ALL', NULL, NULL, 1, 1718948571978, NULL, 1718948571978);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081688, NULL, 2, 44, 'ALL', NULL, NULL, 1, 1718948571979, NULL, 1718948571979);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081689, NULL, 2, 45, 'ALL', NULL, NULL, 1, 1718948571981, NULL, 1718948571981);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081690, NULL, 2, 47, 'ALL', NULL, NULL, 1, 1718948571982, NULL, 1718948571982);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081691, NULL, 2, 491, 'ALL', NULL, NULL, 1, 1718948571983, NULL, 1718948571983);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081692, NULL, 2, 897, 'ALL', NULL, NULL, 1, 1718948571983, NULL, 1718948571983);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081693, NULL, 2, 917, 'ALL', NULL, NULL, 1, 1718948571983, NULL, 1718948571983);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081694, NULL, 2, 946, 'ALL', NULL, NULL, 1, 1718948571984, NULL, 1718948571984);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081695, NULL, 2, 487, 'ALL', NULL, NULL, 1, 1718948571984, NULL, 1718948571984);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081696, NULL, 2, 577, 'ALL', NULL, NULL, 1, 1718948571984, NULL, 1718948571984);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081697, NULL, 2, 708, 'ALL', NULL, NULL, 1, 1718948571985, NULL, 1718948571985);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081698, NULL, 2, 681, 'ALL', NULL, NULL, 1, 1718948571985, NULL, 1718948571985);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081699, NULL, 2, 970, 'ALL', NULL, NULL, 1, 1718948571985, NULL, 1718948571985);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081700, NULL, 2, 2036, 'ALL', NULL, NULL, 1, 1718948571986, NULL, 1718948571986);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081701, NULL, 2, 3000, 'ALL', NULL, NULL, 1, 1718948571986, NULL, 1718948571986);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081702, NULL, 2, 3001, 'ALL', NULL, NULL, 1, 1718948571986, NULL, 1718948571986);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081703, NULL, 2, 2070, 'ALL', NULL, NULL, 1, 1718948571987, NULL, 1718948571987);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081704, NULL, 2, 2002, 'ALL', NULL, NULL, 1, 1718948571987, NULL, 1718948571987);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081705, NULL, 2, 2080, 'ALL', NULL, NULL, 1, 1718948571987, NULL, 1718948571987);
INSERT INTO `basic_role_data_permission` (`id`, `school_id`, `role_id`, `privilege_id`, `data_permission_type`, `org_scope`, `org_id`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (536903509988081706, NULL, 2, 2001, 'ALL', NULL, NULL, 1, 1718948571988, NULL, 1718948571988);

-- ----------------------------
-- Table structure for basic_school
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_school` (
  `id` bigint NOT NULL COMMENT '主键',
  `code` varchar(20) NOT NULL COMMENT '学校编码',
  `domain_name` varchar(20) DEFAULT NULL COMMENT '域名',
  `name` varchar(100) DEFAULT NULL COMMENT '学校名称',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
  `access_key` varchar(50) DEFAULT NULL COMMENT '访问key',
  `access_secret` varchar(50) DEFAULT NULL COMMENT '访问秘钥',
  `remark` text COMMENT '备注',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `logo` mediumtext COMMENT '学校logo',
  `init_password` varchar(100) DEFAULT NULL COMMENT '该学校用户的初始密码，默认为12345678',
  `default_school` tinyint(1) DEFAULT '0',
  `has_paper_number` tinyint(1) DEFAULT '0' COMMENT '该学校是否有固定试卷编号',
  `background_image` varchar(500) DEFAULT NULL COMMENT '学校首页背景图',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `code` (`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校表';

-- ----------------------------
-- Table structure for basic_semester
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_semester` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `name` varchar(100) NOT NULL COMMENT '学期名称',
  `code` varchar(100) DEFAULT NULL COMMENT '学期编码',
  `start_time` bigint DEFAULT NULL COMMENT '开始日期',
  `end_time` bigint DEFAULT NULL COMMENT '结束日期',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `semester_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学期字典表';

-- ----------------------------
-- Table structure for basic_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_student` (
  `id` bigint NOT NULL COMMENT '学生id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `student_name` varchar(100) NOT NULL COMMENT '学生姓名',
  `student_code` varchar(100) NOT NULL COMMENT '学生编号',
  `phone_number` varchar(11) DEFAULT NULL COMMENT '电话号码',
  `belong_org_id` bigint DEFAULT NULL COMMENT '所属院系',
  `major_id` bigint DEFAULT NULL COMMENT '专业id',
  `clazz_id` bigint DEFAULT NULL COMMENT '班级主键',
  `enable` tinyint DEFAULT '1' COMMENT '可用状态（1：可用，0：不可用）',
  `org_id` bigint DEFAULT NULL COMMENT '可操作人机构id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `student_schoolId_code_orgId_idx` (`school_id`,`student_code`,`belong_org_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校id';

-- ----------------------------
-- Table structure for basic_teach_clazz
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_teach_clazz` (
  `id` bigint NOT NULL COMMENT 'id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `course_code` varchar(20) NOT NULL COMMENT '课程编号',
  `clazz_name` varchar(50) NOT NULL COMMENT '教学班名称',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `basic_teach_clazz_unique` (`school_id`,`exam_id`,`clazz_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础教学班表';

-- ----------------------------
-- Table structure for basic_teach_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_teach_course` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `user_id` bigint DEFAULT NULL COMMENT '用户ID',
  `course_id` bigint DEFAULT NULL COMMENT '课程ID',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用？1-是 ；0-否',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='老师和课程关联表';

-- ----------------------------
-- Table structure for basic_template
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_template` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `name` varchar(30) NOT NULL COMMENT '模板名称',
  `classify` varchar(10) DEFAULT NULL COMMENT 'template_type值为VARIABLE、ORDINARY时，不为空。\n  SIGN-签到表，PACKAGE-卷袋贴，CHECK_IN-登记表',
  `display_range` mediumtext COMMENT '卷袋贴、签到表数据范围',
  `preview_path` varchar(500) DEFAULT NULL COMMENT '预览地址',
  `attachment_id` bigint DEFAULT NULL COMMENT '模板附件ID（保存到附件表ID）',
  `enable` tinyint NOT NULL COMMENT '0-禁用，1-启用',
  `diallel` tinyint(1) DEFAULT '1' COMMENT '考生信息是否双列显示',
  `text_desc` varchar(500) DEFAULT NULL COMMENT '文字说明',
  `remark` varchar(200) DEFAULT NULL COMMENT '备注',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `add_blank_page` tinyint(1) DEFAULT '1' COMMENT '是否增加空白页',
  `line_height_times` double DEFAULT '1' COMMENT '行间距在初始值扩大倍数（默认1）',
  `font_size` varchar(10) DEFAULT NULL COMMENT '字体大小（small,medium,large）',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='通用模板';

-- ----------------------------
-- Table structure for basic_template_org
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_template_org` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `type` varchar(20) NOT NULL COMMENT '模板类型：GENERIC-通卡模板，VARIABLE-变量印品模板，ORDINARY-普通印品模板，CARD_RULE-题卡规则，PRINT_CONFIG-印品配置',
  `rule_id` bigint NOT NULL COMMENT '通卡模板ID',
  `org_id` bigint NOT NULL COMMENT '组织机构ID',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='适用学院（题卡规则、模板适用学院）';

-- ----------------------------
-- Table structure for basic_user_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_user_course` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `user_id` bigint DEFAULT NULL COMMENT '用户ID',
  `course_id` bigint DEFAULT NULL COMMENT '课程ID',
  `clazz_id` bigint DEFAULT NULL COMMENT '授课班级',
  `enable` tinyint(1) DEFAULT NULL COMMENT '是否启用？1-是 ；0-否',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户和课程关联表';

-- ----------------------------
-- Table structure for basic_verify_code
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_verify_code` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `user_id` bigint NOT NULL COMMENT '用户ID',
  `mobile_number` varchar(11) NOT NULL COMMENT '手机号',
  `expire_time` bigint NOT NULL COMMENT '到期时间',
  `valid_period` int NOT NULL COMMENT '单位（分）',
  `verify_code` varchar(4) NOT NULL COMMENT '4位数字',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='短信验证码记录表';

-- ----------------------------
-- Table structure for client_print_data
-- ----------------------------
CREATE TABLE IF NOT EXISTS `client_print_data` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `exam_detail_id` bigint DEFAULT NULL COMMENT '考场ID',
  `machine_code` varchar(45) DEFAULT NULL COMMENT '机器唯一码',
  `pages_a4` int DEFAULT NULL COMMENT 'A4页数量',
  `paper_pages` int DEFAULT NULL COMMENT '试卷数量',
  `card_pages` int DEFAULT NULL COMMENT '题卡数量',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='各机器打印数量';

-- ----------------------------
-- Table structure for client_status
-- ----------------------------
CREATE TABLE IF NOT EXISTS `client_status` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `machine_code` varchar(100) NOT NULL COMMENT '机器唯一码',
  `exam_detail_id` bigint DEFAULT NULL COMMENT '考场ID',
  `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划ID',
  `course_code` varchar(100) NOT NULL COMMENT '课程代码',
  `course_name` varchar(200) NOT NULL COMMENT '课程名称',
  `paper_number` varchar(50) NOT NULL COMMENT '试卷编号',
  `is_try` tinyint DEFAULT NULL COMMENT '是否打样：true-是，false-否',
  `try_time` bigint DEFAULT NULL COMMENT '打样时间',
  `is_pass` tinyint DEFAULT NULL COMMENT '是否合格：true-合格，false-不合格',
  `is_download` tinyint DEFAULT NULL COMMENT '是否缓存：true-是，false-否',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_1` (`school_id`,`exam_detail_id`,`course_code`,`paper_number`,`machine_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='机器打样记录';

-- ----------------------------
-- Table structure for client_upgrade
-- ----------------------------
CREATE TABLE IF NOT EXISTS `client_upgrade` (
  `platform` varchar(20) NOT NULL COMMENT '系统',
  `install_path` varchar(200) DEFAULT NULL COMMENT '安装包保存地址',
  `version` varchar(20) DEFAULT NULL COMMENT '版本名称',
  `build` varchar(45) DEFAULT NULL COMMENT '版本号，用于客户端比对版本高低',
  `support_min` varchar(45) DEFAULT NULL COMMENT '增量升级最低版本号，低于（含）此版本需要下载安装包重新安装',
  `upgrade_path` varchar(200) DEFAULT NULL COMMENT '升级包保存地址',
  `mainfest_path` varchar(200) DEFAULT NULL COMMENT 'mainfest.json文件保存路径',
  `install_upload_time` bigint DEFAULT NULL COMMENT '安装包更新时间',
  `upgrade_upload_time` bigint DEFAULT NULL COMMENT '升级包更新时间',
  PRIMARY KEY (`platform`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for cloud_user_push_status
-- ----------------------------
CREATE TABLE IF NOT EXISTS `cloud_user_push_status` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `user_id` bigint NOT NULL,
  `marker_status` varchar(100) NOT NULL COMMENT '评卷员推送状态(UserPushResultEnum):BIND_SUCCESS("绑定成功"),BIND_FAILED("绑定失败"),UNBIND_SUCCESS("解绑成功"),UNBIND_FAILED("解绑失败");',
  `marker_leader_status` varchar(100) NOT NULL COMMENT '科组长推送状态(UserPushResultEnum):BIND_SUCCESS("绑定成功"),BIND_FAILED("绑定失败"),UNBIND_SUCCESS("解绑成功"),UNBIND_FAILED("解绑失败");',
  `sync_status` varchar(100) NOT NULL COMMENT '同步状态(SyncStatusEnum)，ALREADY_PUSH("已经完成推送"),NEED_PUSH_AGAIN("需要重新推送");',
  `create_id` bigint DEFAULT NULL COMMENT '创建人\n',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_school_id_user_id` (`school_id`,`user_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='云阅卷用户推送状态表';

-- ----------------------------
-- Table structure for exam_card
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_card` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `course_code` varchar(30) DEFAULT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `title` varchar(200) NOT NULL COMMENT '标题',
  `make_method` varchar(10) DEFAULT NULL COMMENT '题卡制作方式：SELECT-选择已有题卡，SELF-自助创建，CUST-客户制卡',
  `status` varchar(45) DEFAULT NULL COMMENT 'STAGE-暂存，SUBMIT-提交',
  `content` mediumtext COMMENT '题卡工具制作题卡内容',
  `stage_content` mediumtext COMMENT '暂存内容（提交后置空）',
  `html_content` mediumtext COMMENT 'html格式内容',
  `type` varchar(45) NOT NULL COMMENT '题卡类型：GENERIC-通卡，CUSTOM-自定义',
  `create_method` varchar(45) DEFAULT NULL COMMENT '通卡创建方式（UPLOAD-上传，CUSTOMIZE-自定义）',
  `attachment_id` bigint DEFAULT NULL COMMENT 'type=GENERIC时必传，上传附件ID',
  `enable` tinyint(1) DEFAULT '1' COMMENT '1正常，0禁用',
  `used` tinyint(1) DEFAULT '0' COMMENT '是否绑定命题任务，默认0',
  `remark` mediumtext COMMENT '备注',
  `card_rule_id` bigint DEFAULT NULL COMMENT '题卡规则Id',
  `backup_attachment` mediumtext COMMENT '备用题卡json',
  `jpg_attachment` text COMMENT '题卡转换成的jpg文件信息',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `blank_card_path` varchar(500) DEFAULT NULL COMMENT '空白题卡pdf路径',
  `paper_id` bigint DEFAULT NULL COMMENT '题库试卷ID',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡';

-- ----------------------------
-- Table structure for exam_card_detail
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_card_detail` (
  `id` bigint NOT NULL COMMENT '主键',
  `card_id` bigint NOT NULL COMMENT '题卡ID',
  `content` mediumtext COMMENT '题卡工具制作题卡内容',
  `html_content` mediumtext COMMENT 'html格式内容',
  `attachment_id` mediumtext COMMENT '备用题卡json',
  `cust_attachment_id` bigint DEFAULT NULL COMMENT '客服制卡上传附件ID',
  `jpg_attachment_info` text COMMENT '题卡转换成的jpg文件信息',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡详情';

-- ----------------------------
-- Table structure for exam_detail
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_detail` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `print_plan_id` bigint NOT NULL COMMENT '印刷计划ID',
  `exam_id` bigint DEFAULT NULL COMMENT '考试ID',
  `print_plan_name` varchar(100) DEFAULT NULL COMMENT '印刷计划名称',
  `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始日期',
  `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束日期',
  `exam_place` varchar(30) DEFAULT NULL COMMENT '考场',
  `total_subjects` int DEFAULT NULL COMMENT '总科次：考场总科次',
  `exam_room` varchar(30) DEFAULT NULL COMMENT '教室',
  `print_progress` double DEFAULT NULL COMMENT '打印进度',
  `print_user` varchar(30) DEFAULT NULL COMMENT '打印员：一个考场只能被一个打印员认领',
  `package_code` varchar(30) DEFAULT NULL COMMENT '考场代码：卷袋贴、签到表上条码',
  `paper_pages` int DEFAULT NULL COMMENT '试卷总计（张）',
  `card_pages` int DEFAULT NULL COMMENT '题卡总计（张）',
  `pages_a4` int DEFAULT NULL COMMENT 'A4印量小计（页）',
  `status` varchar(30) DEFAULT NULL COMMENT '状态：NEW: "新建",READY: "就绪",WAITING: "待印刷",PRINTING: "印刷中",FINISH: "已完成"',
  `validate` tinyint(1) DEFAULT '0' COMMENT '是否校验：true-是，false-否',
  `print_start_time` bigint DEFAULT NULL COMMENT '打印开始时间',
  `print_end_time` bigint DEFAULT NULL COMMENT '打印完成时间',
  `attachment_id` bigint DEFAULT NULL COMMENT '附件id',
  `card_attachment_id` bigint DEFAULT NULL COMMENT '题卡合并A3文件附件ID',
  `attachment_path` mediumtext COMMENT '印品附件路径',
  `exam_data_source` varchar(20) DEFAULT NULL COMMENT '数据来源（EXAM_TASK：卷库查询生成，FILE_IMPORT：考务文件导入）',
  `normal` tinyint DEFAULT '1' COMMENT '是否正常，true正常，false做废',
  `print_house_id` bigint DEFAULT NULL COMMENT '印刷室ID',
  `backup_count` double DEFAULT NULL COMMENT '试卷、题卡备份数量（0-1为按比例，大于等于1为按数量）',
  `task_id` bigint DEFAULT NULL COMMENT 'pdf生成异步任务ID（t_b_task）',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_print_plan_id` (`print_plan_id`) USING BTREE,
  KEY `exam_detail_school_id_IDX` (`school_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据';

-- ----------------------------
-- Table structure for exam_detail_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_detail_course` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_detail_id` bigint NOT NULL COMMENT '考试明细id',
  `course_code` varchar(20) NOT NULL COMMENT '课程编码',
  `course_name` varchar(50) NOT NULL COMMENT '课程名称',
  `paper_number` varchar(30) NOT NULL COMMENT '页数',
  `course_paper_id` varchar(45) DEFAULT NULL COMMENT '试卷编号（交互）',
  `total_subjects` int DEFAULT NULL COMMENT '总科次：考场总科次',
  `paper_pages_a3` int DEFAULT NULL COMMENT '试卷单科次准印量A3（页）',
  `card_pages_a3` int DEFAULT NULL COMMENT '题卡单科次准印量A3（页）',
  `clazz_id` text COMMENT '班级id',
  `clazz_name` mediumtext COMMENT '班级（取学生表中的班级集合）',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `paper_type` varchar(30) DEFAULT NULL COMMENT '当前试卷类型',
  `attachment_id` mediumtext COMMENT '备用题卡json',
  `common_attachment_id` mediumtext COMMENT '模式2下考生公共题卡json',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `detail_course_schoolId_idx` (`school_id`,`paper_number`,`paper_type`) USING BTREE,
  KEY `idx_exam_detail_id` (`exam_detail_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据（考场关联科目）';

-- ----------------------------
-- Table structure for exam_detail_course_paper_type
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_detail_course_paper_type` (
  `id` bigint NOT NULL,
  `exam_detail_course_id` bigint NOT NULL,
  `paper_type` varchar(5) NOT NULL COMMENT '卷型',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_exam_detail_course_id` (`exam_detail_course_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据（考场关联科目对应的卷型）';

-- ----------------------------
-- Table structure for exam_paper_class_marker
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_paper_class_marker` (
  `id` bigint NOT NULL,
  `exam_paper_structure_id` bigint DEFAULT NULL COMMENT '评卷参数id',
  `marker_id` bigint DEFAULT NULL COMMENT '评卷员id',
  `login_name` varchar(100) DEFAULT NULL COMMENT '评卷员登录名',
  `class_name` mediumtext COMMENT '班级',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分班阅（评卷员班级对应关系表）';

-- ----------------------------
-- Table structure for exam_paper_group
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_paper_group` (
  `id` bigint NOT NULL COMMENT '分组id',
  `exam_paper_structure_id` bigint NOT NULL COMMENT '试卷结构id',
  `group_number` int NOT NULL COMMENT '分组序号',
  `double_rate` tinyint DEFAULT NULL COMMENT '双评比例（0关闭，1开启）',
  `arbitrate_threshold` int DEFAULT NULL COMMENT '仲裁阈值（开启双评必填）',
  `score_policy` varchar(45) DEFAULT NULL COMMENT '合分策略 开启双评是必填 AVG("平均分", 1), MAX("最高分", 2), MIN("最低分", 3)',
  `trial_count` int DEFAULT NULL COMMENT '试评数量',
  `mark_mode` varchar(45) DEFAULT NULL COMMENT '评卷模式 COMMON("普通"), TRACK("轨迹")',
  `question_info` text COMMENT '题目信息',
  `picture_config` text COMMENT '图片配置',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `exam_paper_group_unique` (`exam_paper_structure_id`,`group_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='试卷分组表';

-- ----------------------------
-- Table structure for exam_paper_group_marker
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_paper_group_marker` (
  `id` bigint NOT NULL COMMENT '评卷员-分组关系id',
  `group_id` bigint NOT NULL COMMENT '分组id',
  `marker_id` bigint NOT NULL COMMENT '评卷员id',
  `login_name` varchar(100) DEFAULT NULL COMMENT '评卷员登录名',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='评卷员-分组关系表';

-- ----------------------------
-- Table structure for exam_paper_structure
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_paper_structure` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校ID',
  `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
  `semester_name` varchar(100) DEFAULT NULL COMMENT '学期',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `third_relate_id` bigint DEFAULT NULL COMMENT '云阅卷考试ID',
  `third_relate_name` varchar(255) DEFAULT NULL COMMENT '云阅卷考试名称',
  `paper_number` varchar(50) NOT NULL COMMENT '试卷编号',
  `course_code` varchar(50) DEFAULT NULL COMMENT '课程代码',
  `course_name` varchar(255) DEFAULT NULL COMMENT '课程名称',
  `sequence` varchar(5) DEFAULT NULL COMMENT '课程创建的任务序号（和exam_task保持一致）',
  `paper_type` varchar(20) DEFAULT NULL COMMENT '试卷类型',
  `status` varchar(700) DEFAULT NULL COMMENT '{\n    "structure":\n    {\n        "save": false,\n        "sync": false\n    },\n    "group":\n    {\n        "save": false,\n        "sync": false\n    },\n    "class":\n    {\n        "save": false,\n        "sync": false\n    },\n    "objective":\n    {\n        "save": false,\n        "sync": false\n    },\n    "markerLeader":\n    {\n        "save": false,\n        "sync": false\n    },\n    "marker":\n    {\n        "save": false,\n        "sync": false\n    },\n    "answerFile":\n    {\n        "save": false,\n        "sync": false\n    }\n}',
  `is_finish` tinyint(1) DEFAULT '0' COMMENT '是否完成。根据status中组合状态计算。用于当查询条件',
  `paper_answer` text COMMENT '试卷原卷和标答附件ID',
  `objective_structure` mediumtext COMMENT '客观题试卷结构JSON',
  `subjective_structure` mediumtext COMMENT '主观题试卷结构JSON',
  `paper_info_json` mediumtext COMMENT '整个试卷信息json（前端提供的全部信息）',
  `proposition_teacher_id` bigint DEFAULT NULL COMMENT '命题老师ID',
  `enable` tinyint(1) DEFAULT NULL COMMENT '是否启用（0-禁用，1-启用）',
  `mark_leader` text COMMENT '科组长，样例：[{markerId:1, loginName:"mt01"}]',
  `cloud_info_json` text COMMENT '云阅卷试卷结构',
  `structure_change` tinyint(1) DEFAULT NULL COMMENT '云阅卷试卷结构和知学知考结构不一样（默认false）',
  `object_answer_change` tinyint(1) DEFAULT '0' COMMENT '客观题答案有提交，需要重新统分。（1：有变动，需要统分，0：不统分）',
  `open_class_reading` tinyint(1) DEFAULT '0' COMMENT '是否开启分班阅',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `exam_paper_structure_unique` (`school_id`,`exam_id`,`paper_number`,`paper_type`) USING BTREE,
  KEY `exam_paper_structure_status_IDX` (`status`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for exam_print_plan
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_print_plan` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `category` varchar(10) DEFAULT NULL COMMENT '考试类型',
  `name` varchar(150) DEFAULT NULL COMMENT '名称',
  `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始时间',
  `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束时间',
  `print_content` varchar(30) NOT NULL COMMENT '{“PAPER”, "CARD"}',
  `backup_method` varchar(10) NOT NULL COMMENT 'PLACE-按考点，ROOM-按考场',
  `backup_count` double NOT NULL COMMENT '试卷、题卡备份数量（0-1为按比例，大于等于1为按数量）',
  `draw_rule` varchar(10) DEFAULT NULL COMMENT 'ONE-只抽一次，CIRCLE-可循环抽取',
  `variable_content` text NOT NULL COMMENT '[\n  	{\n  		"type": "SIGN",\n  		"usedId": 1,\n  		"backupMethod": "ROOM",\n  		"backupCount": 3\n  	},\n  	{\n  		"type": "PACKAG",\n  		"usedId": 3,\n  		"backupMethod": "STUDENT",\n  		"backupCount": 5\n  	}\n  ]',
  `ordinary_content` text NOT NULL COMMENT '[\n  	{\n  		"type": "CHECK_IN",\n  		"usedId": 1,\n  		"backupMethod": "ROOM",\n  		"backupCount": 3\n  	}\n  ]',
  `status` varchar(20) NOT NULL COMMENT '印刷计划状态',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `third_relate_id` bigint DEFAULT NULL COMMENT '第三方系统关联ID（目前只有云阅卷）',
  `third_relate_name` varchar(100) DEFAULT NULL COMMENT '第三方系统关联考试名称（目前只有云阅卷）',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='印刷计划管理';

-- ----------------------------
-- Table structure for exam_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_student` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `exam_detail_course_id` bigint NOT NULL COMMENT '考试明细课程id',
  `student_name` varchar(100) NOT NULL COMMENT '考生姓名',
  `student_code` varchar(100) NOT NULL COMMENT '考生代码',
  `exam_id` bigint DEFAULT NULL COMMENT '考试ID',
  `paper_number` varchar(30) NOT NULL COMMENT '试卷编号',
  `course_paper_id` varchar(45) DEFAULT NULL COMMENT '试卷编号（交互）',
  `ticket_number` varchar(30) DEFAULT NULL COMMENT '准考证号',
  `site_number` varchar(30) DEFAULT NULL COMMENT '座位号',
  `print_paper` tinyint DEFAULT NULL COMMENT '打印试卷',
  `print_card` tinyint DEFAULT NULL COMMENT '打印题卡',
  `required_fields` mediumtext COMMENT '基础字段',
  `extend_fields` text COMMENT '扩展字段',
  `paper_type` varchar(2) DEFAULT NULL COMMENT '试卷类型',
  `college_name` varchar(100) DEFAULT NULL COMMENT '学生学院名称',
  `major_name` varchar(100) DEFAULT NULL COMMENT '专业名称',
  `clazz_id` varchar(100) DEFAULT NULL COMMENT '班级Id',
  `clazz_name` varchar(100) DEFAULT NULL COMMENT '班级名称',
  `teach_clazz_id` bigint DEFAULT NULL COMMENT '教学班id',
  `teach_clazz_name` varchar(100) DEFAULT NULL COMMENT '教学班名称',
  `student_clazz_type` varchar(100) DEFAULT NULL COMMENT '主体班级类型',
  `campus_name` varchar(200) DEFAULT NULL COMMENT '校区',
  `teacher_id` bigint DEFAULT NULL COMMENT '任课老师ID',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `attachment_id` bigint DEFAULT NULL COMMENT '附件id',
  `can_delete` tinyint(1) DEFAULT '0' COMMENT '是否可以删除（手动新增可以删除）',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `unique_ticket_number_idx` (`school_id`,`ticket_number`) USING BTREE,
  KEY `exam_student_schoolId_idx` (`school_id`,`student_code`) USING BTREE,
  KEY `idx_exam_detail_course_id` (`exam_detail_course_id`) USING BTREE,
  KEY `idx_4` (`exam_id`, `paper_number`, `student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考生';

-- ----------------------------
-- Table structure for exam_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `course_code` varchar(20) NOT NULL COMMENT '课程代码',
  `course_name` varchar(50) NOT NULL COMMENT '课程名称',
  `specialty` varchar(100) DEFAULT NULL COMMENT '适用专业',
  `paper_number` varchar(30) NOT NULL COMMENT '试卷编号',
  `sequence` varchar(5) DEFAULT NULL COMMENT '课程创建的任务序号',
  `start_time` bigint DEFAULT NULL COMMENT '命题开始时间',
  `end_time` bigint DEFAULT NULL COMMENT '命题结束时间',
  `card_rule_id` bigint NOT NULL COMMENT '题卡规则',
  `user_id` bigint DEFAULT NULL COMMENT '命题老师',
  `transfer_id` bigint DEFAULT NULL COMMENT '转办人ID',
  `status` varchar(50) DEFAULT NULL COMMENT '任务状态，DRAFT：新建，SUBMIT：已提交，STAGE：待命题',
  `review` tinyint DEFAULT NULL COMMENT '是否审核，0-禁用，1-启用',
  `review_status` varchar(8) DEFAULT NULL COMMENT '审核状态：PASS-审核通过，NOT_PASS-审核不通过，默认为空-未审核',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
  `batch_no` varchar(32) DEFAULT NULL COMMENT '批次id',
  `teaching_room_id` bigint DEFAULT NULL COMMENT '教学单位、教研室',
  `teacher_name` varchar(100) DEFAULT NULL COMMENT '拟卷教师',
  `lecturer_name` varchar(100) DEFAULT NULL COMMENT '主讲教师',
  `paper_name` varchar(100) DEFAULT NULL COMMENT '试卷名称',
  `cancel_remark` mediumtext COMMENT '作废原因',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '修改人',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `flow_id` bigint DEFAULT NULL COMMENT '流程id',
  `approve_form_attachment_id` bigint DEFAULT NULL COMMENT '命题任务审批表附件id',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `task_schoolId_flowId_idx` (`school_id`,`flow_id`,`card_rule_id`) USING BTREE,
  KEY `idx_school_id_paper_number` (`exam_id`,`paper_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务';

-- ----------------------------
-- Table structure for exam_task_apply_temp
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_apply_temp` (
  `id` bigint unsigned NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校Id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `exam_task_content` mediumtext COMMENT '命题任务json',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='卷库查询-命题任务申请临时表';

-- ----------------------------
-- Table structure for exam_task_assign_paper_type
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_assign_paper_type` (
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `exam_start_time` bigint NOT NULL COMMENT '考试时间（开始）',
  `exam_end_time` bigint NOT NULL COMMENT '考试时间（结束）',
  `paper_type` varchar(45) DEFAULT NULL COMMENT '卷型',
  `assign_mode` varchar(10) DEFAULT NULL COMMENT '分配方式：MANUAL-手动关联，AUTO-自动分配',
  PRIMARY KEY (`exam_id`,`paper_number`,`exam_start_time`,`exam_end_time`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for exam_task_detail
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_detail` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_task_id` bigint NOT NULL COMMENT '命题任务ID',
  `paper_type` varchar(20) DEFAULT NULL COMMENT '试卷类型，多个以”/“分隔，如A/B/C/D',
  `draw_count` int DEFAULT NULL COMMENT '单次抽卷数量',
  `paper_attachment_ids` text COMMENT '转换为A3格式的试卷附件\n[\\n  	{\\n  		"type": "A",\\n  		"attachmentId": 12,\\n  		"totalPages": 3\\n  	},\\n  	{\\n  		"type": "B",\\n  		"attachmentId": 13,\\n  		"totalPages": 2\\n  	}\\n  ]',
  `make_method` varchar(45) DEFAULT NULL COMMENT '题卡绑定方式',
  `paper_confirm_attachment_ids` text COMMENT '[\n  	{\n  		"attachmentId": 12\n  	},\n  	{\n  		"attachmentId": 13\n  	}\n  ]',
  `remark` varchar(200) DEFAULT NULL COMMENT '备注',
  `exposed_paper_type` varchar(20) DEFAULT NULL COMMENT '曝光卷型：已打印卷型，多个以”/“分隔，如A/B/C/D',
  `relate_paper_type` varchar(5) DEFAULT NULL COMMENT '已曝光卷型',
  `unexposed_paper_type` varchar(20) DEFAULT NULL COMMENT '未曝光卷型',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `enable` tinyint DEFAULT '1' COMMENT '0-禁用，1-启用',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `exam_task_detail_idx` (`exam_task_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务明细表（入库申请）';

-- ----------------------------
-- Table structure for exam_task_paper_data
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_paper_data` (
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_id` bigint NOT NULL COMMENT '题库试卷ID',
  `data_packet_path` varchar(200) DEFAULT NULL COMMENT '题库试卷数据包地址（zip）',
  `paper_json` mediumtext COMMENT '试卷结构内容（从paper.json解析）',
  `answer_json` mediumtext COMMENT '试卷答案内容（从answer.json解析）',
  `paper_pdf_attachment_id` bigint DEFAULT NULL COMMENT '试卷pdf文件地址（paper.pdf上传附件ID）',
  `answer_pdf_attachment_id` bigint DEFAULT NULL COMMENT '标答pdf文件地址（answer.pdf上传附件ID）',
  `uuid` varchar(200) DEFAULT NULL COMMENT '唯一标识',
  PRIMARY KEY (`exam_id`,`paper_number`,`paper_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务选择题库试卷相关文件表';

-- ----------------------------
-- Table structure for exam_task_paper_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_paper_log` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_task_id` bigint NOT NULL COMMENT '命题任务ID',
  `paper_type` varchar(45) DEFAULT NULL COMMENT '试卷类型',
  `paper_attachment_ids` mediumtext COMMENT '修改后试卷',
  `card_id` bigint DEFAULT NULL COMMENT '修改后题卡ID',
  `review` tinyint(1) DEFAULT NULL COMMENT '是否审核：true-审核，false-未审核',
  `review_status` varchar(45) DEFAULT NULL COMMENT '审核状态：PASS-通过，NOT_PASS-不通过',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `exam_task_paper_idx` (`exam_task_id`,`review`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='卷库修改审核临时表';

-- ----------------------------
-- Table structure for exam_task_print
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_print` (
  `id` bigint NOT NULL,
  `school_id` bigint DEFAULT NULL,
  `org_id` bigint DEFAULT NULL,
  `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划ID',
  `course_code` varchar(45) DEFAULT NULL COMMENT '课程代码',
  `course_name` varchar(50) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(45) DEFAULT NULL COMMENT '试卷编号',
  `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始时间',
  `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束时间',
  `package_seq` varchar(30) DEFAULT NULL COMMENT '卷袋序号',
  `exam_place` varchar(100) DEFAULT NULL,
  `exam_room` varchar(100) DEFAULT NULL,
  `invigilator_teacher` varchar(45) DEFAULT NULL COMMENT '监考老师',
  `class_id` varchar(100) DEFAULT NULL COMMENT '班级ID集合',
  `class_name` varchar(500) DEFAULT NULL COMMENT '班级名称集合',
  `student_count` int DEFAULT NULL COMMENT '考生总人数',
  `campus_id` bigint DEFAULT NULL COMMENT '校区ID',
  `print_house_id` bigint DEFAULT NULL COMMENT '印刷室ID',
  `print_house_name` varchar(100) DEFAULT NULL COMMENT '印刷室名称',
  `exam_detail_id` bigint DEFAULT NULL COMMENT '考场ID',
  `extend_fields` text COMMENT '扩展字段',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='以试卷作为起点生成考务数据';

-- ----------------------------
-- Table structure for exam_task_review_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_review_log` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_task_id` bigint NOT NULL COMMENT '命题任务ID',
  `review_status` varchar(8) NOT NULL COMMENT 'PASS-通过，NOT_PASS-不通过',
  `reason` mediumtext COMMENT '审核意见',
  `operate_id` bigint DEFAULT NULL COMMENT '操作人id',
  `operate_time` bigint DEFAULT NULL COMMENT '操作时间',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务审核日志表';

-- ----------------------------
-- Table structure for exam_task_sync
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_sync` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(50) NOT NULL COMMENT '课程代码',
  `paper_number` varchar(50) NOT NULL COMMENT '试着编号',
  `paper_type` varchar(50) DEFAULT NULL COMMENT '试卷类型',
  `total_paper_type` varchar(50) DEFAULT NULL COMMENT '所有卷型',
  `org_code` varchar(45) DEFAULT NULL COMMENT '机构代码',
  `third_relate_id` int DEFAULT NULL COMMENT '云阅卷考试ID',
  `sync_status` varchar(45) DEFAULT NULL COMMENT '同步状态',
  `error_msg` varchar(500) DEFAULT NULL COMMENT '同步失败原因',
  `sync_user_id` bigint DEFAULT NULL COMMENT '同步用户ID',
  `sync_start_time` bigint DEFAULT NULL COMMENT '同步开始时间 ',
  `sync_end_time` bigint DEFAULT NULL COMMENT '同步结束时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for exam_task_temp
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_task_temp` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `batch_no` varchar(32) NOT NULL COMMENT '本次导入数据临时ID',
  `course_code` varchar(20) NOT NULL COMMENT '课程代码',
  `course_name` varchar(50) NOT NULL COMMENT '课程名称',
  `paper_number` varchar(30) DEFAULT NULL COMMENT '试卷编号',
  `specialty` varchar(100) DEFAULT NULL COMMENT '适用专业',
  `user_account` varchar(45) DEFAULT NULL COMMENT '命题老师账号',
  `user_name` varchar(45) DEFAULT NULL COMMENT '命题老师姓名',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务临时表';

-- ----------------------------
-- Table structure for grade_batch
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_batch` (
  `id` bigint NOT NULL COMMENT '分析批次主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `semester_id` bigint NOT NULL COMMENT '学期id',
  `exam_id` bigint NOT NULL COMMENT '知学知考考试id',
  `batch_code` varchar(32) NOT NULL COMMENT '批次编号（在学校下唯一）',
  `batch_name` varchar(32) NOT NULL COMMENT '批次名称（2020~2021学年上学期期末考试）',
  `batch_time` bigint NOT NULL COMMENT '分析批次时间',
  `status` varchar(32) NOT NULL COMMENT '批次状态\nSETTING_GRADE_PAPER("设置分析试卷"),PUSH_GRADE_BATCH("推送教研分析批次数据"),SETTING_GRADE_PAPER_PARAM("设置分析试卷参数"),READY_TO_CALCULATE("待计算"),FINISH_CALCULATE("完成计算")',
  `third_semester_id` bigint DEFAULT NULL COMMENT '教研分析学期id',
  `third_exam_id` bigint DEFAULT NULL COMMENT '第三方考试id',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  `source` varchar(1000) DEFAULT NULL COMMENT '原始数据',
  `progress` decimal(8,2) DEFAULT NULL COMMENT '进度',
  `report_file_path` varchar(500) DEFAULT NULL COMMENT '报告路径',
  `notify_time` bigint DEFAULT NULL COMMENT '回调时间',
  `result` varchar(30) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-批次表';

-- ----------------------------
-- Table structure for grade_batch_paper
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_batch_paper` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint NOT NULL COMMENT '机构id',
  `exam_id` bigint NOT NULL COMMENT '知学知考考试id',
  `batch_id` bigint NOT NULL COMMENT '分析批次id',
  `grade_paper_id` bigint DEFAULT NULL COMMENT '试卷id',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) NOT NULL COMMENT '试卷类型',
  `status` varchar(32) NOT NULL COMMENT '分析试卷状态\nSETTING_GRADE_PAPER("设置分析试卷"),PUSH_GRADE_BATCH("推送教研分析批次数据"),SETTING_GRADE_PAPER_PARAM("设置分析试卷参数"),READY_TO_CALCULATE("待计算"),FINISH_CALCULATE("完成计算")',
  `teach_college_id` bigint NOT NULL COMMENT '当前开课学院id',
  `teach_college_name` varchar(100) NOT NULL COMMENT '当前开课学院名称',
  `paper_name` varchar(100) DEFAULT NULL COMMENT '试卷名称',
  `enable` tinyint DEFAULT NULL COMMENT '是否可用',
  `publish_status` tinyint DEFAULT NULL COMMENT '是否发布',
  `grade_course_code` varchar(100) DEFAULT NULL COMMENT '推送教研分析后回传的教研分析课程编号（考试下唯一）',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-批次试卷关联关系表';

-- ----------------------------
-- Table structure for grade_batch_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_batch_student` (
  `id` bigint NOT NULL,
  `batch_id` bigint DEFAULT NULL COMMENT '分析-批次表ID',
  `course_code` varchar(50) DEFAULT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(50) DEFAULT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) DEFAULT NULL COMMENT '试卷类型',
  `student_code` varchar(45) DEFAULT NULL COMMENT '学号',
  `student_name` varchar(100) DEFAULT NULL COMMENT '学生姓名',
  `ticket_number` varchar(45) DEFAULT NULL COMMENT '准考证号',
  `teacher_name` varchar(100) DEFAULT NULL COMMENT '任课老师',
  `teacher_number` varchar(45) DEFAULT NULL COMMENT '任课老师工号',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据（包含任课老师）';

-- ----------------------------
-- Table structure for grade_batch_student_clazz
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_batch_student_clazz` (
  `id` bigint NOT NULL,
  `batch_id` bigint DEFAULT NULL COMMENT '分析-批次表ID',
  `course_code` varchar(50) DEFAULT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(50) DEFAULT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) DEFAULT NULL COMMENT '试卷类型',
  `clazz_id` varchar(45) DEFAULT NULL COMMENT '班级ID',
  `clazz_name` varchar(100) DEFAULT NULL COMMENT '班级名称',
  `teacher_name` varchar(100) DEFAULT NULL COMMENT '任课老师',
  `teacher_number` varchar(45) DEFAULT NULL COMMENT '任课老师工号',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据班级（包含任课老师）';

-- ----------------------------
-- Table structure for grade_module_define
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_module_define` (
  `id` bigint NOT NULL COMMENT '模块熟练度主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) NOT NULL COMMENT '试卷类型',
  `paper_name` varchar(100) DEFAULT NULL COMMENT '试卷名称',
  `module_type` varchar(32) NOT NULL COMMENT '维度模块类型',
  `interpret` varchar(255) DEFAULT NULL COMMENT '解释',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `define` varchar(255) DEFAULT NULL COMMENT '二级熟练度定义',
  `level` varchar(32) DEFAULT NULL COMMENT '等级',
  `min` varchar(32) DEFAULT NULL COMMENT '展示用最小边界',
  `max` varchar(32) DEFAULT NULL COMMENT '展示用最大边界',
  `scope` varchar(32) DEFAULT NULL COMMENT '取值范围（计算用）',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-模块二级考察点维度熟练度配置，及模块简要描述表';

-- ----------------------------
-- Table structure for grade_module_evaluation
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_module_evaluation` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) NOT NULL COMMENT '试卷类型',
  `paper_name` varchar(100) DEFAULT NULL COMMENT '试卷名称',
  `module_type` varchar(64) NOT NULL COMMENT '模块类型（知识、维度、素养）',
  `formula` varchar(64) NOT NULL COMMENT '计算公式规则',
  `scope` varchar(64) NOT NULL COMMENT '取值范围（计算用）',
  `level_code` varchar(32) NOT NULL COMMENT '等级',
  `level_name` varchar(32) NOT NULL COMMENT '水平等级层次',
  `result` text COMMENT '诊断结果',
  `advice` text COMMENT '学习建议',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='校验-考察点模块评价建议表';

-- ----------------------------
-- Table structure for grade_paper
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_paper` (
  `id` bigint NOT NULL COMMENT '试卷id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '知学知考考试id',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) NOT NULL COMMENT '试卷类型',
  `paper_name` varchar(100) NOT NULL COMMENT '试卷名称',
  `start_time` bigint DEFAULT NULL COMMENT '该试卷考试开始时间',
  `end_time` bigint DEFAULT NULL COMMENT '该试卷考试结束时间',
  `coefficient` decimal(12,4) DEFAULT NULL COMMENT '赋分系数（赋值分=卷面成绩 +（卷面满分-卷面成绩）/ 赋分系数）',
  `total_score` decimal(12,4) NOT NULL COMMENT '试卷满分',
  `pass_score` decimal(12,4) NOT NULL COMMENT '试卷及格分',
  `score_type` varchar(64) NOT NULL COMMENT '赋分类型\\n1.NEED_ASSIGN_SCORE("是","需要且按照公式赋分")\\n2.NO_NEED_ASSIGN_SCORE("否","不需要赋分，标准分即为赋分")\\n3.SPECIAL_ASSIGN_SCORE("特殊赋分","特殊赋分，按照excel表进行赋分")',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='试卷基础信息表（赋分系数、试卷类型、满分、及格分等）';

-- ----------------------------
-- Table structure for grade_paper_dimension
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_paper_dimension` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) NOT NULL COMMENT '试卷类型',
  `paper_name` varchar(100) NOT NULL COMMENT '试卷名称',
  `dimension_type` varchar(32) NOT NULL COMMENT '维度类型 - 知识，能力，素养',
  `code_primary` varchar(32) NOT NULL COMMENT '一级维度编号',
  `name_primary` varchar(255) NOT NULL COMMENT '一级维度名称',
  `code_second` varchar(32) DEFAULT NULL COMMENT '二级维度编号',
  `name_second` varchar(255) DEFAULT NULL COMMENT '二级维度名称',
  `interpretation` varchar(255) DEFAULT NULL COMMENT '一级维度术语解释',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-考察点维度表';

-- ----------------------------
-- Table structure for grade_paper_struct
-- ----------------------------
CREATE TABLE IF NOT EXISTS `grade_paper_struct` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '知学知考考试id',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `paper_type` varchar(16) NOT NULL COMMENT '试卷类型',
  `paper_name` varchar(100) NOT NULL COMMENT '试卷名称',
  `question_name` varchar(200) NOT NULL COMMENT '大题名称',
  `number_type` varchar(32) NOT NULL COMMENT '题号类型（客观题、主观题）',
  `big_question_number` varchar(64) NOT NULL COMMENT '大题号',
  `small_question_number` varchar(64) NOT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
  `big_topic_name` varchar(64) NOT NULL COMMENT '大题名称',
  `full_score` decimal(12,4) NOT NULL COMMENT '满分',
  `score_rules` varchar(32) DEFAULT NULL COMMENT '计分规则',
  `rules_desc` varchar(500) DEFAULT NULL COMMENT '规则说明',
  `knowledge_dimension` varchar(255) NOT NULL COMMENT '知识维度',
  `ability_dimension` varchar(255) DEFAULT NULL COMMENT '能力维度',
  `literacy_dimension` varchar(255) DEFAULT NULL COMMENT '素养维度',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-试卷结构（蓝图）表';

-- ----------------------------
-- Table structure for mark_arbitrate_history
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_arbitrate_history` (
  `id` bigint NOT NULL COMMENT '自增主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `group_number` int NOT NULL COMMENT '大题号',
  `student_code` varchar(64) NOT NULL COMMENT '准考证号',
  `secret_number` varchar(64) NOT NULL COMMENT '考生密号',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `status` varchar(16) NOT NULL COMMENT '状态',
  `update_user_id` bigint DEFAULT NULL COMMENT '处理人ID',
  `total_score` double DEFAULT NULL COMMENT '总分',
  `score_list` text COMMENT '给分明细',
  `create_time` bigint NOT NULL COMMENT '创建时间',
  `update_time` bigint DEFAULT NULL COMMENT '处理时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `index1` (`exam_id`,`paper_number`,`group_number`,`status`) USING BTREE,
  KEY `index3` (`student_id`,`status`) USING BTREE,
  KEY `index2` (`update_user_id`,`status`,`update_time`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='仲裁记录表';

-- ----------------------------
-- Table structure for mark_document
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_document` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(32) NOT NULL COMMENT '课程代码',
  `course_name` varchar(100) NOT NULL COMMENT '科目名称',
  `paper_number` varchar(64) DEFAULT NULL COMMENT '试卷编号',
  `type` varchar(64) NOT NULL COMMENT '类型',
  `name` varchar(64) DEFAULT NULL COMMENT '名称',
  `file_count` int DEFAULT NULL COMMENT '文件数量',
  `file_path` mediumtext COMMENT '文件地址',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='归档文档表';

-- ----------------------------
-- Table structure for mark_group
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_group` (
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(100) DEFAULT NULL COMMENT '课程代码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `number` int NOT NULL COMMENT '序号',
  `pic_list` text COMMENT '小图配置',
  `total_score` double NOT NULL COMMENT '满分',
  `double_enable` tinyint(1) DEFAULT '0' COMMENT '是否开启双评',
  `double_rate` double DEFAULT NULL COMMENT '双评比例',
  `arbitrate_threshold` double DEFAULT NULL COMMENT '仲裁阈值',
  `score_policy` varchar(16) DEFAULT NULL COMMENT '合分策略',
  `task_count` int NOT NULL COMMENT '任务总量',
  `marked_count` int NOT NULL COMMENT '已评数量',
  `left_count` int DEFAULT NULL COMMENT '剩余数量',
  PRIMARY KEY (`exam_id`,`paper_number`,`number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='评卷分组表';

-- ----------------------------
-- Table structure for mark_group_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_group_student` (
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `group_number` int NOT NULL COMMENT '分组ID',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(32) NOT NULL COMMENT '科目代码',
  `status` varchar(16) NOT NULL COMMENT '状态',
  PRIMARY KEY (`student_id`,`group_number`) USING BTREE,
  KEY `index1` (`exam_id`,`paper_number`,`group_number`,`status`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考生分组状态表';

-- ----------------------------
-- Table structure for mark_header_subjective_score
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_header_subjective_score` (
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `main_number` int NOT NULL COMMENT '大题号',
  `sub_number` varchar(32) NOT NULL COMMENT '小题号',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '课程代码',
  `group_number` int NOT NULL COMMENT '分组序号',
  `group_score` double NOT NULL COMMENT '分组得分',
  `main_score` double NOT NULL COMMENT '大题得分',
  `score` double NOT NULL COMMENT '小题得分',
  `uncalculate` tinyint NOT NULL COMMENT '是否合分',
  `user_id` bigint DEFAULT NULL COMMENT '科组长ID',
  PRIMARY KEY (`student_id`,`main_number`,`sub_number`) USING BTREE,
  KEY `index1` (`exam_id`,`paper_number`,`main_number`,`main_score`) USING BTREE,
  KEY `index11` (`exam_id`,`paper_number`,`main_number`,`main_score`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='主观题得分明细表';

-- ----------------------------
-- Table structure for mark_header_tag
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_header_tag` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(45) NOT NULL COMMENT '试卷编号',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `group_number` int NOT NULL COMMENT '大题题号',
  `user_id` bigint NOT NULL COMMENT '用户ID',
  `tag_name` varchar(64) NOT NULL COMMENT '标记内容',
  `position_x` double NOT NULL COMMENT 'X轴位置',
  `position_y` double NOT NULL COMMENT 'Y轴位置',
  `offset_index` int NOT NULL COMMENT '裁切图序号',
  `offset_x` int NOT NULL COMMENT '裁切图X轴坐标',
  `offset_y` int NOT NULL COMMENT '裁切图Y轴坐标',
  `tag_type` varchar(64) DEFAULT NULL COMMENT '标记类型',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `index1` (`student_id`,`group_number`) USING BTREE,
  KEY `index2` (`user_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='组长特殊标记表';

-- ----------------------------
-- Table structure for mark_header_track
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_header_track` (
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `question_number` varchar(128) NOT NULL COMMENT '完整题号',
  `number` int NOT NULL COMMENT '序号',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '科目代码',
  `group_number` int NOT NULL COMMENT '大题题号',
  `user_id` bigint NOT NULL COMMENT '用户ID',
  `score` double NOT NULL COMMENT '给分',
  `position_x` double NOT NULL COMMENT 'X轴位置',
  `position_y` double NOT NULL COMMENT 'Y轴位置',
  `offset_index` int NOT NULL COMMENT '裁切图序号',
  `offset_x` int NOT NULL COMMENT '裁切图X轴坐标',
  `offset_y` int NOT NULL COMMENT '裁切图Y轴坐标',
  PRIMARY KEY (`student_id`,`question_number`,`number`) USING BTREE,
  KEY `index1` (`student_id`,`group_number`) USING BTREE,
  KEY `index2` (`user_id`) USING BTREE,
  KEY `index3` (`exam_id`,`paper_number`,`group_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='组长轨迹给分表';

-- ----------------------------
-- Table structure for mark_paper
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_paper` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(32) NOT NULL COMMENT '课程代码',
  `course_name` varchar(100) NOT NULL COMMENT '科目名称',
  `paper_number` varchar(64) DEFAULT NULL COMMENT '试卷编号',
  `course_paper_id` varchar(32) DEFAULT NULL COMMENT '试卷编号（交互）',
  `objective_score` double NOT NULL COMMENT '客观题满分',
  `subjective_score` double NOT NULL COMMENT '主观题满分',
  `total_score` double NOT NULL COMMENT '全卷满分',
  `student_count` int DEFAULT NULL COMMENT '考生人数',
  `upload_count` int NOT NULL COMMENT '已上传人数',
  `absent_count` int DEFAULT NULL COMMENT '缺考人数',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  `sheet_config` text COMMENT '原图遮盖配置',
  `pass_score` double DEFAULT NULL COMMENT '及格分',
  `excellent_score` double DEFAULT NULL COMMENT '优秀分',
  `card_type` varchar(16) DEFAULT NULL COMMENT '题卡类型',
  `paper_file_path` varchar(500) DEFAULT NULL COMMENT '试卷文件类型',
  `answer_file_path` varchar(500) DEFAULT NULL COMMENT '标答文件类型',
  `auto_scroll` tinyint(1) DEFAULT NULL COMMENT '评卷是否跳转',
  `mark_mode` varchar(16) DEFAULT NULL COMMENT '评卷模式',
  `force_mode` tinyint(1) DEFAULT '1' COMMENT '强制评卷模式（不限为false）',
  `mark_start_time` bigint DEFAULT NULL COMMENT '评卷开始时间',
  `mark_end_time` bigint DEFAULT NULL COMMENT '评卷结束时间',
  `sheet_view` tinyint DEFAULT NULL COMMENT '是否原卷显示',
  `show_object_score` tinyint DEFAULT NULL COMMENT '评卷是否显示客观分',
  `group_status` tinyint DEFAULT '0' COMMENT '评卷分组是否提交',
  `open_mark_class` tinyint DEFAULT '0' COMMENT '是否开启分班阅',
  `status` varchar(10) DEFAULT NULL COMMENT '评卷状态',
  `package_code` mediumtext COMMENT '签到表编号',
  `user_id` bigint DEFAULT NULL COMMENT '命题老师ID',
  `paper_type` varchar(10) DEFAULT NULL COMMENT '试卷类型',
  `open_double_marking` bigint DEFAULT '0' COMMENT '是否开启双评：true-开启，false-关闭',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考试科目表';

-- ----------------------------
-- Table structure for mark_paper_package
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_paper_package` (
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(32) NOT NULL COMMENT '课程代码',
  `course_name` varchar(100) NOT NULL COMMENT '科目名称',
  `paper_number` varchar(50) DEFAULT NULL COMMENT '试卷编号',
  `course_paper_id` varchar(50) NOT NULL COMMENT '课程试卷号',
  `paper_type` varchar(10) NOT NULL COMMENT '试卷类型',
  `package_code` varchar(10) NOT NULL COMMENT '卷袋号',
  PRIMARY KEY (`exam_id`,`course_paper_id`,`paper_type`,`package_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for mark_problem_history
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_problem_history` (
  `id` bigint NOT NULL COMMENT '自增主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(32) NOT NULL COMMENT '试卷编号',
  `group_number` int NOT NULL COMMENT '大题号',
  `student_code` varchar(64) NOT NULL COMMENT '学号',
  `secret_number` varchar(64) NOT NULL COMMENT '考生密号',
  `type` varchar(10) NOT NULL COMMENT '问题类型',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `task_id` bigint NOT NULL COMMENT '评卷任务ID',
  `status` varchar(16) DEFAULT NULL COMMENT '状态',
  `update_user_id` bigint DEFAULT NULL COMMENT '处理人ID',
  `user_id` bigint DEFAULT NULL COMMENT '评卷员ID',
  `score_list` text COMMENT '给分明细',
  `create_time` bigint NOT NULL COMMENT '创建时间',
  `update_time` bigint DEFAULT NULL COMMENT '处理时间',
  `remark` varchar(100) DEFAULT NULL COMMENT '问题原因',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `index2` (`update_user_id`,`status`,`update_time`) USING BTREE,
  KEY `index3` (`student_id`,`status`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='问题卷历史表';

-- ----------------------------
-- Table structure for mark_question
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_question` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷类型',
  `paper_type` varchar(100) DEFAULT NULL COMMENT '卷型',
  `objective` tinyint NOT NULL COMMENT '是否客观题',
  `group_number` int DEFAULT NULL COMMENT '分组序号',
  `main_number` int NOT NULL COMMENT '大题号',
  `sub_number` int NOT NULL COMMENT '小题号',
  `main_title` varchar(128) NOT NULL COMMENT '大题名称',
  `answer` varchar(16) DEFAULT NULL COMMENT '正确答案',
  `total_score` double DEFAULT NULL COMMENT '满分',
  `option_count` int DEFAULT NULL COMMENT '客观题答案数量',
  `interval_score` double DEFAULT NULL COMMENT '评卷间隔分',
  `objective_policy` varchar(16) DEFAULT NULL COMMENT '客观题判分策略',
  `question_type` varchar(2) DEFAULT NULL COMMENT '题型',
  `name` varchar(128) DEFAULT NULL,
  `paper_index` int DEFAULT NULL,
  `page_index` int DEFAULT NULL,
  `objective_policy_score` double DEFAULT NULL COMMENT '客观题判分策略计分',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='小题信息表';

-- ----------------------------
-- Table structure for mark_special_tag
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_special_tag` (
  `id` bigint NOT NULL COMMENT '主键',
  `task_id` bigint NOT NULL COMMENT '评卷任务ID',
  `tag_name` varchar(64) NOT NULL COMMENT '标记内容',
  `position_x` double NOT NULL COMMENT 'X轴位置',
  `position_y` double NOT NULL COMMENT 'Y轴位置',
  `offset_index` int NOT NULL COMMENT '裁切图序号',
  `offset_x` int NOT NULL COMMENT '裁切图X轴坐标',
  `offset_y` int NOT NULL COMMENT '裁切图Y轴坐标',
  `tag_type` varchar(64) DEFAULT NULL COMMENT '标记类型',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `index1` (`task_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='特殊标记表';

-- ----------------------------
-- Table structure for mark_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_student` (
  `id` bigint NOT NULL COMMENT '主键(和exam_student表id一样)',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(32) NOT NULL COMMENT '科目代码',
  `course_name` varchar(100) NOT NULL COMMENT '科目名称',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷类型',
  `course_paper_id` varchar(45) DEFAULT NULL COMMENT '试卷编号（交互）',
  `paper_type` varchar(10) DEFAULT NULL COMMENT '试卷编号',
  `secret_number` varchar(64) NOT NULL COMMENT '密号',
  `student_code` varchar(64) NOT NULL COMMENT '学号',
  `student_name` varchar(64) NOT NULL COMMENT '姓名',
  `package_code` varchar(64) DEFAULT NULL COMMENT '试卷袋编号',
  `exam_place` varchar(32) DEFAULT NULL COMMENT '校区',
  `exam_room` varchar(32) DEFAULT NULL COMMENT '考场',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  `batch_code` varchar(32) DEFAULT NULL COMMENT '扫描批次号',
  `sheet_count` int NOT NULL COMMENT '原图数量',
  `sheet_path` mediumtext COMMENT '考生所有图片地址',
  `answers` text COMMENT '客观题识别结果',
  `is_upload` tinyint NOT NULL COMMENT '是否已上传',
  `is_absent` tinyint NOT NULL COMMENT '是否缺考',
  `is_manual_absent` tinyint NOT NULL COMMENT '是否人工指定缺考',
  `is_breach` tinyint NOT NULL COMMENT '是否违纪',
  `upload_time` bigint DEFAULT NULL COMMENT '上传时间',
  `check_time` bigint DEFAULT NULL COMMENT '检查时间',
  `check_user_id` bigint DEFAULT NULL COMMENT '检查人ID',
  `objective_score` double DEFAULT NULL COMMENT '客观总分',
  `objective_score_list` text COMMENT '客观得分明细',
  `subjective_status` varchar(16) NOT NULL COMMENT '主观题状态',
  `subjective_score` double DEFAULT NULL COMMENT '主观总分',
  `subjective_score_list` text COMMENT '主观得分明细',
  `college` varchar(64) DEFAULT NULL COMMENT '学院',
  `major_name` varchar(100) DEFAULT NULL COMMENT '专业',
  `class_name` varchar(64) DEFAULT NULL COMMENT '班级',
  `teacher_id` bigint DEFAULT NULL COMMENT '任课老师ID',
  `teacher` varchar(64) DEFAULT NULL COMMENT '任课老师',
  `scan_status` varchar(20) DEFAULT NULL COMMENT '扫描状态',
  `question_filled` bit(1) DEFAULT NULL,
  `assigned` bit(1) DEFAULT NULL,
  `assign_confirmed` bit(1) DEFAULT b'0' COMMENT '人工绑定确认',
  `absent_suspect` bit(1) DEFAULT NULL,
  `incomplete` bit(1) DEFAULT NULL,
  `breach_code` varchar(32) DEFAULT NULL,
  `omr_absent` bit(1) DEFAULT NULL COMMENT '识别缺考',
  `omr_absent_checked` bit(1) DEFAULT NULL COMMENT '识别缺考检查',
  `card_number` int DEFAULT NULL,
  `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始时间',
  `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束时间',
  `create_id` bigint DEFAULT NULL COMMENT '创建人ID',
  `invalid` bit(1) DEFAULT b'0' COMMENT '强制绑定',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `index2` (`exam_id`,`secret_number`) USING BTREE,
  UNIQUE KEY `index1` (`exam_id`,`course_paper_id`,`student_code`) USING BTREE,
  KEY `index3` (`exam_id`,`course_code`,`upload_time`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考试考生库';

-- ----------------------------
-- Table structure for mark_subjective_score
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_subjective_score` (
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `main_number` int NOT NULL COMMENT '大题号',
  `sub_number` int NOT NULL COMMENT '小题号',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '课程代码',
  `group_number` int NOT NULL COMMENT '分组序号',
  `group_score` double NOT NULL COMMENT '分组得分',
  `main_score` double NOT NULL COMMENT '大题得分',
  `score` double NOT NULL COMMENT '小题得分',
  `uncalculate` tinyint(1) NOT NULL COMMENT '是否合分',
  PRIMARY KEY (`student_id`,`main_number`,`sub_number`) USING BTREE,
  KEY `index1` (`exam_id`,`paper_number`,`main_number`,`main_score`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='主观题得分明细表';

-- ----------------------------
-- Table structure for mark_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_task` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_code` varchar(32) NOT NULL COMMENT '课程代码',
  `course_name` varchar(100) NOT NULL COMMENT '课程名称',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `group_number` int NOT NULL COMMENT '大题号',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `student_code` varchar(64) NOT NULL COMMENT '学号',
  `secret_number` varchar(64) NOT NULL COMMENT '考生密号',
  `task_number` int NOT NULL COMMENT '多评任务序号',
  `status` varchar(16) NOT NULL COMMENT '状态',
  `user_id` bigint DEFAULT NULL COMMENT '评卷员ID',
  `marker_time` bigint DEFAULT NULL COMMENT '评卷时间',
  `marker_score` double DEFAULT NULL COMMENT '评卷总分',
  `marker_score_list` text COMMENT '评卷给分明细',
  `marker_spent` int DEFAULT NULL COMMENT '评卷时长',
  `header_id` bigint DEFAULT NULL COMMENT '科组长ID',
  `header_time` bigint DEFAULT NULL COMMENT '科组长评卷时间',
  `header_score` double DEFAULT NULL COMMENT '科组长总分',
  `header_score_list` text COMMENT '科组长给分明细',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `index2` (`student_id`,`group_number`,`task_number`) USING BTREE,
  KEY `index3` (`user_id`,`status`,`marker_time`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='评卷任务表';

-- ----------------------------
-- Table structure for mark_track
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_track` (
  `id` bigint NOT NULL,
  `task_id` bigint NOT NULL COMMENT '评卷任务ID',
  `question_number` varchar(128) NOT NULL COMMENT '完整题号',
  `number` int NOT NULL COMMENT '序号',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `group_number` int NOT NULL COMMENT '大题题号',
  `user_id` bigint NOT NULL COMMENT '评卷员ID',
  `type` varchar(10) DEFAULT NULL COMMENT '标记类型（SCORE：分数，REMARK：备注）',
  `score` double DEFAULT NULL COMMENT '给分',
  `remark` varchar(20) DEFAULT NULL COMMENT '备注',
  `position_x` double NOT NULL COMMENT 'X轴位置',
  `position_y` double NOT NULL COMMENT 'Y轴位置',
  `offset_index` int NOT NULL COMMENT '裁切图序号',
  `offset_x` int NOT NULL COMMENT '裁切图X轴坐标',
  `offset_y` int NOT NULL COMMENT '裁切图Y轴坐标',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `index2` (`user_id`) USING BTREE,
  KEY `index3` (`exam_id`,`paper_number`,`group_number`) USING BTREE,
  KEY `index1` (`exam_id`,`task_id`,`student_id`,`group_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='轨迹给分表';

-- ----------------------------
-- Table structure for mark_user_class
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_user_class` (
  `Id` bigint NOT NULL,
  `exam_id` bigint DEFAULT NULL COMMENT '\n考试ID',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编号',
  `user_id` bigint unsigned DEFAULT NULL COMMENT '评卷员ID',
  `class_name` varchar(100) DEFAULT NULL COMMENT '班级名称',
  PRIMARY KEY (`Id`) USING BTREE,
  KEY `idx_1` (`exam_id`,`paper_number`,`class_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='评卷员班级';

-- ----------------------------
-- Table structure for mark_user_group
-- ----------------------------
CREATE TABLE IF NOT EXISTS `mark_user_group` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) NOT NULL COMMENT '试卷编号',
  `group_number` int NOT NULL COMMENT '分组编号',
  `user_id` bigint NOT NULL COMMENT '用户ID',
  `mode` varchar(16) DEFAULT NULL COMMENT '强制评卷模式',
  `top_count` int DEFAULT NULL COMMENT '评卷数上限',
  `finish_count` int DEFAULT NULL COMMENT '完成数量',
  `header_finish_count` int DEFAULT NULL COMMENT '管理员直接打分数量',
  `valid_count` int DEFAULT NULL COMMENT '有效数量',
  `avg_score` double DEFAULT NULL COMMENT '平均分',
  `avg_speed` double DEFAULT NULL COMMENT '平均时长',
  `stdev_score` double DEFAULT NULL COMMENT '标准差',
  `max_score` double DEFAULT NULL COMMENT '最高分',
  `min_score` double DEFAULT NULL COMMENT '最低分',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `index2` (`exam_id`,`paper_number`,`group_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='评卷员表';

-- ----------------------------
-- Table structure for obe_course_dimension
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_dimension` (
  `id` bigint NOT NULL COMMENT 'id',
  `obe_course_outline_id` bigint NOT NULL COMMENT '课程大纲id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `source` varchar(20) NOT NULL COMMENT '来源',
  `code` varchar(32) NOT NULL COMMENT '知识点编号',
  `name` varchar(255) NOT NULL COMMENT '知识点名称',
  `number` int NOT NULL COMMENT '排序',
  `parent_id` bigint NOT NULL COMMENT '父id（顶级知识点父id为0）',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `course_dimension_unique` (`obe_course_outline_id`,`source`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程知识点表';

-- ----------------------------
-- Table structure for obe_course_evaluation
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_evaluation` (
  `id` bigint NOT NULL COMMENT 'id',
  `obe_course_outline_id` bigint NOT NULL COMMENT '教学课程id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `type` varchar(20) NOT NULL COMMENT '类型（默认DEFAULT、自定义CUSTOM）',
  `evaluation` varchar(255) NOT NULL COMMENT '评价方式',
  `evaluation_desc` varchar(255) DEFAULT NULL COMMENT '评价方式描述',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `course_evaluation_unique` (`obe_course_outline_id`,`evaluation`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程大纲评价方式表';

-- ----------------------------
-- Table structure for obe_course_outline
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_outline` (
  `id` bigint NOT NULL COMMENT '课程大纲表id',
  `culture_program_id` bigint NOT NULL COMMENT '培养方案id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `name` varchar(255) NOT NULL COMMENT '课程大纲名称',
  `semester_id` bigint NOT NULL COMMENT '修读学期id',
  `course_id` bigint NOT NULL,
  `evaluation_mode` varchar(32) NOT NULL COMMENT '考核方式',
  `course_type` varchar(32) NOT NULL COMMENT '课程类别',
  `user_id` bigint NOT NULL COMMENT '课程大纲责任人',
  `weight_setting` tinyint(1) DEFAULT NULL COMMENT '权重设置',
  `weight_setting_sign` bigint DEFAULT NULL COMMENT '课程权重设置标识',
  `dimension_sign` bigint DEFAULT NULL COMMENT '知识点标识',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `obe_course_outline_unique` (`culture_program_id`,`course_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程大纲表';

-- ----------------------------
-- Table structure for obe_course_requirement_dimension
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_requirement_dimension` (
  `id` bigint NOT NULL COMMENT 'id',
  `obe_course_outline_id` bigint NOT NULL COMMENT '课程大纲id',
  `obe_culture_program_requirement_id` bigint NOT NULL COMMENT '指标id',
  `obe_course_dimension_id` bigint NOT NULL COMMENT '知识点id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `obe_course_requirement_dimension_unique` (`obe_course_outline_id`,`obe_culture_program_requirement_id`,`obe_course_dimension_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程大纲指标与知识点关联表';

-- ----------------------------
-- Table structure for obe_course_requirement_matrix
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_requirement_matrix` (
  `id` bigint NOT NULL,
  `culture_program_id` bigint NOT NULL COMMENT '培养方案ID',
  `obe_course_id` bigint NOT NULL COMMENT '专业认证课程ID',
  `obe_requirement_id` bigint NOT NULL COMMENT '专业认证毕业要求ID',
  `obe_sub_requirement_id` bigint DEFAULT NULL COMMENT '子节点名称',
  `scale` double DEFAULT NULL COMMENT '指标值',
  `intensity` varchar(1) DEFAULT NULL COMMENT '强度',
  `create_id` bigint DEFAULT NULL COMMENT '创建人ID',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人ID',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='培养方案毕业要求支撑矩阵';

-- ----------------------------
-- Table structure for obe_course_requirement_report
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_requirement_report` (
  `id` bigint NOT NULL COMMENT '主键',
  `culture_program_id` bigint NOT NULL COMMENT '培养方案id',
  `requirement_radar` mediumtext NOT NULL COMMENT '毕业要求雷达报表',
  `requirement_detail` mediumtext NOT NULL COMMENT '毕业要求详情报表',
  `requirement_degree` double NOT NULL COMMENT '毕业要求达成值',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `obe_course_requirement_report_unique` (`culture_program_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程毕业要求报表';

-- ----------------------------
-- Table structure for obe_course_target
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_target` (
  `id` bigint NOT NULL COMMENT 'id',
  `obe_course_outline_id` bigint NOT NULL COMMENT '教学课程id',
  `obe_culture_program_requirement_id` bigint DEFAULT NULL COMMENT '培养方案毕业要求指标点id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `target_name` varchar(50) DEFAULT NULL COMMENT '课程目标',
  `degree_requirement` varchar(255) DEFAULT NULL COMMENT '毕业要求',
  `total_weight` decimal(6,2) DEFAULT NULL COMMENT '课程目标整体权重',
  `expect_value` double DEFAULT NULL COMMENT '预期值',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `course_target_unique` (`obe_course_outline_id`,`target_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程大纲目标表';

-- ----------------------------
-- Table structure for obe_course_weight
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_course_weight` (
  `id` bigint NOT NULL COMMENT 'id',
  `obe_course_outline_id` bigint NOT NULL COMMENT '课程大纲id',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `target_id` bigint NOT NULL COMMENT '课程目标表id',
  `evaluation_id` bigint NOT NULL COMMENT '课程评价表id',
  `enable` tinyint(1) NOT NULL DEFAULT '1' COMMENT '使用状态 1:使用 0:未使用',
  `weight` decimal(6,2) DEFAULT NULL COMMENT '权重',
  `target_score` decimal(6,2) DEFAULT NULL COMMENT '目标分值',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `course_weight_unique` (`obe_course_outline_id`,`target_id`,`evaluation_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程大纲权重设置表';

-- ----------------------------
-- Table structure for obe_culture_program
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_culture_program` (
  `id` bigint NOT NULL,
  `school_id` bigint DEFAULT NULL COMMENT '学校ID',
  `professional_id` bigint DEFAULT NULL COMMENT '专业ID',
  `name` varchar(100) DEFAULT NULL COMMENT '培养方案名称',
  `target_count` int DEFAULT '0' COMMENT '培养目标数量',
  `requirement_count` int DEFAULT '0' COMMENT '毕业要求数量',
  `course_count` int DEFAULT '0' COMMENT '课程体系数量',
  `description` mediumtext COMMENT '总体描述',
  `expect_value` double DEFAULT NULL COMMENT '期望值',
  `create_id` bigint DEFAULT NULL COMMENT '创建人ID',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人ID',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_1` (`professional_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='培养方案';

-- ----------------------------
-- Table structure for obe_culture_program_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_culture_program_course` (
  `id` bigint NOT NULL,
  `culture_program_id` bigint NOT NULL COMMENT '培养方案ID',
  `course_id` bigint DEFAULT NULL COMMENT '课程ID',
  `course_code` varchar(45) DEFAULT NULL COMMENT '课程代码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `sort_num` int DEFAULT NULL COMMENT '排序值',
  `create_id` bigint DEFAULT NULL COMMENT '创建人ID',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人ID',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `uq_professional_id` (`culture_program_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='培养方案课程体系';

-- ----------------------------
-- Table structure for obe_culture_program_requirement
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_culture_program_requirement` (
  `id` bigint NOT NULL,
  `culture_program_id` bigint NOT NULL COMMENT '培养方案ID',
  `code` varchar(45) DEFAULT NULL COMMENT '毕业要求code',
  `name` varchar(50) NOT NULL COMMENT '毕业要求',
  `content` mediumtext COMMENT '内容',
  `parent_id` bigint DEFAULT NULL COMMENT '上级毕业要求',
  `sort_num` int DEFAULT NULL COMMENT '排序值',
  `expect_value` double DEFAULT NULL COMMENT '预期值',
  `create_id` bigint DEFAULT NULL COMMENT '创建人ID',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人ID',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='培养方案毕业要求';

-- ----------------------------
-- Table structure for obe_culture_program_target
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_culture_program_target` (
  `id` bigint NOT NULL,
  `culture_program_id` bigint DEFAULT NULL COMMENT '培养方案ID',
  `name` varchar(100) DEFAULT NULL COMMENT '培养目标名称',
  `detail` varchar(2000) DEFAULT NULL COMMENT '目标拆解详情',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_1` (`culture_program_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='培养方案培养目标';

-- ----------------------------
-- Table structure for obe_requirement_target_matrix
-- ----------------------------
CREATE TABLE IF NOT EXISTS `obe_requirement_target_matrix` (
  `id` bigint NOT NULL,
  `culture_program_id` bigint DEFAULT NULL COMMENT '培养方案ID',
  `obe_requirement_id` bigint DEFAULT NULL COMMENT '毕业要求ID',
  `obe_target_id` bigint DEFAULT NULL COMMENT '培养目标ID',
  `enable` tinyint(1) DEFAULT NULL COMMENT '是否包含',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_id` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='培养目标与毕业要求关系矩阵';

-- ----------------------------
-- Table structure for qrtz_blob_triggers
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_blob_triggers` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `TRIGGER_NAME` varchar(200) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  `BLOB_DATA` blob,
  PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
  KEY `SCHED_NAME` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_calendars
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_calendars` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `CALENDAR_NAME` varchar(200) NOT NULL,
  `CALENDAR` blob NOT NULL,
  PRIMARY KEY (`SCHED_NAME`,`CALENDAR_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_cron_triggers
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_cron_triggers` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `TRIGGER_NAME` varchar(200) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  `CRON_EXPRESSION` varchar(120) NOT NULL,
  `TIME_ZONE_ID` varchar(80) DEFAULT NULL,
  PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_fired_triggers
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_fired_triggers` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `ENTRY_ID` varchar(95) NOT NULL,
  `TRIGGER_NAME` varchar(200) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  `INSTANCE_NAME` varchar(200) NOT NULL,
  `FIRED_TIME` bigint NOT NULL,
  `SCHED_TIME` bigint NOT NULL,
  `PRIORITY` int NOT NULL,
  `STATE` varchar(16) NOT NULL,
  `JOB_NAME` varchar(200) DEFAULT NULL,
  `JOB_GROUP` varchar(200) DEFAULT NULL,
  `IS_NONCONCURRENT` varchar(1) DEFAULT NULL,
  `REQUESTS_RECOVERY` varchar(1) DEFAULT NULL,
  PRIMARY KEY (`SCHED_NAME`,`ENTRY_ID`) USING BTREE,
  KEY `IDX_QRTZ_FT_TRIG_INST_NAME` (`SCHED_NAME`,`INSTANCE_NAME`) USING BTREE,
  KEY `IDX_QRTZ_FT_INST_JOB_REQ_RCVRY` (`SCHED_NAME`,`INSTANCE_NAME`,`REQUESTS_RECOVERY`) USING BTREE,
  KEY `IDX_QRTZ_FT_J_G` (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_FT_JG` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_FT_T_G` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_FT_TG` (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_job_details
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_job_details` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `JOB_NAME` varchar(200) NOT NULL,
  `JOB_GROUP` varchar(200) NOT NULL,
  `DESCRIPTION` varchar(250) DEFAULT NULL,
  `JOB_CLASS_NAME` varchar(250) NOT NULL,
  `IS_DURABLE` varchar(1) NOT NULL,
  `IS_NONCONCURRENT` varchar(1) NOT NULL,
  `IS_UPDATE_DATA` varchar(1) NOT NULL,
  `REQUESTS_RECOVERY` varchar(1) NOT NULL,
  `JOB_DATA` blob,
  PRIMARY KEY (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_J_REQ_RECOVERY` (`SCHED_NAME`,`REQUESTS_RECOVERY`) USING BTREE,
  KEY `IDX_QRTZ_J_GRP` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_locks
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_locks` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `LOCK_NAME` varchar(40) NOT NULL,
  PRIMARY KEY (`SCHED_NAME`,`LOCK_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_paused_trigger_grps
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_paused_trigger_grps` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  PRIMARY KEY (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_scheduler_state
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_scheduler_state` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `INSTANCE_NAME` varchar(200) NOT NULL,
  `LAST_CHECKIN_TIME` bigint NOT NULL,
  `CHECKIN_INTERVAL` bigint NOT NULL,
  PRIMARY KEY (`SCHED_NAME`,`INSTANCE_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_simple_triggers
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_simple_triggers` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `TRIGGER_NAME` varchar(200) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  `REPEAT_COUNT` bigint NOT NULL,
  `REPEAT_INTERVAL` bigint NOT NULL,
  `TIMES_TRIGGERED` bigint NOT NULL,
  PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_simprop_triggers
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_simprop_triggers` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `TRIGGER_NAME` varchar(200) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  `STR_PROP_1` varchar(512) DEFAULT NULL,
  `STR_PROP_2` varchar(512) DEFAULT NULL,
  `STR_PROP_3` varchar(512) DEFAULT NULL,
  `INT_PROP_1` int DEFAULT NULL,
  `INT_PROP_2` int DEFAULT NULL,
  `LONG_PROP_1` bigint DEFAULT NULL,
  `LONG_PROP_2` bigint DEFAULT NULL,
  `DEC_PROP_1` decimal(13,4) DEFAULT NULL,
  `DEC_PROP_2` decimal(13,4) DEFAULT NULL,
  `BOOL_PROP_1` varchar(1) DEFAULT NULL,
  `BOOL_PROP_2` varchar(1) DEFAULT NULL,
  PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_triggers
-- ----------------------------
CREATE TABLE IF NOT EXISTS `qrtz_triggers` (
  `SCHED_NAME` varchar(120) NOT NULL,
  `TRIGGER_NAME` varchar(200) NOT NULL,
  `TRIGGER_GROUP` varchar(200) NOT NULL,
  `JOB_NAME` varchar(200) NOT NULL,
  `JOB_GROUP` varchar(200) NOT NULL,
  `DESCRIPTION` varchar(250) DEFAULT NULL,
  `NEXT_FIRE_TIME` bigint DEFAULT NULL,
  `PREV_FIRE_TIME` bigint DEFAULT NULL,
  `PRIORITY` int DEFAULT NULL,
  `TRIGGER_STATE` varchar(16) NOT NULL,
  `TRIGGER_TYPE` varchar(8) NOT NULL,
  `START_TIME` bigint NOT NULL,
  `END_TIME` bigint DEFAULT NULL,
  `CALENDAR_NAME` varchar(200) DEFAULT NULL,
  `MISFIRE_INSTR` smallint DEFAULT NULL,
  `JOB_DATA` blob,
  PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_T_J` (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_T_JG` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_T_C` (`SCHED_NAME`,`CALENDAR_NAME`) USING BTREE,
  KEY `IDX_QRTZ_T_G` (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE,
  KEY `IDX_QRTZ_T_STATE` (`SCHED_NAME`,`TRIGGER_STATE`) USING BTREE,
  KEY `IDX_QRTZ_T_N_STATE` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE,
  KEY `IDX_QRTZ_T_N_G_STATE` (`SCHED_NAME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE,
  KEY `IDX_QRTZ_T_NEXT_FIRE_TIME` (`SCHED_NAME`,`NEXT_FIRE_TIME`) USING BTREE,
  KEY `IDX_QRTZ_T_NFT_ST` (`SCHED_NAME`,`TRIGGER_STATE`,`NEXT_FIRE_TIME`) USING BTREE,
  KEY `IDX_QRTZ_T_NFT_MISFIRE` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`) USING BTREE,
  KEY `IDX_QRTZ_T_NFT_ST_MISFIRE` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`,`TRIGGER_STATE`) USING BTREE,
  KEY `IDX_QRTZ_T_NFT_ST_MISFIRE_GRP` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_answer_card
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_answer_card` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '科目代码',
  `course_paper_id` varchar(50) NOT NULL COMMENT '试卷编号（交互）',
  `paper_type` varchar(100) NOT NULL COMMENT '试卷编号',
  `card_id` bigint DEFAULT NULL COMMENT '知学知考题卡ID（自定义卡格式为空）',
  `number` int NOT NULL COMMENT '序号',
  `source` varchar(16) NOT NULL COMMENT '来源',
  `uri` varchar(500) DEFAULT NULL COMMENT '卡格式文件路径',
  `md5` varchar(255) DEFAULT NULL COMMENT '文件md5',
  `parameter` varchar(255) DEFAULT NULL COMMENT '其他属性',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `need_adapte` tinyint DEFAULT NULL COMMENT '是否需要适配',
  `paper_count` int DEFAULT NULL,
  `single_page` tinyint(1) DEFAULT NULL,
  `slice_config` text COMMENT '裁切配置',
  `dpi` int DEFAULT NULL COMMENT 'dpi',
  `code` varchar(64) DEFAULT NULL COMMENT '混扫代码',
  `adapte_md5` varchar(32) DEFAULT NULL COMMENT '适配后文件md5',
  `adapte_uri` varchar(500) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `idx_1` (`exam_id`,`number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡卡格式表';

-- ----------------------------
-- Table structure for scan_answer_card_subject
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_answer_card_subject` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `card_number` int NOT NULL COMMENT '卡格式号',
  `paper_number` varchar(255) NOT NULL COMMENT '试卷编号',
  `course_paper_id` varchar(50) NOT NULL COMMENT '试卷编号（交互）',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `index1` (`exam_id`,`card_number`,`paper_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='卡格式科目关联关系';

-- ----------------------------
-- Table structure for scan_batch
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_batch` (
  `id` bigint NOT NULL AUTO_INCREMENT,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `user_id` bigint NOT NULL COMMENT '扫描员ID',
  `scan_count` int NOT NULL COMMENT '扫描数量',
  `assigned_count` int NOT NULL,
  `status` varchar(16) NOT NULL COMMENT '状态',
  `creator_id` bigint DEFAULT NULL,
  `updater_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  `course_paper_id` varchar(64) DEFAULT NULL COMMENT '试卷编号',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `exam_verify_status` (`exam_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_batch_paper
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_batch_paper` (
  `batch_id` bigint NOT NULL COMMENT '批次ID',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `paper_index` int NOT NULL COMMENT '试卷页数',
  `paper_id` bigint NOT NULL COMMENT '试卷ID',
  `card_number` int NOT NULL COMMENT '题卡编号',
  `assigned` bit(1) NOT NULL,
  PRIMARY KEY (`batch_id`,`student_id`,`paper_index`) USING BTREE,
  UNIQUE KEY `paper_id` (`paper_id`) USING BTREE,
  UNIQUE KEY `paper_id_2` (`paper_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_file_property
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_file_property` (
  `path` varchar(255) NOT NULL COMMENT '文件路径',
  `md5` varchar(32) NOT NULL COMMENT '文件md5',
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `file_size` bigint NOT NULL COMMENT '文件大小',
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`path`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_log` (
  `school_code` varchar(20) NOT NULL COMMENT '学校代码',
  `device_code` varchar(50) NOT NULL COMMENT '设备号',
  `file_name` varchar(45) NOT NULL,
  `type` varchar(10) DEFAULT NULL COMMENT '错误文件类型，崩溃异常文件：COLLAPSE，正常文件：NORMAL',
  `md5` varchar(45) NOT NULL COMMENT '扫描端日志',
  `path` varchar(500) DEFAULT NULL,
  `login_name` varchar(45) DEFAULT NULL COMMENT '扫描账号',
  `upload_time` bigint DEFAULT NULL,
  PRIMARY KEY (`school_code`,`device_code`,`file_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_omr_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_omr_task` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `conditions` varchar(100) NOT NULL COMMENT '条件',
  `student_id` bigint NOT NULL COMMENT '考生ID',
  `paper_index` int NOT NULL COMMENT '试卷页数',
  `paper_id` bigint NOT NULL COMMENT '试卷ID',
  `card_number` int NOT NULL COMMENT '题卡编号',
  `status` varchar(16) NOT NULL COMMENT '状态',
  `user_id` bigint DEFAULT NULL,
  `pages` text NOT NULL,
  `creator_id` bigint DEFAULT NULL,
  `updater_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  KEY `exam_status` (`exam_id`,`status`,`student_id`) USING BTREE,
  KEY `group_paper` (`conditions`,`paper_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_package
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_package` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `course_paper_id` varchar(30) DEFAULT NULL COMMENT '试卷编号',
  `package_code` varchar(20) DEFAULT NULL COMMENT '卷袋编号',
  `package_no` int DEFAULT NULL COMMENT '页码',
  `path` varchar(255) NOT NULL COMMENT '签到表图片路径',
  `md5` varchar(32) NOT NULL COMMENT '文件md5',
  `assigned` bit(1) DEFAULT NULL,
  `creator_id` bigint DEFAULT NULL,
  `updater_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  KEY `exam` (`exam_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_paper
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_paper` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL COMMENT '考试ID',
  `card_number` int NOT NULL COMMENT '卡格式编号',
  `number` int NOT NULL COMMENT '题卡编号（对应paper_index）',
  `page_count` int NOT NULL COMMENT '数量',
  `mismatch` bit(1) NOT NULL,
  `assigned` bit(1) NOT NULL,
  `question_filled` bit(1) NOT NULL,
  `checked` varchar(45) DEFAULT NULL COMMENT '已检查',
  `creator_id` bigint DEFAULT NULL,
  `updater_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  `assign_confirmed` bit(1) DEFAULT NULL COMMENT '人工绑定确认',
  `invalid` bit(1) DEFAULT b'0' COMMENT '强制绑定',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `mismatch` (`exam_id`,`mismatch`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_paper_page
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_paper_page` (
  `id` bigint DEFAULT NULL,
  `paper_id` bigint NOT NULL,
  `page_index` int NOT NULL,
  `absent` text,
  `breach` text,
  `question` text,
  `selective` text,
  `sheet_path` varchar(1000) NOT NULL,
  `recog_data` longtext,
  `creator_id` bigint DEFAULT NULL,
  `updater_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`paper_id`,`page_index`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_refix_batch
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_refix_batch` (
  `id` bigint NOT NULL,
  `exam_id` bigint NOT NULL,
  `card_number` int NOT NULL,
  `conditions` text NOT NULL,
  `update_slice` bit(1) NOT NULL,
  `total_count` int NOT NULL,
  `sucess_count` int NOT NULL,
  `finished` bit(1) NOT NULL,
  `creator_id` bigint DEFAULT NULL,
  `updater_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for scan_student_paper
-- ----------------------------
CREATE TABLE IF NOT EXISTS `scan_student_paper` (
  `id` bigint NOT NULL,
  `student_id` bigint NOT NULL,
  `paper_index` int NOT NULL,
  `paper_id` bigint NOT NULL,
  `create_time` bigint DEFAULT NULL,
  `update_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `paper_id` (`paper_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for sys_config
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_config` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `config_key` varchar(100) NOT NULL COMMENT '参数键名',
  `config_name` varchar(100) NOT NULL COMMENT '参数名称',
  `config_value` varchar(100) DEFAULT NULL COMMENT '参数键值',
  `remark` varchar(100) DEFAULT NULL COMMENT '备注',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `sort` int DEFAULT '1' COMMENT '排序',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='参数表';

-- ----------------------------
-- Records of sys_config
-- ----------------------------
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (1, NULL, NULL, 'sys.user.initPassword', '初始密码', '123456', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (2, NULL, NULL, 'sys.warning.days', '预警天数', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (3, NULL, NULL, 'sys.code.enable', '是否启用短信验证码', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (4, NULL, NULL, 'sys.message.enable', '是否启用短信消息提示', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (5, NULL, NULL, 'sys.message.resendCount', '失败短信重试次数', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (6, NULL, NULL, 'sys.sync.enable', '是否开启数据同步云阅卷', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (8, NULL, NULL, 'sys.pdf.size.list', '全局pdf格式清单', '[A3, A4, A5, B3, B4, B5, 8K]', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (9, NULL, NULL, 'admin.logo.url', '超级管理员logo', 'http://qmth-test.oss-cn-shenzhen.aliyuncs.com/frontend/wx_logo.png', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (10, NULL, NULL, 'attachment.type', '附件类型', '[.xlsx,.xls,.doc,.docx,.pdf,.jpg,.jpeg,.png,.html,.zip,.mp3,.wav,.dll,.exe,.ftl,.bpmn,.xml]', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (11, NULL, NULL, 'attachment.length', '附件名称长度', '100', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (12, NULL, NULL, 'attachment.size', '附件大小 ', '200', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (13, NULL, NULL, 'auto.create.pdf.reset.max.count', '自动重试生成pdf失败最大次数', '5', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (14, NULL, NULL, 'thread.pool.core.size', '自定义线程池大小', '500', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (15, NULL, NULL, 'custom.thread.pool.core.size', '是否自定义线程池大小', 'true', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (16, NULL, NULL, 'session.active', 'session会话时长', '4h', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (18, NULL, NULL, 'sms.normal.code', '万能短信验证码', 'qmth', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (19, NULL, NULL, 'code.expired.time', '短信验证码有效时间', '2', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (20, NULL, NULL, 'code.send.interval', '短信验证码发送间隔', '60', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (21, NULL, NULL, 'teachcloud.print.open.callback.pwd', '分布式印刷回调密码', 'qmth87863577-offline', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (24, NULL, NULL, 'sms.sign.name', '短信签名', '知学知考', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (25, NULL, NULL, 'sms.tpl.code', '登录短信验证码', 'SMS_147416565', NULL, 1, 2, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (26, NULL, NULL, 'sms.audit.pass.code', '命题任务审核通过', 'SMS_216425141', NULL, 1, 3, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (27, NULL, NULL, 'sms.audit.not.pass.code', '命题任务审核不通过', 'SMS_216275156', NULL, 1, 4, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (28, NULL, NULL, 'sms.exam.task.create.code', '命题任务待办生成通知', 'SMS_217436292', NULL, 1, 5, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (29, NULL, NULL, 'sms.exam.task.will.expire.code', '命题任务待办到期预警通知', 'SMS_217436295', NULL, 1, 6, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (30, NULL, NULL, 'sms.exam.task.overdue.code', '命题任务待办逾期通知', 'SMS_217426313', NULL, 1, 7, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (31, NULL, NULL, 'sms.allocation.will.expire.code', '命题分配待办到期预警通知', 'SMS_217406305', NULL, 1, 8, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (32, NULL, NULL, 'sms.allocation.overdue.code', '命题分配待办逾期通知', 'SMS_217406308', NULL, 1, 9, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (33, NULL, NULL, 'sms.audit.create.code', '审核待办生成通知', 'SMS_237216000', NULL, 1, 10, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (34, NULL, NULL, 'sms.audit.review.code', '审核待办修改申请通知', 'SMS_237216002', NULL, 1, 11, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (35, NULL, NULL, 'sms.audit.will.expire.code', '审核待办到期预警通知', 'SMS_217436302', NULL, 1, 12, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (36, NULL, NULL, 'sms.audit.overdue.code', '审核待办逾期通知', 'SMS_217416271', NULL, 1, 13, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (37, NULL, NULL, 'sms.audit.reject.code', '审核驳回通知', 'SMS_237206063', NULL, 1, 14, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (38, NULL, NULL, 'sms.upload.structure.code', '试卷结构推送通知', 'SMS_237201068', NULL, 1, 15, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (39, NULL, NULL, 'sms.audit.copy.user.code', '用户', 'SMS_237206065', NULL, 1, 16, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (40, NULL, NULL, 'sys.txt.charset', 'txt文件编码', 'UTF-8', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` (`id`, `school_id`, `org_id`, `config_key`, `config_name`, `config_value`, `remark`, `enable`, `sort`, `create_id`, `create_time`, `update_id`, `update_time`) VALUES (41, NULL, NULL, 'package.barcode.position', '签到表条码坐标', '[0.7,0,0.3,0.1]', NULL, 1, 17, 1, NULL, NULL, NULL);

-- ----------------------------
-- Table structure for sys_org
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_org` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `type` varchar(50) DEFAULT NULL COMMENT '类型，SCHOOL：学校，COLLEGE：学院，FACULTY：院系，TEACHING_ROOM：教研室，PRINTING_HOUSE：印刷厂',
  `code` varchar(20) DEFAULT NULL COMMENT '机构代码',
  `name` varchar(100) NOT NULL COMMENT '机构名称',
  `parent_id` bigint DEFAULT NULL COMMENT '上级机构id',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '修改人',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `historic_name` varchar(100) DEFAULT NULL COMMENT '历史机构名称',
  `third_relate_id` int DEFAULT NULL COMMENT '云阅卷机构ID',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `org_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校组织架构';

-- ----------------------------
-- Table structure for sys_privilege
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_privilege` (
  `id` bigint NOT NULL COMMENT '主键',
  `name` varchar(100) NOT NULL COMMENT '菜单名称',
  `url` varchar(100) NOT NULL COMMENT 'URL地址',
  `type` varchar(50) NOT NULL COMMENT '类型，MENU：菜单，BUTTON：按钮，LINK：链接，URL：接口地址，LIST：列表，CONDITION：查询条件，TAB：选项卡',
  `parent_id` bigint DEFAULT NULL COMMENT '上级菜单',
  `sequence` int NOT NULL COMMENT '序号',
  `property` varchar(30) DEFAULT NULL COMMENT '属性，NO_AUTH：无需鉴权，AUTH：鉴权，SYS：系统公用',
  `related` text COMMENT '关联属性，type为URL且property为AUTH才有',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `default_auth` tinyint DEFAULT '1' COMMENT '默认权限，0：否，1：是',
  `front_display` tinyint(1) DEFAULT '1' COMMENT '是否前端展示',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='菜单权限表';

-- ----------------------------
-- Records of sys_privilege
-- ----------------------------
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1, '基础配置', 'base', 'MENU', NULL, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2, '用户管理', 'user', 'MENU', 1, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3, '配置管理', 'rule', 'MENU', 1, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (4, '组织架构', 'OrganizationManage', 'MENU', 2, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (5, '用户管理', 'UserManage', 'MENU', 2, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (6, '角色管理', 'RoleManage', 'MENU', 2, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (7, '权限管理', 'MenuManage', 'MENU', 129, 6, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (8, '通用规则', 'CommonRule', 'MENU', 3, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (9, '题卡规则管理', 'CardRuleManage', 'MENU', 3, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (11, '印品管理', 'PrintTemplateManage', 'MENU', 3, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (13, '课程管理', 'CourseManage', 'MENU', 356, 7, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (14, '考试中心', 'exam', 'MENU', NULL, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (38, '印刷管理', 'print', 'MENU', 14, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (39, '命题任务管理', 'ExamTaskManage', 'MENU', 652, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (40, '入库申请', 'TaskApplyManage', 'MENU', 652, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (41, '入库审核', 'TaskReviewManage', 'MENU', 652, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (42, '卷库查询', 'TaskPaperManage', 'MENU', 652, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (43, '印刷计划管理', 'PrintPlanManage', 'MENU', 38, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (44, '考务数据导入', 'BusinessDataExport', 'MENU', 38, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (45, '考务明细查询', 'BusinessDataDetail', 'MENU', 38, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (47, '印刷任务管理', 'PrintTaskManage', 'MENU', 38, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (48, '查询', '/api/admin/exam/print/list', 'URL', 43, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (49, '按类型查询模板', '/api/admin/exam/print/get_template', 'URL', 43, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (50, '新增/修改', '/api/admin/exam/print/save', 'URL', 43, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (51, '删除', '/api/admin/exam/print/remove', 'URL', 43, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (52, '查询', '/api/admin/exam/print/data_list', 'URL', 44, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (53, '汇总数据查询', '/api/admin/exam/print/data_total', 'URL', 44, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (54, '导入', '/api/admin/exam/print/data_import', 'URL', 44, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (55, '查看明细', '/api/admin/exam/print/data_detail_list', 'URL', 44, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (56, '查询', '/api/admin/exam/print/relate_list', 'URL', 43, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (57, '关联/更换试卷', '/api/admin/exam/print/relate_update', 'URL', 43, 2, 'AUTH', '58', 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (58, '查询所有试卷编号/关联卷型', '/api/admin/exam/print/relate_get_paper_numbers', 'URL', 43, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (59, '查询', '/api/admin/exam/print/task_list', 'URL', 47, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (60, '提交印刷', '/api/admin/exam/print/task_submit', 'URL', 47, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (61, '撤回提交', '/api/admin/exam/print/task_cancel', 'URL', 47, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (62, '汇总数据查询', '/api/admin/exam/print/task_total_data', 'URL', 47, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (63, '查询', '/api/admin/exam/task/list', 'URL', 39, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (64, '更改/指派命题老师', '/api/admin/exam/task/assign_user', 'URL', 39, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (65, '启用/禁用', '/api/admin/exam/task/enable', 'URL', 39, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (66, '新建', '/api/admin/exam/task/save', 'URL', 39, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (67, '批量新建-文件导入', '/api/admin/exam/task/import', 'URL', 39, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (68, '批量新建', '/api/admin/exam/task/save_batch', 'URL', 39, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (69, '审核历史', '/api/admin/exam/task/review_list', 'URL', 39, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (70, '查询', '/api/admin/exam/task/apply_list', 'URL', 40, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (71, '提交/暂存', '/api/admin/exam/task/apply_save', 'URL', 40, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (72, '撤回/重新申请', '/api/admin/exam/task/apply_status', 'URL', 40, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (73, '查询未审核', '/api/admin/exam/task/review_list_unaudited', 'URL', 41, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (74, '审核', '/api/admin/exam/task/review_save', 'URL', 41, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (75, '批量审核', '/api/admin/exam/task/review_save_batch', 'URL', 41, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (76, '查询', '/api/admin/exam/task/paper_list', 'URL', 42, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (77, '查询', '/api/admin/sys/user/list', 'URL', 5, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (78, '新增/修改', '/api/admin/sys/user/save', 'URL', 5, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (79, '启用/禁用', '/api/admin/sys/user/enable', 'URL', 5, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (80, '重置密码', '/api/admin/sys/user/reset_password', 'URL', 5, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (81, '导入', '/api/admin/sys/user/import', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (82, '绑定角色', '/api/admin/sys/user/bind_roles', 'URL', 5, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (83, '查询', '/api/admin/sys/role/list', 'URL', 6, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (84, '删除', '/api/admin/sys/role/remove', 'URL', 6, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (85, '新增/修改', '/api/admin/sys/role/save', 'URL', 6, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (86, '启用/禁用', '/api/admin/sys/role/enable', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (87, '用户已绑定角色列表', '/api/admin/sys/role/get_user_roles', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (88, '查询', '/api/admin/sys/privilege/list', 'URL', 7, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (89, '新增/修改', '/api/admin/sys/privilege/save', 'URL', 7, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (90, '删除', '/api/admin/sys/privilege/remove', 'URL', 7, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (91, '角色已绑定权限列表', '/api/admin/sys/privilege/get_role_privileges', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (92, '组织机构-查询', '/api/admin/sys/org/list', 'URL', 4, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (93, '组织机构-新增/修改', '/api/admin/sys/org/save', 'URL', 4, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (94, '组织机构-删除', '/api/admin/sys/org/remove', 'URL', 4, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (95, '组织机构-启用/禁用', '/api/admin/sys/org/enable', 'URL', 4, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (96, '查询', '/api/admin/basic/course/list', 'URL', 13, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (97, '新增/修改', '/api/admin/basic/course/save', 'URL', 13, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (98, '删除', '/api/admin/basic/course/remove', 'URL', 13, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (99, '查询', '/api/admin/basic/exam_rule/list', 'URL', 8, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (100, '新增/修改', '/api/admin/basic/exam_rule/save', 'URL', 8, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (101, '查询', '/api/admin/basic/card_rule/list', 'URL', 9, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (102, '查询单个', '/api/admin/basic/card_rule/get_one', 'URL', 9, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (103, '新增/修改', '/api/admin/basic/card_rule/save', 'URL', 9, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (104, '删除', '/api/admin/basic/card_rule/delete', 'URL', 9, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (105, '查询-汇总数据', '/api/admin/exam/print/relate_total', 'URL', 43, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (112, '系统设置', 'data', 'MENU', 1, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (113, '任务管理', 'DataTaskManage', 'MENU', 112, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (114, '查询', '/api/admin/data/task/query', 'URL', 113, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (115, 'PDF生成管理', 'PdfBuildManage', 'MENU', 112, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (116, '查询', 'Select', 'BUTTON', 115, 1, 'AUTH', '127', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (117, '命题待办接口', '/api/admin/work/exam/task/ready', 'URL', 16, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (118, '命题待办计数接口', '/api/admin/work/exam/task/ready_count', 'URL', 16, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (119, '命题分配待办接口', '/api/admin/work/exam/task/new', 'URL', 16, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (120, '命题分配待办计数接口', '/api/admin/work/exam/task/new_count', 'URL', 16, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (121, '审核待办接口', '/api/admin/work/exam/task/submit', 'URL', 16, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (122, '审核待办计数接口', '/api/admin/work/exam/task/submit_count', 'URL', 16, 6, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (123, '查询', '/api/admin/basic/template/list', 'URL', 11, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (124, '新增/修改', '/api/admin/basic/template/save', 'URL', 11, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (125, '启用/禁用', '/api/admin/basic/template/enable', 'URL', 11, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (126, '查询条件', 'Condition', 'CONDITION', 115, 1, 'AUTH', '127', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (127, '查询', '/api/admin/data/task/page_pdf_create', 'URL', 115, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (128, '列表', 'List', 'LIST', 115, 2, 'AUTH', '127', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (129, '公共接口', 'common', 'MENU', NULL, 12, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (130, '用户登录相关', 'login', 'MENU', 129, 1, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (131, '用户登录', '/api/admin/common/login', 'URL', 130, 1, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (132, '查询用户权限', '/api/admin/common/get_menu', 'URL', 130, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (133, '发送验证码', '/api/admin/common/get_verify_code', 'URL', 130, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (134, '修改密码', '/api/admin/sys/user/update_password', 'URL', 130, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (135, '用户登出', '/api/admin/common/logout', 'URL', 130, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (136, '模糊查询', 'query', 'MENU', 129, 2, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (137, '模糊查询-印刷计划', '/api/admin/exam/print/query', 'URL', 136, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (138, '题卡规则', '/api/admin/basic/card_rule/query', 'URL', 136, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (139, '模糊查询-课程', '/api/admin/basic/course/query', 'URL', 136, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (140, '模糊查询-试卷编号', '/api/admin/exam/task/paper_number_query', 'URL', 136, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (141, '模糊查询-命题老师', '/api/admin/exam/task/user_query', 'URL', 136, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (142, '模糊查询-考点', '/api/admin/exam/print/data_place_query', 'URL', 136, 6, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (143, '模糊查询-考场', '/api/admin/exam/print/data_room_query', 'URL', 136, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (144, '文件相关', 'file', 'MENU', 129, 3, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (145, '文件上传', '/api/admin/common/file/upload', 'URL', 144, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (146, '文件查询', '/api/admin/common/file/get_one', 'URL', 144, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (147, '文件下载', '/api/admin/common/file/download', 'URL', 144, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (148, '文件预览', '/api/admin/common/file/preview', 'URL', 144, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (149, '系统相关', 'sys', 'MENU', 129, 4, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (150, '查询枚举类型', '/api/admin/common/get_enums', 'URL', 149, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (151, '查询学校列表', '/api/admin/common/school/list', 'URL', 149, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (152, '查询系统参数', '/api/admin/common/sys_config/get_one', 'URL', 149, 3, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (153, '根据学校代码查询学校信息', '/api/admin/common/school/query_by_school_code', 'URL', 149, 4, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (154, '其他', 'other', 'MENU', 129, 5, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (155, '用户导入（异步）', '/api/admin/sys/user/async/import', 'URL', 154, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (156, '用户导出', '/api/admin/sys/user/export', 'URL', 154, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (157, '模板下载', '/api/admin/exam/print/template_download', 'URL', 44, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (158, '结果导出', '/api/admin/exam/print/data_export', 'URL', 44, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (159, '查询', '/api/admin/exam/print/data_detail', 'URL', 45, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (160, '重新提交印刷', '/api/admin/exam/print/task_resubmit', 'URL', 47, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (161, '查看PDF', '/api/admin/exam/print/task_view_pdf', 'URL', 47, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (162, '批量下载PDF', '/api/admin/exam/print/task_download_pdf', 'URL', 47, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (163, '导出审核样本', '/api/admin/exam/task/review_export', 'URL', 41, 4, 'AUTH', NULL, 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (164, '下载试卷', '/api/admin/exam/task/paper_download', 'URL', 42, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (165, '试卷启用/禁用', '/api/admin/exam/task/paper_enable', 'URL', 42, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (166, '查询已审核', '/api/admin/exam/task/review_list_audited', 'URL', 41, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (167, '查询可选择题卡', '/api/admin/exam/card/select_card_list', 'URL', 40, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (168, '查询申请详情', '/api/admin/exam/task/apply_get_one', 'URL', 40, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (169, '根据课程查询命题老师', '/api/admin/sys/user/user_list', 'URL', 39, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (170, '客服制卡', 'customer', 'MENU', NULL, 9, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (171, '客服制卡', 'customerManage', 'MENU', 170, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (172, '题卡审核', 'CustomerCard', 'MENU', 171, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (173, '客服制卡-查询', '/api/admin/exam/card/cust_list', 'URL', 172, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (174, '导入模板下载', '/api/admin/common/download_import_template', 'URL', 149, 15, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (175, '题卡管理', 'card', 'MENU', NULL, 10, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (176, '查询题卡规则', '/api/admin/basic/card_rule/get_one', 'URL', 175, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (177, '查询题卡详情', '/api/admin/exam/card/get_one', 'URL', 175, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (178, '保存/提交', '/api/admin/exam/card/save', 'URL', 175, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (179, '查询考务规则', '/api/admin/basic/exam_rule/list', 'URL', 149, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (180, '查询可设置权限列表', '/api/admin/sys/privilege/list_auth', 'URL', 6, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (181, '超管中心', 'admin', 'MENU', 129, 7, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (182, '查询客服', '/api/admin/sys/user/list_customer', 'URL', 181, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (183, '新增客服', '/api/admin/sys/user/save_customer', 'URL', 181, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (184, '查询用户可绑定角色', '/api/admin/sys/role/list_to_user', 'URL', 5, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (185, '客服制卡-批量下载文件', '/api/admin/exam/card/download_files', 'URL', 172, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (186, '查看印品', '/api/admin/exam/print/template_view', 'URL', 47, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (187, '客户端登录', '/api/admin/client/user/login', 'URL', NULL, 1, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (188, '学生明细', '/api/admin/exam/print/get_student_detail', 'URL', 45, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (189, '修改', '/api/admin/exam/task/paper_update', 'URL', 42, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (190, '重新生成pdf', '/api/admin/data/task/reset_create_pdf', 'URL', 115, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (191, '批量下载试卷PDF、题卡', '/api/admin/exam/task/paper_card_download_pdf', 'URL', 42, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (192, '预览', '/api/admin/basic/template/read_content', 'URL', 11, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (193, '补考任务查询', '/api/admin/exam/print/list_makeup_task', 'URL', 43, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (194, '补考任务保存', '/api/admin/exam/print/save_makeup_task', 'URL', 43, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (195, '获取服务器时间', '/api/admin/common/get_system_time', 'URL', 129, 2, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (198, '数据同步', '/api/admin/exam/print/sync_data_cloud', 'URL', 47, 9, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (199, '打印端', 'client', 'MENU', NULL, 11, NULL, '200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,241,973,974,975', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (200, '试卷打样-查询列表', '/api/admin/client/paper_try/list', 'URL', 199, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (201, '试卷打样-查看/试印/重印', '/api/admin/client/paper_try/print', 'URL', 199, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (202, '试卷打样-批量试印', '/api/admin/client/paper_try/print_batch', 'URL', 199, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (203, '试卷打样-标记合格状态', '/api/admin/client/paper_try/tag_pass', 'URL', 199, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (204, '查询列表', '/api/admin/client/print/task_list', 'URL', 199, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (205, '导出', '/api/admin/client/print/task_list_export', 'URL', 199, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (206, '汇总数据查询', '/api/admin/client/print/task_total_data', 'URL', 199, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (207, '查看', '/api/admin/client/print/preview', 'URL', 199, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (208, '印刷/缓存数据', '/api/admin/client/print/get_print_data', 'URL', 199, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (209, '批量缓存', '/api/admin/client/print/get_print_data_batch', 'URL', 199, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (210, '缓存后更新状态', '/api/admin/client/print/update_download', 'URL', 199, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (211, '校验', '/api/admin/client/print/validate_data', 'URL', 199, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (212, '更新打印进度', '/api/admin/client/print/update_progress', 'URL', 199, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (213, '重打-查询考生列表', '/api/admin/client/print/list_student', 'URL', 199, 15, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (214, '重打-内容查询', '/api/admin/client/print/get_reprint_data', 'URL', 199, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (215, '统计查询-查询列表', '/api/admin/client/print/statistics_list', 'URL', 199, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (216, '统计查询-汇总数据查询', '/api/admin/client/print/statistics_total_data', 'URL', 199, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (217, '查询', 'Select', 'BUTTON', 5, 1, 'AUTH', '77', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (218, '新增', 'Add', 'BUTTON', 5, 2, 'AUTH', '78', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (219, '编辑', 'Edit', 'LINK', 5, 1, 'AUTH', '78', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (220, '启用/禁用', 'Enable', 'LINK', 5, 2, 'AUTH', '79', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (221, '列表', 'List', 'LIST', 5, 1, 'AUTH', '77', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (222, '查询条件', 'Condition', 'CONDITION', 5, 1, 'AUTH', '184,87', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (223, '重置密码', 'Reset', 'LINK', 5, 3, 'AUTH', '80', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (224, '新增', 'Add', 'BUTTON', 4, 1, 'AUTH', '93', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (225, '子部门', 'Add', 'LINK', 4, 1, 'AUTH', '93', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (226, '编辑', 'Edit', 'LINK', 4, 2, 'AUTH', '93', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (227, '删除', 'Delete', 'LINK', 4, 3, 'AUTH', '94', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (228, '树形列表', 'List', 'LIST', 4, 1, 'AUTH', '92', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (229, '查询', 'Select', 'BUTTON', 6, 1, 'AUTH', '83,88', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (230, '新增', 'Add', 'BUTTON', 6, 2, 'AUTH', '85,89', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (231, '编辑', 'Edit', 'LINK', 6, 1, 'AUTH', '83,91', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (232, '删除', 'Delete', 'LINK', 6, 2, 'AUTH', '84,90', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (233, '列表', 'List', 'LIST', 6, 1, 'AUTH', '83', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (234, '查询条件', 'Condition', 'CONDITION', 4, 1, 'AUTH', '92', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (235, '查询条件', 'Condition', 'CONDITION', 6, 1, 'AUTH', '83', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (236, '考务规则配置', 'Add', 'BUTTON', 8, 1, 'AUTH', '99, 100', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (237, '查询', 'Select', 'BUTTON', 9, 1, 'AUTH', '101', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (238, '新增', 'Add', 'BUTTON', 9, 2, 'AUTH', '103', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (239, '查询条件', 'Condition', 'CONDITION', 9, 1, 'AUTH', '101', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (240, '列表', 'List', 'LIST', 9, 1, 'AUTH', '101', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (241, '印刷-单文件打印', '/api/admin/client/print/single', 'URL', 199, 17, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (243, '导入', 'Import', 'BUTTON', 5, 3, 'AUTH', '81', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (249, '查询', 'Select', 'BUTTON', 11, 1, 'AUTH', '123', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (250, '新增', 'Add', 'BUTTON', 11, 2, 'AUTH', '124', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (251, '预览', 'Preview', 'LINK', 11, 1, 'AUTH', '192', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (252, '编辑', 'Edit', 'LINK', 11, 2, 'AUTH', '124,763', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (253, '启用/禁用', 'Enable', 'LINK', 11, 3, 'AUTH', '125', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (254, '查询条件', 'Condition', 'CONDITION', 11, 1, 'AUTH', '123', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (255, '列表', 'List', 'LIST', 11, 1, 'AUTH', '123', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (263, '查询', 'Select', 'BUTTON', 13, 1, 'AUTH', '96,462', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (268, '编辑', 'Edit', 'LINK', 13, 1, 'AUTH', '97', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (269, '删除', 'Delete', 'LINK', 13, 2, 'AUTH', '368', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (270, '查询条件', 'Condition', 'CONDITION', 13, 2, 'AUTH', '96', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (271, '列表', 'List', 'LIST', 13, 1, 'AUTH', '96', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (272, '查询', 'Select', 'BUTTON', 39, 1, 'AUTH', '63', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (273, '批量新增', 'BatchAdd', 'BUTTON', 39, 2, 'AUTH', '67', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (274, '新增', 'Add', 'BUTTON', 39, 3, 'AUTH', '66,169,441,442,445,482', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (275, '预览', 'Preview', 'LINK', 39, 1, 'AUTH', '68', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (277, '启用/禁用', 'Cancel', 'LINK', 39, 3, 'AUTH', '65', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (278, '查询条件', 'Condition', 'CONDITION', 39, 1, 'AUTH', '63', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (279, '列表', 'List', 'LIST', 39, 1, 'AUTH', '63', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (280, '查询', 'Select', 'BUTTON', 40, 1, 'AUTH', '70', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (281, '预览', 'Preview', 'LINK', 40, 1, 'AUTH', '168,477,568,417,420,421,441,442,640,641', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (282, '撤销申请', 'End', 'LINK', 40, 2, 'AUTH', '72', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (283, '立即申请', 'Edit', 'LINK', 40, 3, 'AUTH', '71,167,286,287,424,477,417,420,421,441,442,640,641', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (284, '查询条件', 'Condition', 'CONDITION', 40, 1, 'AUTH', '70', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (285, '列表', 'List', 'LIST', 40, 1, 'AUTH', '70', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (286, '题库试卷列表', '/api/admin/exam/task/page_tiku_paper', 'URL', 40, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (287, '题库试卷包', '/api/admin/exam/task/get_tiku_paper_data', 'URL', 40, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (288, '查询（未审核）', 'NotReviewSelect', 'BUTTON', 41, 1, 'AUTH', '73', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (289, '导出审核样本（未审核）', 'NotReviewExport', 'BUTTON', 41, 2, 'AUTH', '163', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (290, '批量不通过（未审核）', 'NotReviewBatchNotPass', 'BUTTON', 41, 3, 'AUTH', '75', 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (291, '批量通过（未审核）', 'NotReviewBatchPass', 'BUTTON', 41, 4, 'AUTH', '75', 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (292, '审核（未审核）', 'NotReviewEdit', 'LINK', 41, 1, 'AUTH', '74,417,420,421,441,442,477,417,640,641', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (293, '查询条件（未审核）', 'NotReviewCondition', 'CONDITION', 41, 1, 'AUTH', '73', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (294, '列表（未审核）', 'NotReviewList', 'LIST', 41, 1, 'AUTH', '73', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (295, '查询（已审核）', 'ReviewSelect', 'BUTTON', 41, 1, 'AUTH', '166', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (296, '查看详情（已审核）', 'ReviewPreview', 'LINK', 41, 1, 'AUTH', '74,477,417,420,421,441,442,640,641', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (297, '查询条件（已审核）', 'ReviewCondition', 'CONDITION', 41, 1, 'AUTH', '166', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (298, '列表（已审核）', 'ReviewList', 'LIST', 41, 1, 'AUTH', '166', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (299, '查询', 'Select', 'BUTTON', 42, 1, 'AUTH', '76', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (300, '批量下载试卷题卡', 'BatchDownload', 'BUTTON', 42, 2, 'AUTH', '191', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (301, '预览', 'Preview', 'LINK', 42, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (302, '启用/禁用', 'Enable', 'LINK', 42, 2, 'AUTH', '165', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (303, '下载', 'Download', 'LINK', 42, 3, 'AUTH', '164', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (304, '查询条件', 'Condition', 'CONDITION', 42, 1, 'AUTH', '76', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (305, '列表', 'List', 'LIST', 42, 1, 'AUTH', '76', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (306, '从题库选择试卷', 'SelectTikuPaper', 'BUTTON', 40, 13, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (308, '编辑', 'Edit', 'LINK', 42, 4, 'AUTH', '189', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (309, '查询', 'Select', 'BUTTON', 43, 1, 'AUTH', '48,49', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (310, '新增', 'Add', 'BUTTON', 43, 2, 'AUTH', '50,49,193,194,621', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (311, '查看', 'Preview', 'LINK', 43, 1, 'AUTH', '56,57,58,105,825,826', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (312, '编辑', 'Edit', 'LINK', 43, 2, 'AUTH', '50', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (313, '删除', 'Delete', 'LINK', 43, 3, 'AUTH', '51', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (314, '查询条件', 'Condition', 'CONDITION', 43, 1, 'AUTH', '48', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (315, '列表', 'List', 'LIST', 43, 1, 'AUTH', '48,49', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (316, '查询', 'Select', 'BUTTON', 44, 1, 'AUTH', '52,53', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (317, '模版下载', 'TempleteDownload', 'BUTTON', 44, 2, 'AUTH', '157', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (318, '导出', 'Export', 'BUTTON', 44, 3, 'AUTH', '158', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (319, '导入', 'Import', 'BUTTON', 44, 4, 'AUTH', '54', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (320, '查看详情', 'Preview', 'LINK', 44, 1, 'AUTH', '55,327,328,329', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (321, '查询条件', 'Condition', 'CONDITION', 44, 1, 'AUTH', '52', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (322, '列表', 'List', 'LIST', 44, 1, 'AUTH', '52,53', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (323, '查询', 'Select', 'BUTTON', 45, 1, 'AUTH', '159', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (324, '预览', 'Preview', 'LINK', 45, 1, 'AUTH', '188', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (325, '查询条件', 'Condition', 'CONDITION', 45, 1, 'AUTH', '159', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (326, '列表', 'List', 'LIST', 45, 1, 'AUTH', '159', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (327, '新增考生', '/api/admin/exam/print/add_exam_student', 'URL', 44, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (328, '查询考场下试卷列表', '/api/admin/exam/print/list_exam_detail_course', 'URL', 44, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (329, '删除考生', '/api/admin/exam/print/delete_exam_student', 'URL', 44, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (330, '重新生成pdf', 'CreatePdf', 'LINK', 47, 6, 'AUTH', '190', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (331, '查询', 'Select', 'BUTTON', 47, 1, 'AUTH', '59,62', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (332, '查看pdf', 'Download', 'LINK', 47, 1, 'AUTH', '161,162', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (333, '查询条件', 'Condition', 'CONDITION', 47, 1, 'AUTH', '59', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (334, '列表', 'List', 'LIST', 47, 1, 'AUTH', '59', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (335, '撤回提交', 'End', 'LINK', 47, 2, 'AUTH', '61', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (336, '批量下载PDF', 'BatchDownload', 'BUTTON', 47, 2, 'AUTH', '336', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (337, '查询', 'Select', 'BUTTON', 113, 1, 'AUTH', '114', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (338, '导出日志', 'Export', 'LINK', 113, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (339, '下载文件', 'Download', 'LINK', 113, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (340, '查询条件', 'Condition', 'CONDITION', 113, 1, 'AUTH', '114', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (341, '列表', 'List', 'LIST', 113, 1, 'AUTH', '114', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (342, '预览', 'Preview', 'LINK', 9, 1, 'AUTH', '102', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (343, '编辑', 'Edit', 'LINK', 9, 2, 'AUTH', '103', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (345, '删除', 'Delete', 'LINK', 9, 3, 'AUTH', '104', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (346, '题卡审核-未审核查询', 'NotReviewSelect', 'BUTTON', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (347, '题卡审核-未审核批量下载试卷文件', 'NotReviewBatchDownload', 'BUTTON', 172, 2, 'AUTH', '185', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (348, '题卡审核-未审核查询条件', 'NotReviewCondition', 'CONDITION', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (349, '题卡审核-未审核列表', 'NotReviewList', 'LIST', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (350, '题卡审核-未审核预览', 'NotReviewPreview', 'LINK', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (351, '题卡审核-未审核设计题卡', 'NotReviewDesign', 'LINK', 172, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (352, '题卡审核-已审核查询', 'ReviewSelect', 'BUTTON', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (353, '题卡审核-已审核查询条件', 'ReviewCondition', 'CONDITION', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (354, '题卡审核-已审核列表', 'ReviewList', 'LIST', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (355, '题卡审核-已审核预览', 'ReviewPreview', 'LINK', 172, 1, 'AUTH', '173', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (356, '字典管理', 'dictionary', 'MENU', 1, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (357, '学生学院管理', 'CollegeManage', 'MENU', 356, 3, NULL, NULL, 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (358, '学生管理', 'StudentManage', 'MENU', 356, 6, NULL, NULL, 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (359, '查询', '/api/admin/basic/college/query', 'URL', 357, 1, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (360, '新增/编辑', '/api/admin/basic/college/save', 'URL', 357, 2, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (361, '删除（逻辑）', '/api/admin/basic/college/delete', 'URL', 357, 3, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (362, '查询', '/api/admin/basic/student/query', 'URL', 358, 1, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (363, '增/编辑', '/api/admin/basic/student/save', 'URL', 358, 2, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (364, '批量删除（逻辑）', '/api/admin/basic/student/delete_batch', 'URL', 358, 3, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (365, '批量导入（异步）', '/api/admin/basic/student/data_import', 'URL', 358, 4, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (366, '查询', '/api/admin/basic/course/query', 'URL', 13, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (367, '新增/编辑', '/api/admin/basic/course/save', 'URL', 13, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (368, '批量删除', '/api/admin/basic/course/delete_batch', 'URL', 13, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (369, '批量导入', '/api/admin/basic/course/data_import', 'URL', 13, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (370, '获取系统编码', '/api/admin/common/get_code', 'URL', 149, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (371, '根据类型查询机构', '/api/admin/sys/org/find_by_type', 'URL', 4, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (372, '查询', 'Select', 'BUTTON', 357, 1, 'AUTH', '359', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (373, '列表', 'List', 'LIST', 357, 1, 'AUTH', '359', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (374, '新增', 'Add', 'BUTTON', 357, 1, 'AUTH', '360,370', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (375, '编辑', 'Edit', 'LINK', 357, 1, 'AUTH', '360', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (376, '删除', 'Delete', 'LINK', 357, 1, 'AUTH', '361', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (377, '查询', 'Select', 'BUTTON', 358, 1, 'AUTH', '362,462', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (378, '列表', 'List', 'LIST', 358, 1, 'AUTH', '362', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (379, '新增', 'Add', 'BUTTON', 358, 1, 'AUTH', '359,363,462', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (380, '编辑', 'Edit', 'LINK', 358, 1, 'AUTH', '359,363', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (381, '删除', 'Delete', 'LINK', 358, 1, 'AUTH', '364', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (382, '导入', 'Import', 'BUTTON', 358, 2, 'AUTH', '365', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (383, '启用/禁用', 'Enable', 'LINK', 9, 4, 'AUTH', '384', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (384, '启用/禁用', '/api/admin/basic/card_rule/enable', 'URL', 9, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (385, '新增', 'Add', 'BUTTON', 13, 1, 'AUTH', '367,462', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (388, '导入', 'Import', 'BUTTON', 13, 2, 'AUTH', '369', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (389, '机构列表', 'List', 'LIST', 13, 1, 'AUTH', NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (390, '流程管理', 'flow', 'MENU', 1, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (391, '查询条件', 'Condition', 'CONDITION', 357, 1, 'AUTH', '359', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (400, '查询条件', 'Condition', 'CONDITION', 358, 1, 'AUTH', '377', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (402, '流程管理', 'FlowManage', 'MENU', 390, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (403, '流程审批记录管理', 'ApproveRecordManage', 'MENU', 390, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (404, '查询', 'Select', 'BUTTON', 403, 1, 'AUTH', '418', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (405, '查询条件', 'Condition', 'CONDITION', 403, 1, 'AUTH', '418', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (406, '列表', 'List', 'LIST', 403, 1, 'AUTH', '418', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (407, '查询', 'Select', 'BUTTON', 402, 1, 'AUTH', '416', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (408, '新建流程', 'Register', 'BUTTON', 402, 2, 'AUTH', '414', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (409, '删除', 'Delete', 'LINK', 402, 2, 'AUTH', '415', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (410, '查询条件', 'Condition', 'CONDITION', 402, 1, 'AUTH', '416', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (411, '列表', 'List', 'LIST', 402, 1, 'AUTH', '416', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (413, '重新生成pdf', 'CreatePdf', 'LINK', 115, 3, 'AUTH', '190', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (414, '保存和发布流程', '/api/admin/custom/flow/save', 'URL', 402, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (415, '流程逻辑删除', '/api/admin/custom/flow/enable', 'URL', 402, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (416, '流程列表', '/api/admin/custom/flow/list', 'URL', 402, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (417, '审批流程', '/api/admin/custom/flow/task/approve', 'URL', 402, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (418, '流程审批记录列表', '/api/admin/custom/flow/approve/list', 'URL', 402, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (419, '流程审批记录逻辑删除', '/api/admin/custom/flow/approve/enable', 'URL', 402, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (420, '流程终止', '/api/admin/custom/flow/end', 'URL', 402, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (421, '获取所有流程节点', '/api/admin/custom/flow/task/all', 'URL', 402, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (422, '删除', 'Delete', 'LINK', 403, 1, 'AUTH', '419', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (427, '发布印刷任务-印刷室列表', '/api/admin/exam/task/list_task_print_house', 'URL', 42, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (437, '查询模板', 'List', 'LIST', 43, 1, 'AUTH', '49', 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (439, '题卡标题查询', '/api/admin/exam/task/find_card_title', 'URL', 40, 7, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (440, '题卡标题查询', 'List', 'LIST', 40, 1, 'AUTH', '439', 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (441, '根据流程类型获取流程节点', '/api/admin/custom/flow/get_flow_info_by_type', 'URL', 402, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (442, '流程节点转他人审批', '/api/admin/custom/flow/task/approver/exchange', 'URL', 402, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (446, '做废/恢复', '/api/admin/exam/print/task_normal', 'URL', 47, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (447, '作废/恢复', 'Normal', 'LINK', 47, 3, 'AUTH', '446', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (448, '指派/更改', 'Assign', 'LINK', 39, 4, 'AUTH', '64', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (450, '班级管理', 'ClazzManage', 'MENU', 356, 5, NULL, NULL, 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (451, '查询', '/api/admin/basic/clazz/query', 'URL', 450, 1, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (452, '新增/编辑', '/api/admin/basic/clazz/save', 'URL', 450, 2, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (453, '批量删除（逻辑）', '/api/admin/basic/clazz/delete_batch', 'URL', 450, 3, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (455, '查询', 'Select', 'BUTTON', 450, 1, 'AUTH', '451', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (456, '列表', 'List', 'LIST', 450, 1, 'AUTH', '451', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (457, '新增', 'Add', 'BUTTON', 450, 1, 'AUTH', '452', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (458, '编辑', 'Edit', 'LINK', 450, 1, 'AUTH', '452', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (459, '删除', 'Delete', 'LINK', 450, 1, 'AUTH', '453', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (461, '查询条件', 'Condition', 'CONDITION', 450, 1, 'AUTH', '451', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (462, '班级数据源查询', '/api/admin/basic/clazz/datasource', 'URL', 450, 5, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (463, '新建任务', 'ExamTaskApplyManage', 'BUTTON', 40, 8, 'AUTH', '49,167,174,286,287,371,464,465,427,642,417,420,421,441,442,640,641,642', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (464, '新建命题申请', '/api/admin/exam/task/submit_task_apply', 'URL', 40, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (465, '新建命题申请-班级列表', '/api/admin/exam/task/list_task_apply_class', 'URL', 39, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (466, '命题任务-审批-获取试卷审批表数据', '/api/admin/exam/task/find_approve_form_json', 'URL', 39, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (467, '命题任务-审批-获取试卷审批表pdf', '/api/admin/exam/task/find_approve_form_pdf', 'URL', 39, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (468, '下载审批表', 'Download', 'LINK', 40, 5, 'AUTH', '466,467', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (469, '命题计划统计', 'Statistics', 'MENU', 14, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (470, '命题计划统计表', 'StatisticsManage', 'MENU', 469, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (471, '查询', 'Select', 'BUTTON', 470, 1, 'AUTH', '476', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (472, '模板下载', 'Download', 'BUTTON', 470, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (473, '导入', 'Import', 'BUTTON', 470, 3, 'AUTH', '475', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (474, '列表', 'List', 'LIST', 470, 1, 'AUTH', '476', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (475, '导入', '/api/admin/statistics/import', 'URL', 470, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (476, '列表', '/api/admin/statistics/list', 'URL', 470, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (477, '命题任务-考试对象查询', '/api/admin/exam/task/find_exam_object', 'URL', 39, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (478, '刷新数据', 'Freshen', 'BUTTON', 470, 4, 'AUTH', '480', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (479, '删除数据', 'Delete', 'BUTTON', 470, 5, 'AUTH', '481', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (480, '刷新数据', '/api/admin/statistics/freshen', 'URL', 470, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (481, '删除数据', '/api/admin/statistics/delete', 'URL', 470, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (483, '评卷管理', 'stmms', 'MENU', NULL, 6, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (486, '评卷管理', 'MarkTaskManage', 'MENU', 483, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (487, '成绩查询', 'ScoreManage', 'MENU', 561, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (488, '班级详情', 'ClassScoreDetail', 'LINK', 487, 1, 'AUTH', '490,543,955,959,1139', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (489, '成绩报告', 'ScoreReport', 'LINK', 487, 2, 'AUTH', '494,544', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (490, '列表查询', '/api/admin/mark/archive/student/list', 'URL', 488, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (491, '评卷入口', 'MarkEntrance', 'MENU', 486, 1, NULL, '492,493,541', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (492, '评卷员登录', '/api/admin/exam/sso/marker_login', 'URL', 491, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (493, '科组长登录', '/api/admin/exam/sso/marker_leader_login', 'URL', 491, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (494, '报告数据', '/api/admin/mark/archive/score/report', 'URL', 489, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (495, '分班阅（开关）', 'OpenClassReading', 'BUTTON', 897, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (498, '列表', 'List', 'LIST', 487, 1, 'AUTH', '542', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (499, '查询条件', 'Condition', 'CONDITION', 487, 1, 'AUTH', '542', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (500, '查询', 'Select', 'BUTTON', 487, 1, 'AUTH', '542', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (506, '归档管理', 'ScoreArchiveManage', 'MENU', NULL, 7, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (507, '菜单管理', 'MenuManage', 'MENU', 1, 7, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (508, '自定义菜单', 'CustomMenu', 'MENU', 507, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (509, '同步', 'SyncUser', 'BUTTON', 5, 1, 'AUTH', '532', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (510, '学期管理', 'SemesterManage', 'MENU', 356, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (511, '新增', 'Add', 'BUTTON', 510, 1, 'AUTH', '534', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (512, '编辑', 'Edit', 'LINK', 510, 1, 'AUTH', '534', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (513, '删除', 'Delete', 'LINK', 510, 2, 'AUTH', '535', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (514, '列表', 'List', 'LIST', 510, 1, 'AUTH', '533', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (515, '专业管理', 'ProfessionalManage', 'MENU', 356, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (516, '新增', 'Add', 'BUTTON', 515, 1, 'AUTH', '537', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (517, '编辑', 'Edit', 'LINK', 515, 1, 'AUTH', '537', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (518, '删除', 'Delete', 'LINK', 515, 2, 'AUTH', '538', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (519, '列表', 'List', 'LIST', 515, 1, 'AUTH', '536,540', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (520, '查询条件', 'Condition', 'CONDITION', 515, 1, 'AUTH', '536,540', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (521, '同步管理', 'SyncManage', 'MENU', 112, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (522, '查询', 'Select', 'BUTTON', 515, 1, 'AUTH', '536,540', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (523, '查询', 'Select', 'BUTTON', 521, 1, 'AUTH', '557', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (524, '查询条件', 'Condition', 'CONDITION', 521, 1, 'AUTH', '557', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (525, '列表', 'List', 'LIST', 521, 1, 'AUTH', '557', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (526, '导出日志', 'Export', 'LINK', 521, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (527, '查询自定义菜单权限', '/api/admin/set/menu/custom/list', 'URL', 508, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (528, '学校已绑定自定义菜单权限列表', '/api/admin/set/menu/custom/get_school_custom_privileges', 'URL', 508, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (529, '学校新增/修改自定义菜单权限', '/api/admin/set/menu/custom/save', 'URL', 508, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (530, '查询', 'Select', 'BUTTON', 508, 1, 'AUTH', '527,528', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (531, '保存', 'Save', 'BUTTON', 508, 2, 'AUTH', '529', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (532, '同步', '/api/admin/sys/user/push', 'URL', 5, 8, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (533, '查询', '/api/admin/basic/semester/query', 'URL', 510, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (534, '新增/编辑', '/api/admin/basic/semester/save', 'URL', 510, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (535, '删除', '/api/admin/basic/semester/delete', 'URL', 510, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (536, '查询', '/api/admin/basic/professional/page', 'URL', 515, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (537, '新增/编辑', '/api/admin/basic/professional/save', 'URL', 515, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (538, '删除', '/api/admin/basic/professional/remove', 'URL', 515, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (539, '共用接口-查询字典', '/api/admin/common/get_dictionary', 'URL', 149, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (540, '查询（不分页）', '/api/admin/basic/professional/list', 'URL', 515, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (541, '获取用户阅卷角色', '/api/admin/common/get_open_role', 'URL', 491, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (542, '查询接口', '/api/admin/mark/archive/score/list', 'URL', 487, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (543, '成绩导出接口', '/api/admin/mark/archive/score/export', 'URL', 488, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (544, '报告下载', '/api/admin/mark/archive/score/report/download', 'URL', 489, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (545, '成绩下载', 'DownloadScore', 'BUTTON', 487, 2, 'AUTH', '546', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (546, '成绩下载', '/api/admin/mark/archive/score/download', 'URL', 487, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (547, '阅卷试卷上传待办计数接口', '/api/admin/work/structure/task/ready_count', 'URL', 16, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (548, '阅卷试卷上传待办接口', '/api/admin/work/structure/task/ready', 'URL', 16, 8, 'SYS', '490', 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (549, '短信日志', 'SmsManage', 'MENU', 112, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (550, '查询', 'Select', 'BUTTON', 549, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (551, '查询', '/api/admin/basic/message/list', 'URL', 550, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (552, '查询短信类型', '/api/admin/basic/message/list_message_types', 'URL', 550, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (553, '短信失败重发', '/api/admin/basic/message/resend', 'URL', 550, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (554, '查询条件', 'Condition', 'CONDITION', 549, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (555, '列表', 'List', 'LIST', 549, 1, 'AUTH', '551,552', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (556, '短信失败重发', 'Send', 'LINK', 549, 1, 'AUTH', '553', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (557, '查询', '/api/admin/data/sync/query', 'URL', 521, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (558, '模糊查询', '/api/admin/basic/semester/list', 'URL', 510, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (559, '启用/禁用', 'Enable', 'LINK', 510, 1, 'AUTH', '560', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (560, '启用/禁用', '/api/admin/basic/semester/enable', 'URL', 510, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (561, '归档管理', 'ScoreArchivePrimary', 'MENU', 506, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (562, '提交印刷', 'Submit', 'LINK', 47, 5, 'AUTH', '60', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (564, '考试试卷文件上传接口', '/api/admin/common/file/exam_paper_upload', 'URL', 144, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (566, '审核-印刷员驳回后命题老师修改', '/api/admin/exam/task/apply_resave', 'URL', 40, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (567, '查看', 'Preview', 'LINK', 403, 1, 'AUTH', '168,568,640,641,477', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (568, '查询任务详情', '/api/admin/exam/task/exam_task_get_one', 'URL', 40, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (569, '根据条件删除（物理）', '/api/admin/basic/student/delete_by_condition', 'URL', 358, 5, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (570, '批量删除', 'Delete', 'BUTTON', 358, 1, 'AUTH', '569', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (571, '批量删除', 'Delete', 'BUTTON', 450, 1, 'AUTH', '453', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (572, '批量删除', 'Delete', 'BUTTON', 515, 1, 'AUTH', '538', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (573, '根据查询条件批量删除', '/api/admin/basic/course/delete_by_query', 'URL', 13, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (574, '批量删除', 'Delete', 'BUTTON', 13, 5, 'AUTH', '573', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (575, '课程管理', 'basicInfo', 'MENU', 650, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (576, '课程管理', 'CourseSimpleManage', 'MENU', 575, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (577, '文档管理', 'CourseDocumentManage', 'MENU', 561, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (578, '列表', 'List', 'LIST', 577, 1, 'AUTH', '583', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (579, '查询条件', 'Condition', 'CONDITION', 577, 2, 'AUTH', '583', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (580, '查询', 'Select', 'BUTTON', 577, 3, 'AUTH', '583', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (581, '新建文件', 'Add', 'BUTTON', 577, 4, 'AUTH', '584', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (582, '查看详情', 'Detail', 'LINK', 577, 5, 'AUTH', '466,467,494,544,585,586,587,588', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (583, '文档管理列表', '/api/admin/mark/archive/document/list', 'URL', 577, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (584, '文档新建', '/api/admin/mark/archive/document/save', 'URL', 577, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (585, '文档详情', '/api/admin/mark/archive/document/detail', 'URL', 577, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (586, '文档上传', '/api/admin/mark/archive/document/import', 'URL', 577, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (587, '文档删除', '/api/admin/mark/archive/document/delete', 'URL', 577, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (588, '文档下载', '/api/admin/mark/archive/document/download', 'URL', 577, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (598, '教学学生-查询', '/api/admin/teach/student/page', 'URL', 597, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (599, '教学学生-创建教学学生', '/api/admin/teach/student/create', 'URL', 597, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (600, '教学学生-批量删除', '/api/admin/teach/student/delete', 'URL', 597, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (601, '教学学生-批量导入', '/api/admin/teach/student/import', 'URL', 597, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (602, '教学学生-列表', 'List', 'LIST', 597, 1, 'AUTH', '598', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (603, '教学学生-查询', 'Select', 'BUTTON', 597, 2, 'AUTH', '598', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (604, '教学学生-新增', 'Add', 'BUTTON', 597, 3, 'AUTH', '599', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (605, '教学学生-批量导入', 'Import', 'BUTTON', 597, 4, 'AUTH', '601', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (606, '教学学生-删除', 'Delete', 'LINK', 597, 5, 'AUTH', '600', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (607, '教学学生-批量删除', 'DeleteBatch', 'BUTTON', 597, 6, 'AUTH', '600', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (609, '考试管理', 'ExamManage', 'MENU', 356, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (610, '查询', 'Select', 'BUTTON', 609, 1, 'AUTH', '616', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (611, '新增', 'Add', 'BUTTON', 609, 3, 'AUTH', '617', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (612, '启用/禁用', 'Enable', 'LINK', 609, 4, 'AUTH', '618', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (613, '删除', 'Delete', 'LINK', 609, 5, 'AUTH', '619', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (614, '设置', 'Set', 'LINK', 609, 6, 'AUTH', '620,621,622,623,49', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (615, '查询条件', 'Condition', 'CONDITION', 609, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (616, '查询', '/api/admin/basic/exam/page', 'URL', 609, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (617, '新增/修改', '/api/admin/basic/exam/save', 'URL', 609, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (618, '启用/禁用', '/api/admin/basic/exam/enable', 'URL', 609, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (619, '删除', '/api/admin/basic/exam/delete', 'URL', 609, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (620, '设置', '/api/admin/basic/exam/set_in_userd', 'URL', 609, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (621, '查询', '/api/admin/basic/print_config/page', 'URL', 614, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (622, '新增/修改', '/api/admin/basic/print_config/save', 'URL', 614, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (623, '启用/禁用', '/api/admin/basic/print_config/enable', 'URL', 614, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (624, '题卡管理', 'CardManage', 'MENU', 3, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (625, '查询', 'Select', 'BUTTON', 624, 1, 'AUTH', '627', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (626, '查询条件', 'Condition', 'CONDITION', 624, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (627, '查询', '/api/admin/exam/card/page', 'URL', 624, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (628, '编辑', 'Edit', 'LINK', 609, 7, 'AUTH', '617', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (629, '新增', 'Add', 'BUTTON', 624, 3, 'AUTH', '631', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (630, '编辑题卡/编辑信息', 'Edit', 'LINK', 624, 4, 'AUTH', '631', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (631, '新增/修改', '/api/admin/exam/card/save_generic', 'URL', 624, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (632, '列表', 'List', 'LIST', 609, 7, 'AUTH', '616', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (633, '列表', 'List', 'LIST', 624, 5, 'AUTH', '627', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (634, '发送验证码（绑定手机号）', '/api/admin/common/get_verify_code_for_bind', 'URL', 130, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (635, '删除', 'Delete', 'LINK', 624, 6, 'AUTH', '636', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (636, '删除', '/api/admin/exam/card/delete_generic', 'URL', 624, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (637, '模糊查询', '/api/admin/basic/exam/query', 'URL', 609, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (638, '编辑', 'Edit', 'LINK', 402, 1, 'AUTH', '639', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (639, '编辑流程', '/api/admin/custom/flow/edit', 'URL', 402, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (640, '获取当前流程节点信息', '/api/admin/custom/flow/task/info', 'URL', 402, 15, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (641, '流程信息', '/api/admin/custom/flow/view', 'URL', 402, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (642, '根据考试ID和机构ID查询印品', '/api/admin/basic/print_config/get_by_exam_id_and_org_id', 'URL', 614, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (643, '重命名', 'Rename', 'LINK', 402, 3, 'AUTH', '643', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (644, '重命名自定义流程名称', '/api/admin/custom/flow/rename', 'URL', 402, 17, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (647, '成员管理', 'Manager', 'LINK', 6, 3, 'AUTH', '648,649', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (648, '新增/修改', '/api/admin/sys/role/group/save', 'URL', 647, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (649, '查询', '/api/admin/sys/role/group/list', 'URL', 647, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (650, '课程管理', 'baseInfo', 'MENU', NULL, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (651, '电子交卷', 'electronic', 'MENU', NULL, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (652, '电子交卷', 'electronicSubmit', 'MENU', 651, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (653, '下载管理', 'DownloadManage', 'MENU', 112, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (654, '查询', 'Select', 'BUTTON', 653, 1, 'AUTH', '659', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (655, '查询条件', 'Condition', 'CONDITION', 653, 2, 'AUTH', '659', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (656, '下载文件', 'Download', 'LINK', 653, 3, 'AUTH', '660', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (657, '批量下载文件', 'Download', 'BUTTON', 653, 4, 'AUTH', '661', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (658, '列表', 'List', 'LIST', 653, 5, 'AUTH', '659', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (659, '查询', '/api/admin/data/download/page', 'URL', 653, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (660, '下载文件', '/api/admin/data/download/download_one', 'URL', 653, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (661, '批量下载文件', '/api/admin/data/download/download_batch', 'URL', 653, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (662, '教学学生-从课程班级批量添加学生', '/api/admin/teach/student/create_batch', 'URL', 597, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (663, '教学学生-从课程班级添加', 'SaveBatch', 'BUTTON', 597, 7, 'AUTH', '662', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (664, '重新同步', 'Push', 'LINK', 521, 1, 'AUTH', '665', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (665, '重新同步', '/api/admin/data/sync/resync', 'URL', 521, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (672, '获取题卡图片', '/api/admin/exam/card/find_jpg_file', 'URL', 488, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (675, '授权配置', 'AuthManage', 'MENU', 1, 6, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (676, '授权配置-导出硬件信息按钮', 'Export', 'BUTTON', 675, 1, 'AUTH', '677,678,679,794', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (677, '导出硬件信息', '/api/admin/auth/export/device/info', 'URL', 676, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (678, '离线激活', '/api/admin/auth/offline/activation', 'URL', 676, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (679, '查询激活信息', '/api/admin/auth/select', 'URL', 676, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (680, '教研分析', 'analyze', 'MENU', NULL, 8, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (681, '分析批次管理', 'AnalysisBatchManage', 'MENU', 680, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (682, '查询', '/api/admin/grade/batch/page', 'URL', 681, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (683, '新建', '/api/admin/grade/batch/save', 'URL', 681, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (684, '删除', '/api/admin/grade/batch/delete', 'URL', 681, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (685, '推送', '/api/admin/grade/batch/push', 'URL', 681, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (686, '查询', 'Select', 'BUTTON', 681, 1, 'AUTH', '682', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (687, '列表', 'List', 'LIST', 681, 2, 'AUTH', '682', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (688, '新建', 'Add', 'BUTTON', 681, 3, 'AUTH', '683', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (689, '批量删除', 'Delete', 'BUTTON', 681, 4, 'AUTH', '684', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (690, '删除', 'Delete', 'LINK', 681, 5, 'AUTH', '684', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (691, '推送', 'Push', 'LINK', 681, 6, 'AUTH', '685', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (692, '添加分析课程', 'Window', 'LINK', 681, 7, 'AUTH', '693,694,695,696,704,705', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (693, '查询', '/api/admin/grade/batch/paper/page', 'URL', 692, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (694, '新建', '/api/admin/grade/batch/paper/save', 'URL', 692, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (695, '删除', '/api/admin/grade/batch/paper/delete', 'URL', 692, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (696, '查询可分析试卷', '/api/admin/grade/batch/paper/able', 'URL', 692, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (697, '课程查询', 'Select', 'BUTTON', 692, 1, 'AUTH', '693', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (698, '课程列表', 'List', 'LIST', 692, 2, 'AUTH', '693', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (699, '课程添加分析课程', 'Add', 'BUTTON', 692, 3, 'AUTH', '694', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (700, '课程批量删除', 'Delete', 'BUTTON', 692, 4, 'AUTH', '695', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (701, '课程删除', 'Delete', 'BUTTON', 692, 5, 'AUTH', '695', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (702, '可分析课程查询', 'Select', 'BUTTON', 692, 6, 'AUTH', '696', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (703, '可分析课程列表', 'List', 'LIST', 692, 7, 'AUTH', '696', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (704, '推送', '/api/admin/grade/batch/paper/push', 'URL', 692, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (705, '计算', '/api/admin/grade/batch/paper/calculate', 'URL', 692, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (706, '推送', 'Push', 'LINK', 692, 8, 'AUTH', '704', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (707, '计算', 'Calculate', 'LINK', 692, 9, 'AUTH', '705', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (708, '蓝图设置', 'DataInitManage', 'MENU', 680, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (709, '成绩分析课程数据初始化', '/api/admin/grade/paper/initialize', 'URL', 708, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (710, '查询', 'Select', 'BUTTON', 708, 1, 'AUTH', '709', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (711, '列表', 'List', 'LIST', 708, 2, 'AUTH', '709', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (712, '成绩分析基础配置', 'Window', 'LINK', 708, 3, 'AUTH', '717,718,719,720,726,727,728,729,735,736,737,738,755', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (717, '查询', '/api/admin/grade/paper/dimension/list', 'URL', 712, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (718, '新建维度', '/api/admin/grade/paper/dimension/save', 'URL', 712, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (719, '模板导出', '/api/admin/grade/paper/dimension/export', 'URL', 712, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (720, '导入', '/api/admin/grade/paper/dimension/import', 'URL', 712, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (721, '查询', 'Select', 'BUTTON', 712, 1, 'AUTH', '717', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (722, '列表', 'List', 'LIST', 712, 2, 'AUTH', '717', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (723, '新建', 'Add', 'BUTTON', 712, 3, 'AUTH', '718', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (724, '导入', 'Import', 'BUTTON', 712, 4, 'AUTH', '720', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (725, '模板导出', 'Export', 'BUTTON', 712, 5, 'AUTH', '719', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (726, '查询', '/api/admin/grade/paper/struct/list', 'URL', 712, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (727, '新建试卷结构', '/api/admin/grade/paper/struct/save', 'URL', 712, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (728, '导入', '/api/admin/grade/paper/struct/import', 'URL', 712, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (729, '模板导出', '/api/admin/grade/paper/struct/export', 'URL', 712, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (730, '查询', 'Select', 'BUTTON', 712, 1, 'AUTH', '726', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (731, '列表', 'List', 'LIST', 712, 2, 'AUTH', '726', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (732, '导入', 'Import', 'BUTTON', 712, 3, 'AUTH', '728', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (734, '模板导出', 'Export', 'BUTTON', 712, 4, 'AUTH', '729', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (735, '查询定义', '/api/admin/grade/paper/paper_define', 'URL', 712, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (736, '新建定义', '/api/admin/grade/paper/save_define', 'URL', 712, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (737, '查询', '/api/admin/grade/module/evaluation/list', 'URL', 712, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (738, '新建模块评价', '/api/admin/grade/module/evaluation/save', 'URL', 712, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (739, '查看报告', 'AnalysisReportView', 'MENU', 680, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (740, '教研分析单点登录', '/api/admin/exam/sso/analysis_login', 'URL', 149, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (741, '考务数据导出', 'Export', 'LINK', 681, 8, 'AUTH', '743', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (742, '考务数据导入', 'Import', 'LINK', 681, 9, 'AUTH', '744', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (743, '考务数据导出', '/api/admin/grade/batch/download', 'URL', 681, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (744, '考务数据导入', '/api/admin/grade/batch/upload', 'URL', 681, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (745, '教研待办接口', '/api/admin/work/grade/task/ready', 'URL', 16, 9, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (746, '教研待办计数接口', '/api/admin/work/grade/task/ready_count', 'URL', 16, 10, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (747, '开始计算', 'StartCalc', 'LINK', 681, 12, 'AUTH', '748', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (748, '开始计算', '/api/admin/grade/batch/start_calc', 'URL', 681, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (749, '查询条件', 'Condition', 'CONDITION', 708, 4, 'AUTH', '709', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (750, '查询条件', 'Condition', 'CONDITION', 681, 14, 'AUTH', '682', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (751, '课程发布', 'Publish', 'LINK', 681, 6, 'AUTH', '752', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (752, '课程发布', '/api/admin/grade/batch/paper/publish', 'URL', 681, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (755, '更新试卷机构', '/api/admin/grade/paper/struct/change_paper_structure', 'URL', 712, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (756, '查询已审核数量', '/api/admin/exam/task/review_list_audited_count', 'URL', 41, 6, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (757, '批量导入', '/api/admin/sys/org/import', 'URL', 4, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (758, '导入', 'Import', 'BUTTON', 4, 4, 'AUTH', '757', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (759, '考生对象查询', '/api/admin/exam/task/find_exam_task_student_object', 'URL', 40, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (760, '增加考试对象', 'ExamTaskStudentObject', 'BUTTON', 40, 9, 'AUTH', '759', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (761, '导入考生对象', '/api/admin/exam/task/exam_task_exam_student_import', 'URL', 40, 10, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (762, '批量导入考生', 'ExamTaskStudentObjectImport', 'BUTTON', 40, 10, 'AUTH', '761', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (763, '查询详情', '/api/admin/basic/template/get_one', 'URL', 11, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (764, '复制', '/api/admin/exam/card/copy', 'URL', 175, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (765, '查询开课学院', '/api/admin/grade/batch/paper/find_teach_college', 'URL', 692, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (766, '查询条件', 'Condition', 'CONDITION', 470, 1, 'AUTH', '476', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (767, '同步机构数据', '/api/admin/auth/sync/org', 'URL', 676, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (768, '题库单点登录', '/api/admin/exam/sso/question_library_login', 'URL', 149, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (769, '题库管理', 'questionLibrary', 'MENU', NULL, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (770, '题库管理', 'QuestionLibraryManage', 'MENU', 769, 1, NULL, '768', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (771, '用户验证查询', '/api/admin/set/user/select', 'URL', 508, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (772, '用户验证保存', '/api/admin/set/user/save', 'URL', 508, 5, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (773, '试卷规格配置保存', '/api/admin/set/paper/save', 'URL', 508, 6, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (774, '试卷规格配置查询', '/api/admin/set/paper/select', 'URL', 508, 7, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (775, '系统试卷规格配置查询', '/api/admin/set/paper/sys/select', 'URL', 508, 8, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (776, '同步配置保存', '/api/admin/set/sync/save', 'URL', 508, 9, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (777, '同步配置查询', '/api/admin/set/sync/select', 'URL', 508, 10, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (778, '数据还原', '/api/admin/set/backup', 'URL', 508, 11, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (779, '查询自定义角色权限', '/api/admin/set/role/custom/list', 'URL', 508, 12, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (780, '学校新增/修改自定义角色权限', '/api/admin/set/role/custom/save', 'URL', 508, 13, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (781, '学校已绑定自定义角色权限列表', '/api/admin/set/role/custom/get_school_custom_roles', 'URL', 508, 14, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (782, '操作日志', 'ActionLogManage', 'MENU', 112, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (783, '查询', '/api/admin/basic/operation_log/query', 'URL', 782, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (784, '查询条件', 'Condition', 'CONDITION', 782, 1, 'AUTH', '783', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (785, '查询', 'Select', 'BUTTON', 782, 2, 'AUTH', '783', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (786, '课程目标达成度模板配置查询', '/api/admin/set/course/degree/select', 'URL', 508, 15, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (787, '课程目标达成度模板配置保存', '/api/admin/set/course/degree/save', 'URL', 508, 16, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (788, '删除', 'Delete', 'LINK', 11, 4, 'AUTH', '789', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (789, '删除', '/api/admin/basic/template/remove', 'URL', 11, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (790, '查询异步结果', '/api/admin/data/task/query_result', 'URL', 113, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (794, '在线激活', '/api/admin/auth/online/activation', 'URL', 676, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (795, '学校管理', 'SchoolManage', 'MENU', 1, 7, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (796, '查询', 'Select', 'BUTTON', 795, 1, 'AUTH', '798', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (797, '查询条件', 'Condition', 'CONDITION', 795, 2, 'AUTH', '798', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (798, '查询', '/api/admin/commom/school/list', 'URL', 795, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (799, '机构同步', 'Sync', 'BUTTON', 795, 3, 'AUTH', '800', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (800, '机构同步', '/api/admin/auth/sync/org', 'URL', 795, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (801, '编辑', 'Edit', 'LINK', 795, 1, 'AUTH', '802', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (802, '编辑', '/api/admin/commom/school/update', 'URL', 795, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (803, '列表', 'List', 'LIST', 782, 3, 'AUTH', '783', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (804, '删除', 'Delete', 'LINK', 39, 5, 'AUTH', '805', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (805, '删除', '/api/admin/exam/task/delete', 'URL', 39, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (806, '删除', 'Delete', 'LINK', 40, 6, 'AUTH', '807', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (807, '删除', '/api/admin/exam/task/apply_delete', 'URL', 40, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (808, '删除', 'Delete', 'LINK', 44, 2, 'AUTH', '809', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (809, '删除', '/api/admin/exam/print/data_delete', 'URL', 44, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (810, '导出', 'Export', 'BUTTON', 4, 5, 'AUTH', '811', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (811, '导出', '/api/admin/sys/org/export', 'URL', 4, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (812, '导出', 'Export', 'BUTTON', 5, 4, 'AUTH', '813', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (813, '导出', '/api/admin/sys/user/export', 'URL', 5, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (814, '导出', 'Export', 'BUTTON', 358, 3, 'AUTH', '815', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (815, '导出', '/api/admin/basic/student/export', 'URL', 358, 6, 'AUTH', NULL, 0, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (816, '导出', 'Export', 'BUTTON', 13, 6, 'AUTH', '817', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (817, '导出', '/api/admin/basic/course/export', 'URL', 13, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (825, '命题任务公共卷型查询接口', '/api/admin/exam/print/list_relate_common_types', 'URL', 43, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (826, '批量关联接口', '/api/admin/exam/print/relate_update_batch', 'URL', 43, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (827, '超管-角色管理查询', '/api/admin/sys/role/list_to_admin', 'URL', 5, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (828, '生成图片/预览图片', 'ConvertImage', 'LINK', 624, 7, 'AUTH', '829', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (829, '生成图片', '/api/admin/exam/card/convert_image', 'URL', 624, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (830, '教学课程-分页查询', '/api/admin/teach/course/page', 'URL', 576, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (831, '教学课程-手动添加', '/api/admin/teach/course/manual_create', 'URL', 576, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (832, '教学课程-课程表选择并添加', '/api/admin/teach/course/select_create', 'URL', 576, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (833, '教学课程-批量导入', '/api/admin/teach/course/import', 'URL', 576, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (834, '教学课程-批量删除', '/api/admin/teach/course/delete', 'URL', 576, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (835, '教学课程-列表', 'List', 'LIST', 576, 1, 'AUTH', '830', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (836, '查询', 'Select', 'BUTTON', 576, 2, 'AUTH', '830', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (837, '删除', 'Delete', 'LINK', 576, 3, 'AUTH', '834', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (838, '查询条件', 'Condition', 'CONDITION', 576, 4, 'AUTH', '830', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (839, '基础课程-根据学院查询课程', '/api/admin/basic/course/list_by_org', 'URL', 13, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (840, '新增', 'AddCourse', 'BUTTON', 576, 5, 'AUTH', '831,832,833,839', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (841, '管理', 'Link', 'LINK', 576, 6, 'AUTH', '77,842,843,844,845,846,847,848,849,850,851,852,853,866,1115,3018,1117,1118,1119,1120,1121,1122,1123,1124,1125,1126,1128,1129', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (842, '教学班-分页查询', '/api/admin/teach/clazz/page', 'URL', 841, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (843, '教学班-编辑', '/api/admin/teach/clazz/edit', 'URL', 841, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (844, '教学班-删除', '/api/admin/teach/clazz/delete', 'URL', 841, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (845, '教师团队-分页查询', '/api/admin/teach/course/teacher_team_page', 'URL', 841, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (846, '教师团队-手动添加', '/api/admin/teach/course/manual_create_teacher', 'URL', 841, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (847, '教师团队-教师库添加', '/api/admin/teach/course/select_create_teacher', 'URL', 841, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (848, '教师团队-批量导入教师', '/api/admin/teach/course/import_teacher', 'URL', 841, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (849, '教学学生-创建教学学生', '/api/admin/teach/student/create', 'URL', 841, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (850, '教学学生-查询', '/api/admin/teach/student/page', 'URL', 841, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (851, '教学学生-从课程班级批量添加学生', '/api/admin/teach/student/create_batch', 'URL', 841, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (852, '教学学生-批量导入', '/api/admin/teach/student/import', 'URL', 841, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (853, '教学学生-批量删除', '/api/admin/teach/student/delete', 'URL', 841, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (856, '查看', 'Preview', 'LINK', 624, 8, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (860, '共用接口-查询学期', '/api/admin/basic/condition/list_semester', 'URL', 149, 8, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (861, '共用接口-查询考试', '/api/admin/basic/condition/list_exam', 'URL', 149, 9, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (862, '共用接口-查询计划', '/api/admin/basic/condition/list_print_plan', 'URL', 149, 10, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (863, '共用接口-查询课程', '/api/admin/basic/condition/list_course', 'URL', 149, 11, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (864, '共用接口-查询试卷编号', '/api/admin/basic/condition/list_paper_number', 'URL', 149, 12, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (865, '共用接口-查询班级', '/api/admin/basic/condition/list_clazz', 'URL', 149, 13, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (866, '教师团队-根据机构查询', '/api/admin/teach/course/find_teacher_by_org', 'URL', 841, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (867, '下载', 'Download', 'LINK', 624, 9, 'AUTH', '868', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (868, '下载', '/api/admin/exam/card/download_card', 'URL', 624, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (869, '试卷题卡预览日志记录接口', '/api/admin/basic/operation_log/save_preview_log', 'URL', 149, 14, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (872, '批量撤回', 'BatchEnd', 'BUTTON', 47, 3, 'AUTH', '873', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (873, '批量撤回', '/api/admin/exam/print/task_batch_cancel', 'URL', 47, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (874, '共用接口-查询学院', '/api/admin/basic/condition/list_college', 'URL', 149, 14, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (875, '我教课程选择', 'MyTeachCourse', 'BUTTON', 40, 10, 'AUTH', '759', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (876, '考生库选择', 'StudentLibrary', 'BUTTON', 40, 11, 'AUTH', '759', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (877, '考生库选择（是否可选学生）', 'SelectStudent', 'BUTTON', 40, 12, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (878, '作废', 'Cancel', 'LINK', 42, 5, 'AUTH', '879', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (879, '作废', '/api/admin/exam/task/cancel', 'URL', 42, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (880, '重启流程', '/api/admin/exam/task/restart', 'URL', 42, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (881, '打回', 'Restart', 'LINK', 42, 6, 'AUTH', '880', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (884, '列表', 'List', 'LIST', 491, 1, 'AUTH', '887', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (885, '查询', 'Select', 'BUTTON', 491, 2, 'AUTH', '887', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (886, '点击评卷', 'Marking', 'LINK', 491, 3, 'AUTH', '888,889,890,891,892,893,894,895,896', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (887, '查询', '/api/admin/mark/entrance/list', 'URL', 491, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (888, '评卷页面', '/api/mark/getSetting', 'URL', 491, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (889, '获取分组列表', '/api/mark/getGroup', 'URL', 491, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (890, '获取评卷状态', '/api/mark/getStatus', 'URL', 491, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (891, '获取任务', '/api/mark/getTask', 'URL', 491, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (892, '保存任务', '/api/mark/saveTask', 'URL', 491, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (893, '获取评卷历史', '/api/mark/getHistory', 'URL', 491, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (894, '更新个人评卷配置', '/api/mark/updateSetting', 'URL', 491, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (895, '选择评卷分组', '/api/mark/subjectSelect', 'URL', 491, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (896, '清理评卷员的评卷任务缓存', '/api/mark/clear', 'URL', 491, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (897, '评卷设置', 'MarkSetting', 'MENU', 486, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (898, '列表', 'List', 'LIST', 897, 1, 'AUTH', '900', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (899, '查询', 'Select', 'BUTTON', 897, 2, 'AUTH', '900', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (900, '查询', '/api/admin/mark/setting/list', 'URL', 897, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (901, '评卷参数设置', 'MarkParamSetting', 'LINK', 897, 3, 'AUTH', '672,902,903,904,905,906,907,908,909,910,911,912,913,962,963,1132,1133', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (902, '结构查询', '/api/admin/mark/question/list', 'URL', 897, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (903, '结构提交', '/api/admin/mark/question/save', 'URL', 897, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (904, '评卷任务查询', '/api/admin/mark/group/list', 'URL', 897, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (905, '评卷任务新增', '/api/admin/mark/group/save', 'URL', 897, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (906, '评卷任务修改', '/api/admin/mark/group/update', 'URL', 897, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (907, '评卷任务删除', '/api/admin/mark/group/delete', 'URL', 897, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (908, '分班阅查询', '/api/admin/mark/class/list', 'URL', 897, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (909, '分班阅提交', '/api/admin/mark/class/save', 'URL', 897, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (910, '客观题标答查询', '/api/admin/mark/question/objective/list', 'URL', 897, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (911, '客观题标答提交', '/api/admin/mark/question/objective/save', 'URL', 897, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (912, '主观题标答查询', '/api/admin/mark/question/subjective/get', 'URL', 897, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (913, '主观题标答提交', '/api/admin/mark/question/subjective/upload', 'URL', 897, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (914, '评卷设置', 'MarkConfig', 'LINK', 897, 4, 'AUTH', '915,916', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (915, '数据获取', '/api/admin/mark/setting/paper/get', 'URL', 897, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (916, '数据保存', '/api/admin/mark/setting/paper/save', 'URL', 897, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (917, '评卷管理', 'MarkManage', 'MENU', 486, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (918, '列表', 'List', 'LIST', 917, 1, 'AUTH', '925', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (919, '查询', 'Select', 'BUTTON', 917, 2, 'AUTH', '925', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (920, '查询条件', 'Condition', 'CONDITION', 917, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (921, '查询条件', 'Condition', 'CONDITION', 491, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (922, '查询条件', 'Condition', 'CONDITION', 897, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (923, '导出评卷工作量', 'Export', 'BUTTON', 917, 4, 'AUTH', '926', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (924, '结束评卷', 'BatchFinish', 'BUTTON', 917, 5, 'AUTH', '927', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (925, '列表获取', '/api/admin/mark/setting/summary', 'URL', 917, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (926, '导出评卷员工作量', '/api/admin/mark/setting/export_marker', 'URL', 917, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (927, '结束评卷', '/api/admin/mark/paper/finish', 'URL', 917, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (928, '进度列表查询', '/api/admin/mark/group/summary', 'URL', 917, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (929, '评卷员管理列表查询', '/api/admin/mark/marker/list', 'URL', 917, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (930, '重置', '/api/admin/mark/marker/reset', 'URL', 917, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (931, '解绑', '/api/admin/mark/marker/delete', 'URL', 917, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (932, '回收', '/api/admin/mark/marker/release', 'URL', 917, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (933, '设置评卷数', '/api/admin/mark/marker/setTaskCount', 'URL', 917, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (934, '评卷质量查询', '/api/admin/mark/quality/list', 'URL', 917, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (935, '问题试卷列表查询', '/api/admin/mark/problem/list', 'URL', 917, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (936, '问题试卷重置', '/api/admin/mark/problem/reset', 'URL', 917, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (937, '仲裁管理列表查询', '/api/admin/mark/arbitrate/list', 'URL', 917, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (938, '仲裁-获取任务', '/api/admin/mark/arbitrate/getTask', 'URL', 917, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (939, '仲裁-左边的列表', '/api/admin/mark/arbitrate/getArbitrationList', 'URL', 917, 15, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (940, '仲裁-清理锁卷缓存', '/api/admin/mark/arbitrate/clear', 'URL', 917, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (941, '仲裁-获取评卷状态', '/api/admin/mark/arbitrate/getStatus', 'URL', 917, 17, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (942, '仲裁-获取配置信息', '/api/admin/mark/arbitrate/getSetting', 'URL', 917, 18, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (943, '仲裁-保存任务', '/api/admin/mark/arbitrate/saveTask', 'URL', 917, 19, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (944, '查看详情', 'Detail', 'LINK', 917, 6, 'AUTH', '928,929,930,931,932,933,934,935,936,937,938,939,940,941,942,943,964,965,966,967,968,1008', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (945, '结束评卷', 'Finish', 'LINK', 917, 7, 'AUTH', '927', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (946, '成绩检查', 'ScoreCheck', 'MENU', 486, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (947, '列表', 'List', 'LIST', 946, 1, 'AUTH', '952', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (948, '查询条件', 'Condition', 'CONDITION', 946, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (949, '查询', 'Select', 'BUTTON', 946, 3, 'AUTH', '952', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (950, '查看详情', 'Detail', 'LINK', 946, 4, 'AUTH', '953,954,955,956,957,958,959,960,969,1139', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (951, '查看签到表', 'PackageDetail', 'LINK', 946, 5, 'AUTH', '961', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (952, '列表获取', '/api/admin/mark/setting/scoreList', 'URL', 946, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (953, '详情列表', '/api/admin/mark/student/score', 'URL', 946, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (954, '获取配置', '/api/admin/mark/track/getSetting', 'URL', 946, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (955, '获取任务', '/api/admin/mark/track/getTask', 'URL', 946, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (956, '主观题检查-获取配置', '/api/admin/mark/inspected/getSetting', 'URL', 946, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (957, '主观题检查-获取任务', '/api/admin/mark/inspected/subjective/getTask', 'URL', 946, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (958, '主观题检查-保存任务', '/api/admin/mark/inspected/subjective/saveTask', 'URL', 946, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (959, '客观题检查-获取任务', '/api/admin/mark/inspected/objective/getTask', 'URL', 946, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (960, '客观题检查-保存任务', '/api/admin/mark/inspected/objective/saveTask', 'URL', 946, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (961, '签到表列表', '/api/admin/mark/paper/package/list', 'URL', 946, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (962, '评卷区设置', '/api/admin/mark/group/update_picture_config', 'URL', 897, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (963, '开启/关闭分班阅', '/api/admin/mark/group/update_open_mark_class', 'URL', 897, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (964, '班级阅卷进度', '/api/admin/mark/group/class/summary', 'URL', 917, 20, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (965, '绑定评卷员', '/api/admin/mark/marker/add', 'URL', 917, 21, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (966, '评卷质量重新计算', '/api/admin/mark/quality/update', 'URL', 917, 22, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (967, '评卷质量给分曲线', '/api/admin/mark/quality/chart', 'URL', 917, 23, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (968, '绑定评卷员-已绑定评卷员集合', '/api/admin/mark/marker/list_bind_marker', 'URL', 917, 20, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (969, '客观题统分', '/api/admin/mark/student/objective/calculate', 'URL', 946, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (970, '扫描端', 'scan', 'MENU', NULL, 11, NULL, '971,972,973,974,975,976,977,978,979,980,981,982,983,984,985,986,987,988,989,990,991,992,993,994,995,996,997,998,999,1000,1001,1002,1003,1004,1005,1007,1009,1010', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (971, '心跳接口', '/api/scan/server/heartbeat', 'URL', 970, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (972, '登出接口', '/api/scan/logout', 'URL', 970, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (973, '获取学期、考试列表', '/api/admin/basic/condition/scan/semester/list', 'URL', 970, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (974, '获取课程、试卷编号列表', '/api/admin/basic/condition/scan/course/list', 'URL', 970, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (975, '获取校区、考场', '/api/admin/basic/condition/scan/campus/list', 'URL', 970, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (976, '扫描汇总-答题卡扫描、签到表扫描', '/api/scan/exam/card/info', 'URL', 970, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (977, '扫描汇总-数据校对', '/api/scan/exam/check/info', 'URL', 970, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (978, '答题卡卡格式列表', '/api/scan/answer/card/list', 'URL', 970, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (979, '创建/修改题卡卡格式', '/api/scan/answer/card/save', 'URL', 970, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (980, '删除答题卡卡格式', '/api/scan/answer/card/delete', 'URL', 970, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (981, '答题卡适配卡格式上传', '/api/scan/answer/card/adapte/upload', 'URL', 970, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (982, '答题卡卡格式查询', '/api/scan/answer/card/get', 'URL', 970, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (983, '答题卡扫描批次创建', '/api/scan/answer/batch/create', 'URL', 970, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (984, '答题卡扫描批次完成', '/api/scan/answer/batch/finish', 'URL', 970, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (985, '答题卡扫描结果保存', '/api/scan/answer/batch/save', 'URL', 970, 15, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (986, '获取考生信息', '/api/scan/student/find', 'URL', 970, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (987, '答题卡扫描原图上传', '/api/scan/answer/sheet/upload', 'URL', 970, 17, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (988, '答题卡条码识别坐标获取', '/api/scan/package/position/get', 'URL', 970, 18, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (989, '签到表扫描图片上传', '/api/scan/package/image/upload', 'URL', 970, 19, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (990, '签到表扫描结果保存', '/api/scan/package/save', 'URL', 970, 20, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (991, '签到表扫描结果列表', '/api/scan/package/image/list', 'URL', 970, 21, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (992, '签到表编号查询', '/api/scan/package/find', 'URL', 970, 22, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (993, '签到表详情', '/api/scan/package/image/get', 'URL', 970, 23, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (994, '查询答题卡扫描详情', '/api/scan/answer/query', 'URL', 970, 24, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (995, '查询答题卡扫描概要', '/api/scan/answer/summary', 'URL', 970, 25, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (996, '修改答题卡识别结果', '/api/scan/answer/omr/edit', 'URL', 970, 26, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (997, '更新缺考状态', '/api/scan/student/absent/update', 'URL', 970, 27, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (998, '修改答题卡扫描图片绑定考生', '/api/scan/answer/paper/migrate', 'URL', 970, 28, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (999, '任务确认', '/api/scan/student/confirm', 'URL', 970, 29, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1000, '任务待处理列表', '/api/scan/task/omr/get', 'URL', 970, 30, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1001, '任务提交', '/api/scan/task/omr/save', 'URL', 970, 31, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1002, '任务状态', '/api/scan/task/omr/status', 'URL', 970, 32, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1003, '任务释放', '/api/scan/task/omr/release', 'URL', 970, 33, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1004, '任务历史', '/api/scan/task/omr/history', 'URL', 970, 34, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1005, '答题卡二次识别', '/api/scan/answer/refix', 'URL', 970, 35, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1006, '查询条件', 'Condition', 'CONDITION', 970, 1, 'AUTH', '971,972,973,974,975,976,977,978,979,980,981,982,983,984,985,986,987,988,989,990,991,992,993,994,995,996,997,998,999,1000,1001,1002,1003,1004,1005,1007', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1007, '未扫描-导出', '/api/scan/student/unexist/export', 'URL', 970, 36, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1008, '仲裁-评卷历史', '/api/admin/mark/arbitrate/getHistory', 'URL', 917, 20, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1009, '任务列表', '/api/scan/task/omr/list', 'URL', 970, 37, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1010, '人工绑定确认', '/api/scan/student/assign/confirm', 'URL', 970, 38, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1100, '考生管理', 'BasicExamStudentManage', 'MENU', 356, 8, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1101, '分页查询', '/api/admin/basic/exam_student/page', 'URL', 1100, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1102, '新增/编辑', '/api/admin/basic/exam_student/save', 'URL', 1100, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1103, '导入', '/api/admin/basic/exam_student/import', 'URL', 1100, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1104, '导出', '/api/admin/basic/exam_student/export', 'URL', 1100, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1105, '批量删除', '/api/admin/basic/exam_student/delete', 'URL', 1100, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1106, '查询', 'Select', 'BUTTON', 1100, 1, 'AUTH', '1101', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1107, '查询条件', 'Condition', 'CONDITION', 1100, 3, 'AUTH', '1101', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1108, '列表', 'List', 'LIST', 1100, 2, 'AUTH', '1101', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1109, '新增', 'Add', 'BUTTON', 1100, 4, 'AUTH', '1102', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1110, '编辑', 'Edit', 'LINK', 1100, 5, 'AUTH', '1102', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1111, '导入学生', 'Import', 'BUTTON', 1100, 6, 'AUTH', '1103', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1112, '导出学生', 'Export', 'BUTTON', 1100, 7, 'AUTH', '1104', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1113, '删除', 'Delete', 'LINK', 1100, 8, 'AUTH', '1105', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1114, '批量删除', 'DeleteBatch', 'BUTTON', 1100, 9, 'AUTH', '1105', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1115, '教学课程-查询课程权重设置状态', '/api/admin/teach/course/find_course_weight_setting_status', 'URL', 841, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1116, '课程目标管理-列表查询', '/api/admin/teach/course_target/list', 'URL', 841, 15, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1117, '课程目标管理-同步题库知识点', '/api/admin/teach/course_target/dimension_sync_tiku', 'URL', 841, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1118, '课程目标管理-导入课程知识点', '/api/admin/teach/course_target/dimension_import', 'URL', 841, 17, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1119, '课程目标管理-课程知识点树查询', '/api/admin/teach/course_target/dimension_tree', 'URL', 841, 18, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1120, '课程目标管理-新增/编辑', '/api/admin/teach/course_target/save', 'URL', 841, 19, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1121, '课程目标管理-删除', '/api/admin/teach/course_target/delete', 'URL', 841, 20, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1122, '评价方式管理-列表查询', '/api/admin/teach/course_evaluation/list', 'URL', 841, 21, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1123, '评价方式管理-新增', '/api/admin/teach/course_evaluation/save', 'URL', 841, 22, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1124, '评价方式管理-删除', '/api/admin/teach/course_evaluation/delete', 'URL', 841, 23, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1125, '权重设置-查询', '/api/admin/teach/course_weight/find', 'URL', 841, 24, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1126, '权重设置-保存', '/api/admin/teach/course_weight/save', 'URL', 841, 25, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1127, '共用接口-查询教学班字典', '/api/admin/basic/condition/list_basic_teach_clazz', 'URL', 149, 16, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1128, '教师团队管理-分配班级列表查询', '/api/admin/teach/course/find_clazz_list', 'URL', 841, 26, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1129, '教师团队管理-分配班级', '/api/admin/teach/course/assign_clazz', 'URL', 841, 27, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1130, '阅卷数据批量导入（同步）', '/api/admin/mark/setting/mark_student_import', 'URL', 917, 23, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1131, '阅卷数据导入', 'MarkStudentImport', 'BUTTON', 917, 8, 'AUTH', '1130', 0, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1132, '客观题模板导出', '/api/admin/mark/question/objective/export', 'URL', 897, 15, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1133, '客观题标答导入', '/api/admin/mark/question/objective/import', 'URL', 897, 16, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1134, '编辑试卷结构', 'EditPaperStruct', 'LINK', 897, 17, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1135, '客观题导入', '/api/admin/mark/setting/objective_struct/import', 'URL', 897, 17, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1136, '主观题导入', '/api/admin/mark/setting/subjective_struct/import', 'URL', 897, 18, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1137, '客观题导入', 'ObjectiveStructImport', 'BUTTON', 897, 6, 'AUTH', '1135', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1138, '主观题导入', 'SubjectiveStructImport', 'BUTTON', 897, 7, 'AUTH', '1136', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1139, '轨迹图查询题卡内容', '/api/admin/mark/track/getCard', 'URL', 946, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1170, '共用接口-OBE专业', '/api/admin/basic/condition/list_professional', 'URL', 149, 17, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1171, '共用接口-OBE培养方案', '/api/admin/basic/condition/list_culture_program', 'URL', 149, 18, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1172, '共用接口-OBE课程', '/api/admin/basic/condition/list_culture_program_course', 'URL', 149, 18, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1173, '共用接口-OBE学期', '/api/admin/basic/condition/list_outline_semester', 'URL', 149, 19, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1999, '达成度统计', 'DegreeManage', 'MENU', 2000, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2000, '达成度分析', 'TargetDegreeManage', 'MENU', NULL, 13, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2001, '成绩管理', 'TargetScoreManage', 'MENU', 2100, 1, NULL, '2003,2004,2005', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2002, '课程目标达成度统计', 'TargetReportManage', 'MENU', 1999, 2, NULL, '2021,2022,2023', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2003, '列表', 'List', 'LIST', 2001, 1, 'AUTH', '2007', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2004, '查询条件', 'Condition', 'CONDITION', 2001, 2, 'AUTH', '2007', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2005, '查询', 'Select', 'BUTTON', 2001, 3, 'AUTH', '2007', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2006, '管理成绩', 'Score', 'LINK', 2001, 1, 'AUTH', '2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2029,2030,2031,2032,2033,2034,3018', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2007, '列表', '/api/admin/course/degree/score/list', 'URL', 2001, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2008, '平时成绩-下载模版', '/api/admin/course/degree/usual_score/template_download', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2009, '平时成绩-导入模版', '/api/admin/course/degree/usual_score/import', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2010, '平时成绩列表', '/api/admin/course/degree/usual_score/list', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2011, '平时成绩编辑', '/api/admin/course/degree/usual_score/edit', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2012, '平时成绩保存', '/api/admin/course/degree/usual_score/save', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2013, '平时成绩启用/禁用', '/api/admin/course/degree/usual_score/enable', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2014, '期末成绩-下载模版', '/api/admin/course/degree/final_score/template_download', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2015, '期末成绩-导入模版', '/api/admin/course/degree/final_score/import', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2016, '期末成绩列表', '/api/admin/course/degree/final_score/list', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2017, '期末成绩编辑', '/api/admin/course/degree/final_score/edit', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2018, '期末成绩保存', '/api/admin/course/degree/final_score/save', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2019, '期末成绩启用/禁用', '/api/admin/course/degree/final_score/enable', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2020, '保存试卷蓝图', '/api/admin/course/degree/final_score/paper_struct/save', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2021, '列表', 'List', 'LIST', 2002, 1, 'AUTH', '2024', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2022, '查询条件', 'Condition', 'CONDITION', 2002, 2, 'AUTH', '2024', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2023, '查询', 'Select', 'BUTTON', 2002, 3, 'AUTH', '2024', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2024, '列表', '/api/admin/course/degree/report/list', 'URL', 2002, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2025, '查看报告', 'View', 'LINK', 2002, 1, 'AUTH', '2026,2027,2028,2031', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2026, '查看报告', '/api/admin/course/degree/report/view', 'URL', 2025, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2027, '导出报告', '/api/admin/course/degree/report/export', 'URL', 2025, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2028, '保存报告', '/api/admin/course/degree/report/save', 'URL', 2025, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2029, '获取试卷蓝图信息', '/api/admin/course/degree/final_score/paper_struct/query', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2030, '期末成绩-同步', '/api/admin/course/degree/final_score/sync', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2031, '报告数据发生变化', '/api/admin/course/degree/report/change', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2032, '试卷结构-导入模版', '/api/admin/course/degree/final_score/paper_struct/import', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2033, '同步试卷蓝图结构', '/api/admin/course/degree/final_score/paper_struct_dimension/sync', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2034, '同步期末成绩选择试卷', '/api/admin/course/degree/final_score/choose_paper', 'URL', 2006, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2035, '培养方案管理', 'CultureProgramManage', 'MENU', 2000, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2036, '培养方案管理', 'CultureProgram', 'MENU', 2035, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2037, '列表', 'List', 'LIST', 2036, 1, 'AUTH', '2042', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2038, '查询条件', 'Condition', 'CONDITION', 2036, 2, 'AUTH', '2042,540', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2039, '查询', 'Select', 'BUTTON', 2036, 3, 'AUTH', '2042', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2040, '新增', 'Add', 'BUTTON', 2036, 4, 'AUTH', '2043', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2041, '查看详情', 'CultureProgramDetail', 'LINK', 2036, 5, 'AUTH', '2044,2045,2046,2047,2048,2049,2050,2051,2052,2053,2054,2055,2058,2059,2060,2066,2067,2068,2069', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2042, '查询', '/api/admin/obe/culture/program/page', 'URL', 2036, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2043, '新增', '/api/admin/obe/culture/program/save', 'URL', 2036, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2044, '课程体系-选择课程', '/api/admin/obe/culture/program/course/query_list', 'URL', 2036, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2045, '课程体系-查询列表', '/api/admin/obe/culture/program/course/list', 'URL', 2036, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2046, '课程体系-新增', '/api/admin/obe/culture/program/course/save', 'URL', 2036, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2047, '课程体系-排序', '/api/admin/obe/culture/program/course/sort', 'URL', 2036, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2048, '课程体系-删除', '/api/admin/obe/culture/program/course/remove', 'URL', 2036, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2049, '毕业要求-查询', '/api/admin/obe/culture/program/requirement/list', 'URL', 2036, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2050, '毕业要求-新增/编辑', '/api/admin/obe/culture/program/requirement/save', 'URL', 2036, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2051, '培养目标-列表', '/api/admin/obe/culture/program/target/list', 'URL', 2036, 10, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2052, '毕业要求-删除', '/api/admin/obe/culture/program/requirement/remove', 'URL', 2036, 11, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2053, '课程支撑毕业要求达成矩阵-查询-查询', '/api/admin/obe/culture/program/course/matrix/get', 'URL', 2036, 12, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2054, '课程支撑毕业要求达成矩阵-提交-提交', '/api/admin/obe/culture/program/course/matrix/save', 'URL', 2036, 13, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2055, '培养目标-新增/编辑', '/api/admin/obe/culture/program/target/save', 'URL', 2036, 14, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2056, '是否可编辑（课程）', 'canEditCourse', 'LINK', 2036, 6, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2057, '是否可编辑（毕业要求）', 'canEditRequirement', 'LINK', 2036, 7, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2058, '培养目标-删除', '/api/admin/obe/culture/program/target/remove', 'URL', 2036, 15, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2059, '培养目标与毕业要求关系矩阵-查询', '/api/admin/obe/culture/program/target/matrix/get', 'URL', 2036, 16, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2060, '培养目标与毕业要求关系矩阵-提交', '/api/admin/obe/culture/program/target/matrix/save', 'URL', 2036, 17, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2061, '编辑', 'Edit', 'LINK', 2036, 8, 'AUTH', '2043', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2062, '复制', 'Copy', 'LINK', 2036, 9, 'AUTH', '2063', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2063, '复制', '/api/admin/obe/culture/program/copy', 'URL', 2036, 18, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2064, '删除', 'Delete', 'LINK', 2036, 10, 'AUTH', '2065', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2065, '删除', '/api/admin/obe/culture/program/remove', 'URL', 2036, 19, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2066, '保存总体描述', '/api/admin/obe/culture/program/description/save', 'URL', 2036, 20, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2067, '设置期望值', '/api/admin/obe/culture/program/requirement/expect/save', 'URL', 2036, 21, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2068, '基本信息查询', '/api/admin/obe/culture/program/get', 'URL', 2036, 22, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2069, '毕业要求-新增指标点', '/api/admin/obe/culture/program/requirement/node/add', 'URL', 2036, 23, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2070, '毕业要求达成度统计', 'GraduationRequirement', 'MENU', 1999, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2071, '列表', 'List', 'LIST', 2070, 1, 'AUTH', '2075', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2072, '查询条件', 'Condition', 'CONDITION', 2070, 2, 'AUTH', '2075', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2073, '查询', 'Select', 'BUTTON', 2070, 3, 'AUTH', '2075', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2074, '查看详情', 'Detail', 'LINK', 2070, 4, 'AUTH', '2076,2077', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2075, '毕业要求达成度报表列表', '/api/admin/obe/requirements/list', 'URL', 2070, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2076, '毕业要求达成度雷达图', '/api/admin/obe/requirements/radar/report', 'URL', 2070, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2077, '毕业要求达成情况详细报表', '/api/admin/obe/requirements/detail/report', 'URL', 2070, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2080, '学生毕业要求达成度', 'StudentRequirement', 'MENU', 1999, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2081, '列表', 'List', 'LIST', 2080, 1, 'AUTH', '2085', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2082, '查询条件', 'Condition', 'CONDITION', 2080, 2, 'AUTH', '2085', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2083, '查询', 'Select', 'BUTTON', 2080, 3, 'AUTH', '2085', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2084, '查看详情', 'Detail', 'LINK', 2080, 4, 'AUTH', '2086', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2085, '查询', '/api/admin/obe/student_requirement/page', 'URL', 2080, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2086, '查看详情', '/api/admin/obe/student_requirement/detail', 'URL', 2080, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2100, '基础数据', 'BasicDataManage', 'MENU', 2000, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2101, '重新计算', 'Calculate', 'LINK', 2070, 5, 'AUTH', '2102', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2102, '毕业要求达成情况重新计算', '/api/admin/obe/requirements/again/calculate', 'URL', 2070, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2103, '重新计算', 'Calculate', 'BUTTON', 2080, 4, 'AUTH', '2104', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2104, '学生毕业要求达成度重新计算', '/api/admin/obe/student_requirement/again/calculate', 'URL', 2080, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3000, '课程大纲管理', 'CourseOutlineManager', 'MENU', 2035, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3001, '课程考核设置', 'CourseAssessmentSetting', 'MENU', 2035, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3002, '课程大纲-查询', '/api/admin/obe/course_outline/page', 'URL', 3000, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3003, '课程大纲-保存', '/api/admin/obe/course_outline/save', 'URL', 3000, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3004, '课程大纲-删除', '/api/admin/obe/course_outline/delete', 'URL', 3000, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3005, '课程大纲-查询课程权重设置状态', '/api/admin/obe/course_outline/find_course_weight_setting_status', 'URL', 3000, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3006, '课程大纲-查询可选择的培养方案', '/api/admin/obe/course_outline/can_choose_culture_program', 'URL', 3000, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3007, '课程大纲-查询可选择的课程', '/api/admin/obe/course_outline/can_choose_course', 'URL', 3000, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3010, '列表', 'List', 'LIST', 3000, 1, 'AUTH', '3002', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3011, '查询条件', 'Condition', 'CONDITION', 3000, 2, 'AUTH', '3002', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3012, '查询', 'Select', 'BUTTON', 3000, 3, 'AUTH', '3002', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3013, '新增课程大纲', 'Save', 'BUTTON', 3000, 4, 'AUTH', '3003', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3014, '编辑', 'Edit', 'LINK', 3000, 5, 'AUTH', '3003,3006,3007', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3015, '删除', 'Delete', 'LINK', 3000, 6, 'AUTH', '3004', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3016, '查看详情', 'Detail', 'LINK', 3000, 7, 'AUTH', '3005,3017,3018,3019,3020,3021,3022,3023,3024,3025', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3017, '课程大纲-课程基本信息', '/api/admin/obe/course_outline/course_basic_info', 'URL', 3016, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3018, '课程目标管理-列表查询', '/api/admin/obe/course_target/list', 'URL', 3016, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3019, '课程目标管理-新增/编辑', '/api/admin/obe/course_target/save', 'URL', 3016, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3020, '课程目标管理-课程知识点树查询', '/api/admin/obe/course_target/dimension_tree', 'URL', 3016, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3021, '课程目标管理-导入课程知识点', '/api/admin/obe/course_target/dimension_import', 'URL', 3016, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3022, '课程目标管理-指标知识点关系查询', '/api/admin/obe/course_target/requirement_dimension', 'URL', 3016, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3023, '课程目标管理-删除', '/api/admin/obe/course_target/delete', 'URL', 3016, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3024, '课程目标管理-预期值设置', '/api/admin/obe/course_target/setting_expect_value', 'URL', 3016, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3025, '根据培养方案、课程查询指标点', '/api/admin/obe/course_target/sub_requirement/list', 'URL', 3016, 9, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3030, '课程考核设置-查询', '/api/admin/obe/course_outline/assessment_setting_page', 'URL', 3001, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3031, '课程考核设置-删除', '/api/admin/obe/course_outline/assessment_setting_delete', 'URL', 3001, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3040, '列表', 'List', 'LIST', 3001, 1, 'AUTH', '3030', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3041, '查询条件', 'Condition', 'CONDITION', 3001, 2, 'AUTH', '3030', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3042, '查询', 'Select', 'BUTTON', 3001, 3, 'AUTH', '3030', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3043, '删除', 'Delete', 'LINK', 3001, 4, 'AUTH', '3031', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3044, '编辑', 'Edit', 'LINK', 3001, 5, 'AUTH', '3050,3051,3052,3053,3054', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3050, '评价方式管理-列表查询', '/api/admin/obe/course_evaluation/list', 'URL', 3044, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3051, '评价方式管理-新增/编辑', '/api/admin/obe/course_evaluation/save', 'URL', 3044, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3052, '评价方式管理-删除', '/api/admin/obe/course_evaluation/delete', 'URL', 3044, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3053, '课程权重管理-列表查询', '/api/admin/obe/course_weight/find', 'URL', 3044, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (3054, '课程权重管理-新增/编辑', '/api/admin/obe/course_weight/save', 'URL', 3044, 5, 'AUTH', NULL, 1, 1, 1);

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_role` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `name` varchar(50) NOT NULL COMMENT '角色名称',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `type` varchar(20) DEFAULT NULL COMMENT '角色类别，ADMIN：超级管理员，SCHOOL_ADMIN：管理员：EXAM_TEACHER：考务老师，QUESTION_TEACHER：命题老师，CUSTOMER：客服人员，PRINTER：印刷人员，CUSTOM：自定义',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '修改人',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `default_role` tinyint NOT NULL DEFAULT '0' COMMENT '是否系统内置角色，1：是，0：不是',
  `source` varchar(100) DEFAULT NULL COMMENT '角色来源，ANALYSIS：教研分析',
  `interpret` varchar(1000) DEFAULT NULL COMMENT '角色说明',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `role_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色表';

-- ----------------------------
-- Records of sys_role
-- ----------------------------
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (1, NULL, NULL, '系统管理员', 1, 'ADMIN', NULL, NULL, NULL, NULL, 1, NULL, NULL);
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (2, NULL, NULL, '学校管理员', 1, 'SCHOOL_ADMIN', NULL, NULL, 1, 1718948571451, 1, 'SYS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (3, NULL, NULL, '老师', 1, 'SCHOOL_TEACHER', NULL, NULL, 1, 1718948496840, 1, 'SYS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (4, NULL, NULL, '学院秘书', 1, 'ASSISTANT', NULL, NULL, 1, 1718948512325, 1, 'SYS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (5, NULL, NULL, '印刷员', 1, 'PRINT', NULL, NULL, 1, 1710723820791, 1, 'SYS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (6, NULL, NULL, '扫描员', 1, 'SCANNER', NULL, NULL, 1, 1710723800893, 1, 'SYS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (7, NULL, NULL, '评卷员', 1, 'MARKER', NULL, NULL, 506395218631720960, 1713252976427, 1, 'CLOUD_MARK', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (8, NULL, NULL, '学科老师', 1, 'SUBJECT_TEACHER', NULL, NULL, 1, 1712827296444, 1, 'QUESTION_LIBRARY', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (9, NULL, NULL, '命题老师', 1, 'ASSIGN_TEACHER', NULL, NULL, 1, 1718590118464, 1, 'QUESTION_LIBRARY', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (10, NULL, NULL, '教务处老师', 1, 'OFFICE_TEACHER', NULL, NULL, 1, 1712827266110, 1, 'ANALYSIS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (11, NULL, NULL, '学院院长', 1, 'PRESIDENT', NULL, NULL, 506528465164439552, 1714372109928, 1, 'ANALYSIS', '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (12, NULL, NULL, '任课老师', 1, 'TEACHER', NULL, NULL, 1, 1718590144635, 1, 'ANALYSIS', '系统内置');

-- ----------------------------
-- Table structure for sys_role_group_member
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_role_group_member` (
  `id` bigint NOT NULL COMMENT '主键',
  `role_id` bigint NOT NULL COMMENT '角色id',
  `user_id` bigint NOT NULL COMMENT '用户id',
  `member_id` bigint NOT NULL COMMENT '成员id',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `role_group_roleId_memberId_idx` (`role_id`,`member_id`,`enable`) USING BTREE,
  KEY `role_group_member_idx` (`role_id`,`user_id`,`member_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色组成员表';

-- ----------------------------
-- Table structure for sys_role_privilege
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_role_privilege` (
  `id` bigint NOT NULL COMMENT '主键',
  `role_id` bigint NOT NULL COMMENT '角色id',
  `privilege_id` bigint NOT NULL COMMENT '菜单id',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `school_id` bigint DEFAULT NULL COMMENT '内置角色，按学校自定义的权限',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色和菜单关联表';

-- ----------------------------
-- Records of sys_role_privilege
-- ----------------------------
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1, 1, 1, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (2, 1, 2, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (3, 1, 4, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (4, 1, 5, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (5, 1, 6, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (6, 1, 92, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (7, 1, 93, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (8, 1, 94, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (9, 1, 95, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (10, 1, 224, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (11, 1, 225, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (12, 1, 226, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (13, 1, 227, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (14, 1, 228, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (15, 1, 234, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (16, 1, 77, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (17, 1, 78, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (18, 1, 79, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (19, 1, 80, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (20, 1, 81, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (21, 1, 82, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (22, 1, 87, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (23, 1, 184, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (24, 1, 217, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (25, 1, 218, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (26, 1, 219, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (27, 1, 220, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (28, 1, 221, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (29, 1, 222, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (30, 1, 223, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (31, 1, 243, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (32, 1, 83, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (33, 1, 84, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (34, 1, 85, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (35, 1, 86, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (36, 1, 91, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (37, 1, 180, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (38, 1, 229, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (39, 1, 230, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (40, 1, 231, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (41, 1, 232, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (42, 1, 233, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (43, 1, 235, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (44, 1, 390, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (45, 1, 402, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (46, 1, 407, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (47, 1, 408, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (48, 1, 409, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (49, 1, 410, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (50, 1, 411, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (53, 1, 527, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (54, 1, 528, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (55, 1, 529, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (56, 1, 638, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (57, 1, 643, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (58, 1, 675, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (59, 1, 676, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (60, 1, 677, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (61, 1, 678, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (62, 1, 679, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (81, 1, 767, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (88, 1, 771, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (89, 1, 772, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (90, 1, 773, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (91, 1, 774, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (92, 1, 775, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (93, 1, 776, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (94, 1, 777, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (95, 1, 778, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (96, 1, 779, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (97, 1, 780, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (98, 1, 781, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991525810177, 6, 970, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991534198785, 6, 971, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991534198786, 6, 972, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991538393089, 6, 973, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991538393090, 6, 974, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991538393091, 6, 975, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991542587394, 6, 976, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991542587395, 6, 977, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991546781698, 6, 978, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991546781699, 6, 979, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991550976001, 6, 980, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991550976002, 6, 981, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991550976003, 6, 982, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991555170306, 6, 983, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991555170307, 6, 984, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991559364610, 6, 985, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991559364611, 6, 986, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991563558913, 6, 987, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991563558914, 6, 988, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991563558915, 6, 989, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991567753218, 6, 990, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991567753219, 6, 991, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991571947521, 6, 992, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991571947522, 6, 993, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991576141825, 6, 994, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991576141826, 6, 995, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991576141827, 6, 996, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991580336129, 6, 997, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991580336130, 6, 998, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991584530433, 6, 999, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991584530434, 6, 1000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991588724738, 6, 1001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991588724739, 6, 1002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991588724740, 6, 1003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991592919042, 6, 1004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991592919043, 6, 1005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991597113346, 6, 1006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991597113347, 6, 1007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991597113348, 6, 1009, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769529991601307649, 6, 1010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530074996654081, 5, 199, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075005042690, 5, 200, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075005042691, 5, 201, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075005042692, 5, 202, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075009236993, 5, 203, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075009236994, 5, 204, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075013431297, 5, 205, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075013431298, 5, 973, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075013431299, 5, 206, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075017625602, 5, 974, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075017625603, 5, 207, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075021819906, 5, 975, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075021819907, 5, 208, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075021819908, 5, 209, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075026014210, 5, 241, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075026014211, 5, 210, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075030208514, 5, 211, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075030208515, 5, 212, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075030208516, 5, 213, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075034402817, 5, 214, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075034402818, 5, 215, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1769530075038597121, 5, 216, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352564086751234, 10, 739, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352564090945537, 10, 680, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352691320963073, 8, 768, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352691325157378, 8, 769, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352691329351681, 8, 770, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352766998790145, 7, 896, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767002984449, 7, 483, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767002984450, 7, 486, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767007178754, 7, 491, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767007178755, 7, 492, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767007178756, 7, 493, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767011373057, 7, 884, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767011373058, 7, 885, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767011373059, 7, 886, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767015567362, 7, 887, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767015567363, 7, 888, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767019761666, 7, 921, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767019761667, 7, 889, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767019761668, 7, 890, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767023955969, 7, 891, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767023955970, 7, 892, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767023955971, 7, 893, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767028150273, 7, 541, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767028150274, 7, 894, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1778352767032344577, 7, 895, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1784807531827937282, 11, 739, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1784807531836325890, 11, 680, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718800097281, 9, 2048, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718804291585, 9, 768, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718804291586, 9, 769, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718808485890, 9, 2049, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718808485891, 9, 770, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718812680194, 9, 2050, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718812680195, 9, 2051, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718812680196, 9, 2052, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718816874498, 9, 2053, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718816874499, 9, 2054, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718816874500, 9, 2055, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718821068802, 9, 2056, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718821068803, 9, 2057, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718825263106, 9, 2058, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718825263107, 9, 2059, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718825263108, 9, 2060, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718829457410, 9, 2061, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718829457411, 9, 2062, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718829457412, 9, 2063, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718833651713, 9, 2064, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718833651714, 9, 2065, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718833651715, 9, 2066, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718837846017, 9, 2067, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718837846018, 9, 2068, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718837846019, 9, 2069, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718842040322, 9, 2070, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718842040323, 9, 2071, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718842040324, 9, 2072, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718846234625, 9, 2073, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718846234626, 9, 2074, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718850428929, 9, 2075, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718850428930, 9, 540, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718850428931, 9, 2076, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718854623234, 9, 2077, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718854623235, 9, 2080, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718854623236, 9, 2081, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718858817537, 9, 2082, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718858817538, 9, 2083, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718858817539, 9, 2084, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718863011841, 9, 2085, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718863011842, 9, 2086, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718863011843, 9, 2100, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718867206145, 9, 3000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718867206146, 9, 3001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718867206147, 9, 3002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718871400450, 9, 3003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718871400451, 9, 3004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718871400452, 9, 3005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718875594754, 9, 3006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718875594755, 9, 3007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718879789057, 9, 3010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718879789058, 9, 3011, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718879789059, 9, 3012, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718883983362, 9, 3013, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718883983363, 9, 3014, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718883983364, 9, 3015, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718888177665, 9, 3016, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718888177666, 9, 3017, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718888177667, 9, 3018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718892371969, 9, 3019, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718892371970, 9, 3020, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718892371971, 9, 3021, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718896566274, 9, 3022, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718896566275, 9, 1999, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718896566276, 9, 3023, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718900760578, 9, 2000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718900760579, 9, 3024, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718900760580, 9, 2001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718904954882, 9, 3025, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718904954883, 9, 2002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718909149186, 9, 2003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718909149187, 9, 2004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718909149188, 9, 2005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718913343489, 9, 2006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718913343490, 9, 3030, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718913343491, 9, 2007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718917537794, 9, 3031, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718917537795, 9, 2008, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718917537796, 9, 2009, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718921732098, 9, 2010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718921732099, 9, 2011, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718921732100, 9, 2012, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718925926402, 9, 2013, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718925926403, 9, 2014, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718925926404, 9, 2015, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718930120705, 9, 3040, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718930120706, 9, 2016, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718930120707, 9, 3041, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718934315010, 9, 2017, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718934315011, 9, 3042, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718934315012, 9, 2018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718938509314, 9, 3043, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718938509315, 9, 2019, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718942703617, 9, 3044, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718942703618, 9, 2020, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718942703619, 9, 2021, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718946897922, 9, 2022, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718946897923, 9, 2023, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718946897924, 9, 2024, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718951092225, 9, 2025, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718951092226, 9, 2026, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718951092227, 9, 3050, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718955286529, 9, 2027, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718955286530, 9, 3051, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718955286531, 9, 2028, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718959480834, 9, 3052, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718959480835, 9, 2029, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718959480836, 9, 3053, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718963675137, 9, 2030, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718963675138, 9, 3054, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718963675139, 9, 2031, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718967869441, 9, 2032, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718967869442, 9, 2033, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718972063746, 9, 2034, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718972063747, 9, 2035, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718972063748, 9, 2036, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718976258050, 9, 2037, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718976258051, 9, 2038, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718976258052, 9, 2039, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718980452354, 9, 2040, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718980452355, 9, 2041, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718980452356, 9, 2042, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718984646658, 9, 2043, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718984646659, 9, 2044, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718984646660, 9, 2045, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718988840961, 9, 2046, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523718988840962, 9, 2047, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828586004482, 12, 2048, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828594393090, 12, 2049, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828594393091, 12, 2050, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828598587394, 12, 2051, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828598587395, 12, 2052, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828602781698, 12, 2053, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828602781699, 12, 2054, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828602781700, 12, 2055, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828606976001, 12, 2056, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828606976002, 12, 2057, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828611170305, 12, 2058, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828611170306, 12, 2059, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828611170307, 12, 2060, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828615364609, 12, 2061, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828615364610, 12, 2062, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828619558913, 12, 2063, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828619558914, 12, 2064, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828623753217, 12, 2065, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828623753218, 12, 2066, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828623753219, 12, 2067, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828627947522, 12, 2068, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828627947523, 12, 2069, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828627947524, 12, 2070, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828632141825, 12, 2071, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828632141826, 12, 2072, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828636336130, 12, 2073, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828636336131, 12, 2074, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828636336132, 12, 2075, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828640530434, 12, 540, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828640530435, 12, 2076, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828640530436, 12, 2077, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828644724737, 12, 2080, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828644724738, 12, 2081, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828648919041, 12, 2082, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828648919042, 12, 2083, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828648919043, 12, 2084, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828653113346, 12, 2085, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828653113347, 12, 2086, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828653113348, 12, 2100, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828657307649, 12, 680, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828657307650, 12, 3000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828657307651, 12, 3001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828661501954, 12, 3002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828661501955, 12, 3003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828665696257, 12, 3004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828665696258, 12, 3005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828665696259, 12, 3006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828669890561, 12, 3007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828669890562, 12, 3010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828669890563, 12, 3011, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828674084865, 12, 3012, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828674084866, 12, 3013, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828678279169, 12, 3014, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828678279170, 12, 3015, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828678279171, 12, 3016, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828682473473, 12, 3017, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828682473474, 12, 3018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828682473475, 12, 3019, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828686667778, 12, 3020, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828686667779, 12, 3021, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828686667780, 12, 3022, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828690862082, 12, 1999, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828690862083, 12, 3023, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828690862084, 12, 2000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828695056385, 12, 3024, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828695056386, 12, 2001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828699250690, 12, 3025, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828699250691, 12, 2002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828699250692, 12, 2003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828703444994, 12, 2004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828703444995, 12, 2005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828703444996, 12, 2006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828707639297, 12, 3030, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828707639298, 12, 3031, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828711833602, 12, 2007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828711833603, 12, 2008, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828711833604, 12, 2009, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828716027905, 12, 2010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828716027906, 12, 2011, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828716027907, 12, 2012, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828720222210, 12, 2013, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828720222211, 12, 2014, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828720222212, 12, 2015, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828724416514, 12, 3040, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828724416515, 12, 2016, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828728610817, 12, 3041, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828728610818, 12, 2017, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828728610819, 12, 3042, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828732805122, 12, 2018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828732805123, 12, 739, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828732805124, 12, 3043, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828736999425, 12, 2019, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828736999426, 12, 3044, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828736999427, 12, 2020, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828741193730, 12, 2021, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828741193731, 12, 2022, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828745388034, 12, 2023, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828745388035, 12, 2024, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828745388036, 12, 2025, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828749582338, 12, 2026, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828749582339, 12, 3050, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828749582340, 12, 2027, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828753776641, 12, 3051, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828753776642, 12, 2028, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828753776643, 12, 3052, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828757970946, 12, 2029, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828757970947, 12, 3053, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828762165250, 12, 2030, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828762165251, 12, 3054, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828762165252, 12, 2031, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828766359554, 12, 2032, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828766359555, 12, 2033, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828766359556, 12, 2034, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828770553857, 12, 2035, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828770553858, 12, 2036, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828774748162, 12, 2037, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828774748163, 12, 2038, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828774748164, 12, 2039, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828778942466, 12, 2040, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828778942467, 12, 2041, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828778942468, 12, 2042, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828783136769, 12, 2043, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828783136770, 12, 2044, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828783136771, 12, 2045, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828787331073, 12, 2046, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1802523828787331074, 12, 2047, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866768572417, 3, 541, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866785349633, 3, 542, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866789543937, 3, 543, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866789543938, 3, 544, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866789543939, 3, 40, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866793738242, 3, 561, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866793738243, 3, 49, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866793738244, 3, 568, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866797932545, 3, 575, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866797932546, 3, 576, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866797932547, 3, 577, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866802126850, 3, 578, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866802126851, 3, 579, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866802126852, 3, 580, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866806321153, 3, 581, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866806321154, 3, 582, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866806321155, 3, 70, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866806321156, 3, 71, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866810515457, 3, 583, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866810515458, 3, 72, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866810515459, 3, 584, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866814709761, 3, 585, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866814709762, 3, 586, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866814709763, 3, 587, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866818904066, 3, 588, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866818904067, 3, 77, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866818904068, 3, 1115, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866818904069, 3, 1117, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866823098370, 3, 1118, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866823098371, 3, 1119, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866823098372, 3, 1120, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866827292673, 3, 1121, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866827292674, 3, 1122, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866827292675, 3, 1123, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866831486978, 3, 1124, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866831486979, 3, 1125, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866831486980, 3, 1126, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866835681281, 3, 1128, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866835681282, 3, 1129, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866835681283, 3, 1132, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866835681284, 3, 1133, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866839875585, 3, 1139, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866839875586, 3, 640, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866839875587, 3, 641, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866844069890, 3, 642, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866844069891, 3, 650, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866844069892, 3, 651, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866848264193, 3, 652, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866848264194, 3, 672, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866848264195, 3, 167, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866848264196, 3, 168, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866852458497, 3, 174, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866852458498, 3, 759, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866852458499, 3, 760, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866856652802, 3, 280, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866856652803, 3, 281, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866856652804, 3, 282, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866860847105, 3, 283, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866860847106, 3, 284, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866860847107, 3, 285, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866860847108, 3, 286, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866865041409, 3, 287, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866865041410, 3, 806, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866865041411, 3, 807, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866869235714, 3, 830, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866869235715, 3, 831, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866869235716, 3, 832, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866873430017, 3, 833, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866873430018, 3, 834, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866873430019, 3, 835, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866873430020, 3, 836, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866877624322, 3, 837, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866877624323, 3, 838, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866877624324, 3, 839, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866881818625, 3, 840, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866881818626, 3, 841, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866881818627, 3, 842, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866881818628, 3, 843, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866886012930, 3, 844, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866886012931, 3, 845, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866886012932, 3, 846, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866890207234, 3, 847, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866890207235, 3, 848, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866890207236, 3, 849, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866894401537, 3, 850, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866894401538, 3, 851, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866894401539, 3, 852, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866894401540, 3, 853, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866898595842, 3, 866, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866898595843, 3, 876, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866898595844, 3, 371, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866902790146, 3, 884, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866902790147, 3, 885, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866902790148, 3, 886, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866902790149, 3, 887, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866906984449, 3, 888, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866906984450, 3, 889, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866906984451, 3, 890, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866911178754, 3, 891, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866911178755, 3, 892, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866911178756, 3, 893, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866915373057, 3, 894, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866915373058, 3, 895, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866915373059, 3, 896, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866919567362, 3, 897, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866919567363, 3, 898, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866923761666, 3, 899, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866927955970, 3, 900, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866927955971, 3, 901, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866927955972, 3, 902, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866932150273, 3, 903, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866932150274, 3, 904, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866932150275, 3, 905, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866936344578, 3, 906, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866940538881, 3, 907, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866944733185, 3, 908, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866944733186, 3, 909, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866944733187, 3, 910, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866948927489, 3, 911, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866948927490, 3, 912, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866948927491, 3, 913, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866953121793, 3, 917, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866953121794, 3, 918, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866953121795, 3, 919, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866953121796, 3, 920, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866957316098, 3, 921, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866957316099, 3, 922, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866957316100, 3, 923, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866961510402, 3, 924, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866961510403, 3, 925, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866961510404, 3, 926, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866961510405, 3, 927, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866965704705, 3, 928, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866965704706, 3, 417, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866965704707, 3, 929, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866969899009, 3, 930, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866969899010, 3, 931, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866969899011, 3, 420, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866969899012, 3, 932, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866974093313, 3, 421, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866974093314, 3, 933, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866974093315, 3, 934, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866978287618, 3, 935, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866978287619, 3, 936, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866978287620, 3, 424, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866978287621, 3, 937, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866982481921, 3, 938, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866982481922, 3, 939, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866982481923, 3, 427, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866986676225, 3, 940, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866986676226, 3, 941, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866986676227, 3, 942, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866986676228, 3, 943, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866990870529, 3, 944, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866990870530, 3, 945, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866990870531, 3, 946, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866995064834, 3, 947, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866995064835, 3, 948, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866995064836, 3, 949, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866995064837, 3, 950, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866999259137, 3, 951, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866999259138, 3, 952, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026866999259139, 3, 441, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867003453441, 3, 953, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867003453442, 3, 442, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867003453443, 3, 954, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867003453444, 3, 955, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867007647746, 3, 956, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867007647747, 3, 957, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867007647748, 3, 958, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867011842049, 3, 959, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867011842050, 3, 960, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867011842051, 3, 961, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867011842052, 3, 962, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867016036353, 3, 963, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867016036354, 3, 964, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867016036355, 3, 965, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867020230657, 3, 966, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867020230658, 3, 967, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867020230659, 3, 968, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867020230660, 3, 969, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867024424961, 3, 970, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867024424962, 3, 3018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867024424963, 3, 971, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867028619266, 3, 972, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867028619267, 3, 973, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867028619268, 3, 974, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867028619269, 3, 463, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867032813569, 3, 975, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867032813570, 3, 976, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867032813571, 3, 464, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867037007874, 3, 977, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867037007875, 3, 465, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867037007876, 3, 978, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867037007877, 3, 466, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867041202177, 3, 979, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867041202178, 3, 467, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867041202179, 3, 468, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867045396481, 3, 980, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867045396482, 3, 981, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867045396483, 3, 982, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867045396484, 3, 983, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867049590786, 3, 984, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867049590787, 3, 985, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867049590788, 3, 986, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867053785090, 3, 987, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867053785091, 3, 988, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867053785092, 3, 477, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867053785093, 3, 989, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867057979394, 3, 990, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867057979395, 3, 991, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867057979396, 3, 992, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867062173698, 3, 993, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867062173699, 3, 994, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867062173700, 3, 483, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867062173701, 3, 995, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867066368002, 3, 996, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867066368003, 3, 997, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867066368004, 3, 486, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867070562305, 3, 998, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867070562306, 3, 487, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867070562307, 3, 999, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867070562308, 3, 488, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867074756609, 3, 1000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867074756610, 3, 489, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867074756611, 3, 1001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867078950913, 3, 1002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867078950914, 3, 490, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867078950915, 3, 491, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867078950916, 3, 1003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867083145218, 3, 1004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867083145219, 3, 492, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867083145220, 3, 1005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867087339521, 3, 493, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867087339522, 3, 1006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867087339523, 3, 494, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867087339524, 3, 1007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867091533826, 3, 1008, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867091533827, 3, 1009, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867091533828, 3, 498, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867095728129, 3, 1010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867095728130, 3, 499, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867095728131, 3, 500, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026867095728132, 3, 506, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931625095170, 4, 650, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931633483777, 4, 651, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931633483778, 4, 652, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931633483779, 4, 272, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931637678081, 4, 273, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931637678082, 4, 274, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931637678083, 4, 275, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931637678084, 4, 277, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931641872385, 4, 278, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931641872386, 4, 279, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931641872387, 4, 804, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931646066690, 4, 165, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931646066691, 4, 805, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931646066692, 4, 39, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931650260993, 4, 169, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931650260994, 4, 42, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931650260995, 4, 299, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931650260996, 4, 300, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931654455298, 4, 301, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931654455299, 4, 302, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931654455300, 4, 304, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931658649601, 4, 305, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931658649602, 4, 441, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931658649603, 4, 442, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931658649604, 4, 445, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931662843906, 4, 830, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931662843907, 4, 575, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931662843908, 4, 191, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931667038210, 4, 831, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931667038211, 4, 63, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931667038212, 4, 576, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931671232513, 4, 448, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931671232514, 4, 832, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931671232515, 4, 64, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931671232516, 4, 833, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931675426817, 4, 65, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931675426818, 4, 66, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931675426819, 4, 834, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931679621122, 4, 835, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931679621123, 4, 67, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931679621124, 4, 836, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931683815426, 4, 68, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931683815427, 4, 837, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931683815428, 4, 838, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931683815429, 4, 839, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931688009730, 4, 840, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931688009731, 4, 841, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931688009732, 4, 842, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931692204034, 4, 3018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931692204035, 4, 843, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931692204036, 4, 844, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931692204037, 4, 76, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931696398337, 4, 77, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931696398338, 4, 845, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931696398339, 4, 846, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931700592642, 4, 847, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931700592643, 4, 848, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931700592644, 4, 849, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931704786946, 4, 850, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931704786947, 4, 851, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931704786948, 4, 852, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931704786949, 4, 853, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931708981249, 4, 1115, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931708981250, 4, 1117, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931708981251, 4, 1118, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931713175554, 4, 1119, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931713175555, 4, 1120, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931713175556, 4, 1121, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931713175557, 4, 482, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931717369857, 4, 866, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931717369858, 4, 1122, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931717369859, 4, 1123, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931721564161, 4, 1124, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931721564162, 4, 1125, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931721564163, 4, 1126, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931721564164, 4, 1128, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804026931725758466, 4, 1129, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180162772993, 2, 2048, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180192133122, 2, 1, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180196327425, 2, 2049, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180196327426, 2, 2, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180200521730, 2, 2050, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180204716033, 2, 3, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180208910337, 2, 2051, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180208910338, 2, 4, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180213104641, 2, 2052, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180213104642, 2, 5, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180213104643, 2, 2053, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180217298945, 2, 6, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180217298946, 2, 2054, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180221493250, 2, 2055, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180221493251, 2, 8, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180225687553, 2, 2056, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180225687554, 2, 9, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180225687555, 2, 2057, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180229881858, 2, 2058, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180229881859, 2, 11, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180229881860, 2, 2059, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180234076161, 2, 2060, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180234076162, 2, 13, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180234076163, 2, 2061, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180238270466, 2, 14, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180238270467, 2, 2062, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180238270468, 2, 2063, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180238270469, 2, 2064, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180242464769, 2, 2065, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180242464770, 2, 2066, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180246659074, 2, 2067, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180246659075, 2, 2068, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180246659076, 2, 2069, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180250853378, 2, 2070, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180250853379, 2, 2071, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180250853380, 2, 2072, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180255047681, 2, 2073, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180259241986, 2, 2074, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180259241987, 2, 2075, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180259241988, 2, 2076, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180263436290, 2, 2077, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180263436291, 2, 2080, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180263436292, 2, 2081, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180267630594, 2, 2082, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180267630595, 2, 2083, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180267630596, 2, 2084, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180271824897, 2, 2085, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180280213506, 2, 38, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180284407810, 2, 2086, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180288602113, 2, 39, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180292796418, 2, 40, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180292796419, 2, 41, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180292796420, 2, 42, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180296990721, 2, 43, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180296990722, 2, 44, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180296990723, 2, 45, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180301185025, 2, 47, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180301185026, 2, 48, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180301185027, 2, 49, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180301185028, 2, 50, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180305379329, 2, 51, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180305379330, 2, 2100, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180309573634, 2, 52, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180309573635, 2, 2101, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180313767937, 2, 53, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180313767938, 2, 2102, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180317962242, 2, 54, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180317962243, 2, 2103, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180317962244, 2, 55, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180322156546, 2, 2104, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180322156547, 2, 56, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180322156548, 2, 57, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180326350849, 2, 58, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180326350850, 2, 59, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180326350851, 2, 60, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180330545153, 2, 61, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180330545154, 2, 62, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180334739457, 2, 63, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180334739458, 2, 64, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180338933761, 2, 65, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180338933762, 2, 66, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180338933763, 2, 67, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180338933764, 2, 68, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180343128065, 2, 70, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180343128066, 2, 71, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180343128067, 2, 72, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180347322370, 2, 73, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180347322371, 2, 74, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180351516674, 2, 76, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180351516675, 2, 77, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180351516676, 2, 78, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180355710978, 2, 79, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180355710979, 2, 80, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180355710980, 2, 81, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180359905282, 2, 83, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180359905283, 2, 84, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180359905284, 2, 85, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180364099585, 2, 87, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180364099586, 2, 88, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180368293890, 2, 89, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180368293891, 2, 90, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180372488194, 2, 91, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180372488195, 2, 92, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180372488196, 2, 93, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180376682498, 2, 94, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180376682499, 2, 96, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180376682500, 2, 97, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180380876802, 2, 99, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180380876803, 2, 100, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180380876804, 2, 101, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180385071106, 2, 102, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180385071107, 2, 103, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180385071108, 2, 104, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180385071109, 2, 105, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180389265410, 2, 112, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180389265411, 2, 113, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180389265412, 2, 114, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180393459714, 2, 115, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180393459715, 2, 116, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180393459716, 2, 123, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180397654018, 2, 124, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180397654019, 2, 125, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180397654020, 2, 126, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180401848322, 2, 127, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180401848323, 2, 128, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180406042626, 2, 157, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180406042627, 2, 158, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180406042628, 2, 159, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180410236929, 2, 161, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180410236930, 2, 162, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180410236931, 2, 164, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180414431233, 2, 165, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180418625537, 2, 166, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180422819842, 2, 167, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180422819843, 2, 168, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180422819844, 2, 169, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180427014146, 2, 174, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180427014147, 2, 184, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180431208450, 2, 188, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180431208451, 2, 190, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180431208452, 2, 191, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180435402753, 2, 192, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180435402754, 2, 193, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180435402755, 2, 194, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180439597058, 2, 199, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180439597059, 2, 200, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180439597060, 2, 201, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180443791361, 2, 202, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180443791362, 2, 203, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180443791363, 2, 204, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180447985665, 2, 205, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180447985666, 2, 206, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180447985667, 2, 207, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180447985668, 2, 208, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180452179969, 2, 209, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180452179970, 2, 210, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180452179971, 2, 211, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180452179972, 2, 212, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180456374274, 2, 213, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180456374275, 2, 214, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180456374276, 2, 215, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180460568578, 2, 216, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180460568579, 2, 217, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180460568580, 2, 218, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180460568581, 2, 219, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180464762882, 2, 220, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180464762883, 2, 221, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180464762884, 2, 222, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180464762885, 2, 223, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180468957186, 2, 224, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180468957187, 2, 225, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180473151489, 2, 226, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180473151490, 2, 227, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180473151491, 2, 228, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180477345794, 2, 229, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180477345795, 2, 230, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180481540097, 2, 231, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180481540098, 2, 232, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180481540099, 2, 233, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180485734402, 2, 235, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180485734403, 2, 236, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180485734404, 2, 237, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180489928706, 2, 238, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180489928707, 2, 239, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180494123010, 2, 240, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180494123011, 2, 241, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180494123012, 2, 243, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180498317313, 2, 249, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180498317314, 2, 250, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180498317315, 2, 251, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180502511618, 2, 252, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180502511619, 2, 253, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180506705921, 2, 254, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180506705922, 2, 255, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180506705923, 2, 263, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180510900225, 2, 268, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180510900226, 2, 269, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180510900227, 2, 270, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180510900228, 2, 271, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180515094529, 2, 272, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180515094530, 2, 273, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180515094531, 2, 274, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180519288833, 2, 275, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180519288834, 2, 277, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180519288835, 2, 278, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180519288836, 2, 279, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180523483137, 2, 280, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180523483138, 2, 281, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180523483139, 2, 282, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180527677441, 2, 283, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180527677442, 2, 284, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180527677443, 2, 285, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180527677444, 2, 286, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180531871745, 2, 287, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180531871746, 2, 288, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180531871747, 2, 292, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180536066050, 2, 293, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180536066051, 2, 294, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180536066052, 2, 295, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180540260353, 2, 296, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180540260354, 2, 297, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180540260355, 2, 298, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180540260356, 2, 299, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180544454657, 2, 300, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180544454658, 2, 301, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180544454659, 2, 302, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180544454660, 2, 303, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180548648961, 2, 304, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180548648962, 2, 305, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180548648963, 2, 306, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180552843266, 2, 309, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180552843267, 2, 310, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180552843268, 2, 311, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180552843269, 2, 312, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180557037570, 2, 313, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180557037571, 2, 314, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180557037572, 2, 315, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180561231873, 2, 316, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180561231874, 2, 317, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180561231875, 2, 318, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180561231876, 2, 319, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180565426177, 2, 320, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180565426178, 2, 321, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180565426179, 2, 322, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180565426180, 2, 323, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180569620481, 2, 324, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180569620482, 2, 325, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180569620483, 2, 326, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180573814786, 2, 327, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180573814787, 2, 328, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180573814788, 2, 329, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180573814789, 2, 330, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180578009089, 2, 331, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180578009090, 2, 332, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180578009091, 2, 333, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180582203393, 2, 334, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180582203394, 2, 335, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180582203395, 2, 336, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180582203396, 2, 337, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180586397697, 2, 338, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180586397698, 2, 339, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180586397699, 2, 340, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180586397700, 2, 341, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180590592001, 2, 342, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180590592002, 2, 343, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180590592003, 2, 345, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180594786306, 2, 356, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180594786307, 2, 367, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180594786308, 2, 368, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180594786309, 2, 369, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180598980610, 2, 371, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180598980611, 2, 383, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180598980612, 2, 384, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180603174914, 2, 385, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180603174915, 2, 388, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180603174916, 2, 390, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180603174917, 2, 402, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180607369218, 2, 403, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180607369219, 2, 404, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180607369220, 2, 405, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180607369221, 2, 406, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180611563521, 2, 407, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180611563522, 2, 408, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180611563523, 2, 409, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180615757825, 2, 410, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180615757826, 2, 411, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180615757827, 2, 413, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180615757828, 2, 414, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180619952129, 2, 415, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180619952130, 2, 416, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180619952131, 2, 417, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180624146433, 2, 418, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180624146434, 2, 419, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180624146435, 2, 420, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180624146436, 2, 421, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180628340738, 2, 422, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180628340739, 2, 424, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180628340740, 2, 427, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180628340741, 2, 441, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180632535042, 2, 442, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180632535043, 2, 445, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180632535044, 2, 446, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180636729345, 2, 447, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180636729346, 2, 448, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180636729347, 2, 462, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180636729348, 2, 463, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180640923649, 2, 464, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180640923650, 2, 465, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180640923651, 2, 466, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180645117953, 2, 467, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180645117954, 2, 468, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180645117955, 2, 477, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180645117956, 2, 482, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180649312257, 2, 483, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180649312258, 2, 486, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180649312259, 2, 487, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180653506561, 2, 488, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180653506562, 2, 489, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180653506563, 2, 490, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180653506564, 2, 491, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180657700866, 2, 492, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180657700867, 2, 493, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180657700868, 2, 494, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180657700869, 2, 495, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180661895170, 2, 498, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180661895171, 2, 499, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180661895172, 2, 500, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180666089474, 2, 506, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180666089475, 2, 510, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180666089476, 2, 511, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180666089477, 2, 513, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180670283777, 2, 514, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180670283778, 2, 515, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180670283779, 2, 516, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180674478082, 2, 517, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180674478083, 2, 518, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180674478084, 2, 519, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180674478085, 2, 520, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180678672385, 2, 521, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180678672386, 2, 522, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180678672387, 2, 523, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180678672388, 2, 524, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180682866690, 2, 525, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180682866691, 2, 526, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180682866692, 2, 533, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180687060993, 2, 534, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180687060994, 2, 535, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180687060995, 2, 536, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180687060996, 2, 537, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180691255298, 2, 538, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180691255299, 2, 540, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180691255300, 2, 541, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180695449602, 2, 542, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180695449603, 2, 543, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180695449604, 2, 544, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180695449605, 2, 545, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180699643906, 2, 546, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180699643907, 2, 549, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180699643908, 2, 550, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180699643909, 2, 551, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180703838209, 2, 552, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180703838210, 2, 553, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180703838211, 2, 554, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180708032513, 2, 555, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180708032514, 2, 556, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180708032515, 2, 557, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180708032516, 2, 559, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180712226818, 2, 560, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180712226819, 2, 561, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180712226820, 2, 562, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180716421121, 2, 567, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180716421122, 2, 568, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180716421123, 2, 573, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180716421124, 2, 574, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180720615425, 2, 575, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180720615426, 2, 576, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180720615427, 2, 577, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180720615428, 2, 578, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180724809730, 2, 579, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180724809731, 2, 580, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180724809732, 2, 581, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180729004034, 2, 582, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180729004035, 2, 583, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180729004036, 2, 584, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180729004037, 2, 585, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180733198338, 2, 586, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180733198339, 2, 587, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180733198340, 2, 588, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180737392641, 2, 609, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180737392642, 2, 610, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180737392643, 2, 611, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180737392644, 2, 612, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180741586946, 2, 613, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180741586947, 2, 614, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180741586948, 2, 615, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180745781250, 2, 616, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180745781251, 2, 617, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180745781252, 2, 618, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180745781253, 2, 619, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180749975553, 2, 620, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180749975554, 2, 621, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180749975555, 2, 622, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180749975556, 2, 623, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180754169857, 2, 624, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180754169858, 2, 625, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180754169859, 2, 626, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180758364162, 2, 627, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180758364163, 2, 628, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180758364164, 2, 629, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180758364165, 2, 630, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180762558466, 2, 631, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180762558467, 2, 632, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180762558468, 2, 633, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180766752770, 2, 635, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180766752771, 2, 636, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180766752772, 2, 638, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180770947074, 2, 639, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180770947075, 2, 640, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180770947076, 2, 641, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180770947077, 2, 642, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180775141377, 2, 643, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180775141378, 2, 647, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180775141379, 2, 648, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180779335682, 2, 649, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180779335683, 2, 650, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180779335684, 2, 651, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180779335685, 2, 652, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180783529986, 2, 653, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180783529987, 2, 654, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180783529988, 2, 655, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180783529989, 2, 656, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180787724290, 2, 657, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180787724291, 2, 658, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180787724292, 2, 659, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180791918594, 2, 660, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180791918595, 2, 661, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180791918596, 2, 664, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180796112897, 2, 665, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180796112898, 2, 672, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180796112899, 2, 680, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180796112900, 2, 681, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180800307202, 2, 682, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180800307203, 2, 683, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180800307204, 2, 684, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180804501505, 2, 685, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180804501506, 2, 686, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180804501507, 2, 687, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180804501508, 2, 688, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180808695809, 2, 689, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180808695810, 2, 690, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180808695811, 2, 691, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180812890114, 2, 692, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180812890115, 2, 693, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180812890116, 2, 694, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180812890117, 2, 695, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180817084418, 2, 696, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180817084419, 2, 704, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180817084420, 2, 705, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180817084421, 2, 708, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180821278722, 2, 709, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180821278723, 2, 710, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180821278724, 2, 711, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180825473025, 2, 712, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180825473026, 2, 717, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180825473027, 2, 718, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180825473028, 2, 719, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180829667329, 2, 720, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180829667330, 2, 726, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180829667331, 2, 727, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180833861634, 2, 728, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180833861635, 2, 729, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180833861636, 2, 735, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180833861637, 2, 736, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180838055937, 2, 737, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180838055938, 2, 738, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180838055939, 2, 739, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180838055940, 2, 741, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180842250241, 2, 742, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180842250242, 2, 743, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180842250243, 2, 744, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180846444546, 2, 747, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180846444547, 2, 748, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180846444548, 2, 749, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180846444549, 2, 750, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180850638850, 2, 751, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180850638851, 2, 752, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180850638852, 2, 755, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180854833153, 2, 757, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180854833154, 2, 758, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180854833155, 2, 759, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180854833156, 2, 760, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180859027457, 2, 763, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180859027458, 2, 782, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180859027459, 2, 783, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180863221762, 2, 784, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180863221763, 2, 785, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180863221764, 2, 788, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180863221765, 2, 789, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180867416066, 2, 803, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180867416067, 2, 804, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180867416068, 2, 805, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180871610370, 2, 806, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180871610371, 2, 807, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180871610372, 2, 808, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180871610373, 2, 809, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180875804674, 2, 810, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180879998978, 2, 811, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180879998979, 2, 812, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180884193282, 2, 813, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180884193283, 2, 816, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180884193284, 2, 817, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180884193285, 2, 825, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180888387586, 2, 826, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180888387587, 2, 828, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180892581889, 2, 829, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180892581890, 2, 830, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180892581891, 2, 831, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180892581892, 2, 832, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180896776193, 2, 833, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180896776194, 2, 834, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180896776195, 2, 835, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180896776196, 2, 836, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180900970497, 2, 837, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180900970498, 2, 838, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180900970499, 2, 839, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180905164802, 2, 840, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180905164803, 2, 841, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180905164804, 2, 842, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180909359106, 2, 843, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180909359107, 2, 844, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180909359108, 2, 845, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180913553410, 2, 846, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180913553411, 2, 847, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180913553412, 2, 848, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180913553413, 2, 849, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180917747714, 2, 850, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180917747715, 2, 851, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180917747716, 2, 852, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180921942018, 2, 853, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180921942019, 2, 856, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180921942020, 2, 866, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180921942021, 2, 867, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180926136322, 2, 868, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180926136323, 2, 872, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180926136324, 2, 873, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180930330625, 2, 876, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180930330626, 2, 877, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180930330627, 2, 878, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180930330628, 2, 879, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180934524930, 2, 880, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180934524931, 2, 881, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180934524932, 2, 884, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180934524933, 2, 885, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180938719233, 2, 886, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180938719234, 2, 887, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180942913538, 2, 888, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180942913539, 2, 889, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180942913540, 2, 890, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180942913541, 2, 891, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180947107841, 2, 892, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180947107842, 2, 893, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180947107843, 2, 894, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180947107844, 2, 895, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180951302146, 2, 896, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180951302147, 2, 897, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180951302148, 2, 898, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180955496449, 2, 899, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180955496450, 2, 900, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180955496451, 2, 901, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180955496452, 2, 902, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180959690754, 2, 903, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180959690755, 2, 904, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180959690756, 2, 905, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180963885057, 2, 906, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180963885058, 2, 907, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180963885059, 2, 908, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180963885060, 2, 909, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180968079361, 2, 910, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180968079362, 2, 911, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180968079363, 2, 912, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180972273665, 2, 913, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180972273666, 2, 914, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180972273667, 2, 915, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180972273668, 2, 916, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180976467970, 2, 917, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180976467971, 2, 918, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180976467972, 2, 919, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180980662273, 2, 920, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180980662274, 2, 921, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180980662275, 2, 922, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180980662276, 2, 923, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180984856578, 2, 924, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180984856579, 2, 925, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180984856580, 2, 926, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180984856581, 2, 927, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180989050881, 2, 928, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180989050882, 2, 929, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180989050883, 2, 930, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180993245185, 2, 931, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180993245186, 2, 932, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180993245187, 2, 933, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180993245188, 2, 934, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180997439489, 2, 935, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180997439490, 2, 936, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027180997439491, 2, 937, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181001633794, 2, 938, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181001633795, 2, 939, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181001633796, 2, 940, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181001633797, 2, 941, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181005828098, 2, 942, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181005828099, 2, 943, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181005828100, 2, 944, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181005828101, 2, 945, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181010022402, 2, 946, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181010022403, 2, 947, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181010022404, 2, 948, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181014216705, 2, 949, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181014216706, 2, 950, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181014216707, 2, 951, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181014216708, 2, 3000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181018411010, 2, 952, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181018411011, 2, 3001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181018411012, 2, 953, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181022605314, 2, 3002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181022605315, 2, 954, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181022605316, 2, 3003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181022605317, 2, 955, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181026799618, 2, 3004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181026799619, 2, 956, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181026799620, 2, 3005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181030993921, 2, 957, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181030993922, 2, 3006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181030993923, 2, 958, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181030993924, 2, 3007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181035188225, 2, 959, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181035188226, 2, 960, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181035188227, 2, 961, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181035188228, 2, 3010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181039382529, 2, 962, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181039382530, 2, 3011, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181039382531, 2, 963, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181043576833, 2, 3012, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181043576834, 2, 964, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181043576835, 2, 3013, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181043576836, 2, 965, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181047771138, 2, 3014, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181047771139, 2, 966, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181047771140, 2, 3015, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181051965441, 2, 967, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181051965442, 2, 3016, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181051965443, 2, 968, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181051965444, 2, 3017, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181056159745, 2, 969, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181056159746, 2, 970, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181056159747, 2, 3018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181056159748, 2, 3019, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181060354050, 2, 971, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181060354051, 2, 3020, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181060354052, 2, 972, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181064548353, 2, 973, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181064548354, 2, 3021, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181064548355, 2, 974, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181064548356, 2, 3022, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181068742657, 2, 975, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181068742658, 2, 3023, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181068742659, 2, 3024, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181072936961, 2, 976, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181072936962, 2, 3025, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181072936963, 2, 977, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181072936964, 2, 978, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181077131266, 2, 979, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181077131267, 2, 980, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181077131268, 2, 981, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181077131269, 2, 982, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181081325570, 2, 3030, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181081325571, 2, 983, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181081325572, 2, 3031, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181085519873, 2, 984, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181085519874, 2, 985, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181085519875, 2, 986, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181085519876, 2, 987, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181089714178, 2, 988, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181089714179, 2, 989, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181089714180, 2, 990, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181093908481, 2, 991, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181093908482, 2, 3040, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181093908483, 2, 992, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181093908484, 2, 3041, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181098102786, 2, 993, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181098102787, 2, 3042, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181098102788, 2, 994, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181098102789, 2, 3043, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181102297089, 2, 995, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181102297090, 2, 3044, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181102297091, 2, 996, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181106491394, 2, 997, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181106491395, 2, 998, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181106491396, 2, 999, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181106491397, 2, 1000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181110685697, 2, 1001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181110685698, 2, 3050, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181110685699, 2, 1002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181114880002, 2, 3051, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181114880003, 2, 1003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181114880004, 2, 3052, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181114880005, 2, 1004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181119074306, 2, 3053, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181119074307, 2, 1005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181119074308, 2, 1006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181119074309, 2, 3054, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181123268610, 2, 1007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181123268611, 2, 1008, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181123268612, 2, 1009, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181127462913, 2, 1010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181127462914, 2, 1100, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181127462915, 2, 1101, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181127462916, 2, 1102, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181131657217, 2, 1103, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181131657218, 2, 1104, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181131657219, 2, 1105, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181131657220, 2, 1106, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181135851521, 2, 1107, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181135851522, 2, 1108, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181135851523, 2, 1109, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181140045826, 2, 1110, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181140045827, 2, 1111, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181140045828, 2, 1112, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181140045829, 2, 1113, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181144240130, 2, 1114, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181144240131, 2, 1115, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181144240132, 2, 1117, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181144240133, 2, 1118, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181148434434, 2, 1119, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181148434435, 2, 1120, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181148434436, 2, 1121, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181152628737, 2, 1122, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181152628738, 2, 1123, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181152628739, 2, 1124, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181152628740, 2, 1125, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181156823042, 2, 1126, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181156823043, 2, 1128, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181156823044, 2, 1129, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181161017346, 2, 1132, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181161017347, 2, 1133, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181161017348, 2, 1134, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181161017349, 2, 1135, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181165211649, 2, 1136, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181165211650, 2, 1137, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181165211651, 2, 1138, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181169405953, 2, 1139, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181169405954, 2, 1999, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181169405955, 2, 2000, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181169405956, 2, 2001, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181173600258, 2, 2002, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181173600259, 2, 2003, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181173600260, 2, 2004, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181173600261, 2, 2005, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181177794561, 2, 2006, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181177794562, 2, 2007, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181177794563, 2, 2008, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181181988866, 2, 2009, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181181988867, 2, 2010, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181181988868, 2, 2011, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181181988869, 2, 2012, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181186183170, 2, 2013, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181186183171, 2, 2014, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181186183172, 2, 2015, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181190377473, 2, 2016, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181190377474, 2, 2017, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181190377475, 2, 2018, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181190377476, 2, 2019, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181194571777, 2, 2020, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181194571778, 2, 2021, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181194571779, 2, 2022, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181194571780, 2, 2023, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181198766082, 2, 2024, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181198766083, 2, 2025, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181198766084, 2, 2026, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181202960386, 2, 2027, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181202960387, 2, 2028, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181202960388, 2, 2029, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181202960389, 2, 2030, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181207154689, 2, 2031, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181207154690, 2, 2032, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181207154691, 2, 2033, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181207154692, 2, 2034, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181211348994, 2, 2035, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181211348995, 2, 2036, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181211348996, 2, 2037, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181215543298, 2, 2038, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181215543299, 2, 2039, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181215543300, 2, 2040, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181215543301, 2, 2041, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181219737602, 2, 2042, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181219737603, 2, 2043, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181219737604, 2, 2044, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181219737605, 2, 2045, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181223931906, 2, 2046, 1, NULL);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`, `school_id`) VALUES (1804027181223931907, 2, 2047, 1, NULL);

-- ----------------------------
-- Table structure for sys_user
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_user` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `login_name` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '用户名',
  `real_name` varchar(100) NOT NULL COMMENT '姓名',
  `code` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin DEFAULT NULL COMMENT '工号',
  `password` varchar(50) NOT NULL COMMENT '密码',
  `mobile_number` varchar(30) DEFAULT NULL COMMENT '手机号',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `pwd_count` tinyint DEFAULT '0' COMMENT '密码修改次数，默认为0',
  `pwd_update_time` bigint DEFAULT NULL COMMENT '密码修改时间',
  `remark` varchar(200) DEFAULT NULL COMMENT '备注',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '修改人',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `historic_name` varchar(100) DEFAULT NULL COMMENT '历史用户名称',
  `ui_setting` text COMMENT '阅卷参数',
  `allow_manual_card` tinyint(1) DEFAULT '0' COMMENT '是否允许新增卡格式',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `user_schoolId_loginName_idx` (`school_id`,`login_name`) USING BTREE,
  UNIQUE KEY `uq_school_id_mobile_number` (`school_id`,`mobile_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户表';

-- ----------------------------
-- Records of sys_user
-- ----------------------------
INSERT INTO `sys_user` (`id`, `school_id`, `login_name`, `real_name`, `code`, `password`, `mobile_number`, `org_id`, `enable`, `pwd_count`, `pwd_update_time`, `remark`, `create_id`, `create_time`, `update_id`, `update_time`, `historic_name`, `ui_setting`, `allow_manual_card`) VALUES (1, NULL, 'sysadmin', 'sysadmin', NULL, 'UW10aDg3ODYzNTc3', NULL, NULL, 1, 2, 1700550554413, NULL, NULL, NULL, NULL, 1700550554425, NULL, NULL, 0);

-- ----------------------------
-- Table structure for sys_user_role
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_user_role` (
  `id` bigint NOT NULL COMMENT '主键',
  `user_id` bigint NOT NULL COMMENT '用户id',
  `role_id` bigint NOT NULL COMMENT '角色id',
  `privilege_id` bigint DEFAULT NULL COMMENT '权限id',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户和角色关联表';

-- ----------------------------
-- Records of sys_user_role
-- ----------------------------
INSERT INTO `sys_user_role` (`id`, `user_id`, `role_id`, `privilege_id`, `enable`) VALUES (1, 1, 1, NULL, 1);

-- ----------------------------
-- Table structure for t_b_session
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_b_session` (
  `id` varchar(100) NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `identity` varchar(100) NOT NULL COMMENT '用户标识',
  `type` varchar(50) NOT NULL COMMENT '用户类型',
  `source` varchar(50) NOT NULL COMMENT '访问来源',
  `platform` varchar(50) NOT NULL COMMENT '设备分类',
  `device_id` varchar(100) NOT NULL COMMENT '设备标识',
  `address` varchar(100) NOT NULL COMMENT '登录IP地址',
  `access_token` varchar(50) NOT NULL COMMENT '访问令牌',
  `last_access_time` bigint DEFAULT NULL COMMENT '最近访问时间',
  `last_access_ip` varchar(100) DEFAULT NULL COMMENT '最近访问IP地址',
  `update_time` bigint DEFAULT NULL COMMENT '令牌更新时间',
  `expire_time` bigint DEFAULT NULL COMMENT '令牌强制失效时间',
  `app_source` varchar(50) DEFAULT NULL COMMENT '应用来源',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='会话表';

-- ----------------------------
-- Table structure for t_b_sync_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_b_sync_task` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `semester_id` bigint DEFAULT NULL COMMENT '学期',
  `exam_id` bigint DEFAULT NULL COMMENT '考试',
  `course_code` varchar(50) DEFAULT NULL COMMENT '课程代码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(45) DEFAULT NULL COMMENT '试卷编号',
  `paper_type` varchar(10) DEFAULT NULL COMMENT '试卷类型',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `type` varchar(50) NOT NULL COMMENT '推送类型，USER_PUSH：用户推送',
  `exam_time` varchar(20) DEFAULT NULL COMMENT '考试时间',
  `object_id` bigint DEFAULT NULL COMMENT '印刷计划id',
  `status` varchar(30) NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
  `summary` text COMMENT '实时摘要信息',
  `result` varchar(30) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '修改人',
  `update_time` bigint DEFAULT NULL COMMENT '修改时间',
  `remark` mediumtext COMMENT '备注',
  `reset_count` int DEFAULT '0' COMMENT '重试次数',
  `error_message` varchar(500) DEFAULT NULL COMMENT '人工错误原因',
  `report_file_path` varchar(500) DEFAULT NULL COMMENT '报告路径',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='云阅卷同步任务表';

-- ----------------------------
-- Table structure for t_b_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_b_task` (
  `id` bigint NOT NULL COMMENT '主键',
  `semester_id` bigint DEFAULT NULL COMMENT '学期',
  `exam_id` bigint DEFAULT NULL COMMENT '考试',
  `course_code` varchar(50) DEFAULT NULL COMMENT '课程代码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(45) DEFAULT NULL COMMENT '试卷编号',
  `type` varchar(50) NOT NULL COMMENT '任务类型，USER_IMPORT：用户导入，\nQUESTION_MISSION_BATCH_CREATE：批量新建命题任务，\nSAMPLE_EXPORT：导出审核样本，\nPAPER_DOWNLOAD：卷库下载，\nEXAMINATION_IMPORT：考务数据导入，\nEXAMINATION_EXPORT：考务数据导出，\nPRINT_PDF_DOWNLOAD：批量下载pdf，\nCREATE_PDF：生成pdf，\nCOURSE_IMPORT：课程导入',
  `entity_id` bigint DEFAULT NULL COMMENT '关联业务对象id',
  `status` varchar(30) NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
  `summary` text COMMENT '实时摘要信息',
  `progress` double DEFAULT NULL COMMENT '执行进度',
  `result` varchar(30) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
  `import_file_name` varchar(100) DEFAULT NULL COMMENT '导入文件名',
  `import_file_path` varchar(500) DEFAULT NULL COMMENT '导入文件路径',
  `result_file_path` varchar(500) DEFAULT NULL COMMENT '导出文件路径',
  `error_file_path` varchar(500) DEFAULT NULL COMMENT '错误数据文件路径',
  `report_file_path` varchar(500) DEFAULT NULL COMMENT '报告路径',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
  `remark` mediumtext COMMENT '备注',
  `obj_name` varchar(500) DEFAULT NULL COMMENT '实体名称',
  `reset_count` int DEFAULT '0' COMMENT '重试次数',
  `version` int DEFAULT '0' COMMENT '更新版本号',
  `error_message` varchar(500) DEFAULT NULL COMMENT '人工错误原因',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='导入导出任务表';

-- ----------------------------
-- Table structure for t_b_task_pdf
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_b_task_pdf` (
  `id` bigint NOT NULL COMMENT '主键（与exam_detail表id一致）',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
  `exam_id` bigint DEFAULT NULL COMMENT '考试ID',
  `print_plan_id` bigint NOT NULL COMMENT '印刷计划id',
  `course_name_code` mediumtext COMMENT '课程名称',
  `paper_number` mediumtext COMMENT '试卷编号',
  `create_type` varchar(45) DEFAULT NULL COMMENT '生成pdf类型：ALL("全部"),PAPER("试卷"),CARD_A3("题卡"),SIGN("签到表"),PACKAGE("卷袋贴"),CHECK_IN("登记表")',
  `status` varchar(30) NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
  `summary` mediumtext COMMENT '实时摘要信息',
  `result` varchar(30) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `remark` mediumtext COMMENT '备注',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='pdf生成日志表';

-- ----------------------------
-- Table structure for t_c_final_score
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_c_final_score` (
  `id` bigint NOT NULL COMMENT '主键',
  `culture_program_id` bigint DEFAULT NULL COMMENT '培养方案id',
  `exam_id` bigint DEFAULT NULL COMMENT '考试id',
  `course_id` bigint DEFAULT NULL COMMENT '课程id',
  `course_code` varchar(100) DEFAULT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编码',
  `name` varchar(100) NOT NULL COMMENT '考生姓名',
  `student_code` varchar(100) NOT NULL COMMENT '学号',
  `score` double NOT NULL COMMENT '分数',
  `score_detail` mediumtext NOT NULL COMMENT '成绩明细',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `source` varchar(50) DEFAULT NULL COMMENT '来源，EXCEL_IMPORT：excel导入，SYNC：数据同步',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `t_c_final_score_unique` (`culture_program_id`,`course_id`,`name`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='期末考试成绩表';

-- ----------------------------
-- Table structure for t_c_paper_struct
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_c_paper_struct` (
  `id` bigint NOT NULL COMMENT '主键',
  `culture_program_id` bigint DEFAULT NULL COMMENT '培养方案id',
  `exam_id` bigint DEFAULT NULL COMMENT '考试id',
  `course_id` bigint DEFAULT NULL COMMENT '课程id',
  `course_code` varchar(100) NOT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编码',
  `paper_struct` mediumtext COMMENT '试卷结构',
  `paper_struct_dimension` mediumtext COMMENT '试卷知识点结构',
  `total_score` double DEFAULT NULL COMMENT '全卷满分',
  `pass_score` double DEFAULT NULL COMMENT '及格分',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `dimension_sign` bigint DEFAULT NULL COMMENT '知识点变化id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `t_c_paper_struct_unique` (`culture_program_id`,`course_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='试卷蓝图表';

-- ----------------------------
-- Table structure for t_c_statistics
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_c_statistics` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `exam_task_detail_ids` mediumtext COMMENT '命题任务明细id',
  `exam_detail_course_ids` mediumtext COMMENT '考务数据课程id',
  `college_id` bigint NOT NULL COMMENT '学院id',
  `college_name` varchar(100) NOT NULL COMMENT '学院名称',
  `course_name` varchar(100) NOT NULL COMMENT '课程名称',
  `course_code` varchar(100) NOT NULL COMMENT '课程代码',
  `teaching_room_id` bigint NOT NULL COMMENT '教研室id',
  `teaching_room_name` varchar(100) NOT NULL COMMENT '教研室名称',
  `teacher_name` mediumtext NOT NULL COMMENT '任课老师名称',
  `clazz_ids` varchar(100) NOT NULL COMMENT '班级ids',
  `clazz_name` varchar(100) NOT NULL COMMENT '班级名称',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编号',
  `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
  `batch_no` varchar(100) NOT NULL COMMENT '批次号',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `print_sum` varchar(100) DEFAULT NULL COMMENT '总印份数',
  `status` varchar(50) DEFAULT NULL COMMENT '完成状态，FINISH：已完成，UN_FINISH：未完成',
  `exam_detail_id` bigint DEFAULT NULL COMMENT '命题明细id',
  `clazz_content` mediumtext COMMENT '班级详细信息内容',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题统计表';

-- ----------------------------
-- Table structure for t_c_statistics_temp
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_c_statistics_temp` (
  `id` bigint NOT NULL COMMENT '主键',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `exam_task_detail_id` bigint DEFAULT NULL COMMENT '命题任务明细id',
  `exam_detail_course_id` bigint DEFAULT NULL COMMENT '考务数据课程id',
  `college_id` bigint NOT NULL COMMENT '学院id',
  `college_name` varchar(100) NOT NULL COMMENT '学院名称',
  `course_name` varchar(100) NOT NULL COMMENT '课程名称',
  `course_code` varchar(100) NOT NULL COMMENT '课程代码',
  `teaching_room_id` bigint NOT NULL COMMENT '教研室id',
  `teaching_room_name` varchar(100) NOT NULL COMMENT '教研室名称',
  `teacher_name` mediumtext NOT NULL COMMENT '任课老师名称',
  `clazz_ids` varchar(100) NOT NULL COMMENT '班级ids',
  `clazz_name` varchar(100) NOT NULL COMMENT '班级名称',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编号',
  `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
  `batch_no` varchar(100) NOT NULL COMMENT '批次号',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `data_source` varchar(50) DEFAULT NULL COMMENT '数据来源，IMPORT：导入，JOIN：关联查询的数据',
  `exam_detail_id` bigint DEFAULT NULL COMMENT '命题明细id',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题统计表';

-- ----------------------------
-- Table structure for t_c_usual_score
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_c_usual_score` (
  `id` bigint NOT NULL COMMENT '主键',
  `culture_program_id` bigint DEFAULT NULL COMMENT '培养方案id',
  `exam_id` bigint DEFAULT NULL COMMENT '考试id',
  `course_id` bigint DEFAULT NULL COMMENT '课程id',
  `course_code` varchar(100) DEFAULT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编码',
  `name` varchar(100) NOT NULL COMMENT '考生姓名',
  `student_code` varchar(100) NOT NULL COMMENT '学号',
  `score` mediumtext NOT NULL COMMENT '平常作业分数',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `t_c_usual_score_unique` (`culture_program_id`,`course_id`,`name`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='平常作业成绩表';

-- ----------------------------
-- Table structure for t_f_custom_flow
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_f_custom_flow` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `name` varchar(100) NOT NULL COMMENT '流程名称',
  `model_type` varchar(50) NOT NULL COMMENT '模式类型，USER_FIXED：指定人员,APPROVE_SET：发起人指定',
  `type` varchar(100) NOT NULL COMMENT '流程类型，ELECTRON_FLOW：电子交卷审核，QUESTION_ELECTRON_FLOW：题库试题提交审核，PAPER_ELECTRON_FLOW：题库试卷审核',
  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `publish` tinyint NOT NULL DEFAULT '1' COMMENT '是否发布，0：否，1：是',
  `object_data` mediumtext NOT NULL COMMENT '自定义流程源数据',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `version` bigint NOT NULL DEFAULT '1' COMMENT '版本号',
  `flow_key` varchar(100) DEFAULT NULL COMMENT '流程key',
  `act_flow_id` varchar(100) DEFAULT NULL COMMENT '流程版本id',
  `flow_process_var` mediumtext COMMENT '流程过程变量数据',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `custom_flow_schoolId_type_idx` (`school_id`,`type`,`enable`,`publish`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='自定义流程表';

-- ----------------------------
-- Table structure for t_f_custom_flow_entity
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_f_custom_flow_entity` (
  `id` bigint NOT NULL COMMENT '主键',
  `t_f_custom_flow_id` bigint NOT NULL COMMENT '自定义流程id',
  `flow_id` bigint DEFAULT NULL COMMENT '流程id',
  `flow_process_var` mediumtext NOT NULL COMMENT '流程过程变量',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `flow_entity_flowId_idx` (`flow_id`) USING BTREE,
  KEY `flow_entity_custom_flowId_idx` (`t_f_custom_flow_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='自定义流程实体数据';

-- ----------------------------
-- Table structure for t_f_flow_approve
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_f_flow_approve` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `flow_id` bigint NOT NULL COMMENT '流程id',
  `approve_id` bigint DEFAULT NULL COMMENT '审核id',
  `status` varchar(50) NOT NULL COMMENT '状态，START：已开始，AUDITING：审核中，REJECT：已驳回，END：已终止，FINISH：已结束',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `setup` tinyint NOT NULL COMMENT '计划步骤',
  `approve_setup` int DEFAULT NULL COMMENT '审批步骤',
  `approve_max_setup` int DEFAULT NULL COMMENT '最大审批步骤',
  `transfer_assignee` mediumtext COMMENT '流程转办',
  `all_assignee` mediumtext COMMENT '会签审批人',
  `reject_link` mediumtext COMMENT '驳回路线',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `flow_approve_idx` (`school_id`,`flow_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='流程审核表';

-- ----------------------------
-- Table structure for t_f_flow_join
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_f_flow_join` (
  `id` bigint NOT NULL COMMENT '主键',
  `flow_entity_id` bigint NOT NULL COMMENT '自定义流程实体id',
  `object_table` varchar(100) NOT NULL COMMENT '实体表',
  `object_id` bigint NOT NULL COMMENT '实体id',
  `flow_id` bigint NOT NULL COMMENT '流程id',
  `level` int NOT NULL COMMENT '流程等级',
  `type` varchar(50) NOT NULL COMMENT '类型，NEW：新增，RESTART：重新提交',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `task_flowId_idx` (`flow_id`) USING BTREE,
  KEY `task_objectId_idx` (`object_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='实体和流程关联表';

-- ----------------------------
-- Table structure for t_f_flow_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_f_flow_log` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `flow_id` bigint NOT NULL COMMENT '流程id',
  `object_table` varchar(100) DEFAULT NULL COMMENT '实体表',
  `object_id` bigint NOT NULL COMMENT '实体id',
  `approve_id` bigint DEFAULT NULL COMMENT '审核人id',
  `approve_setup` tinyint DEFAULT NULL COMMENT '审核步骤',
  `approve_remark` mediumtext COMMENT '审核意见',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `approve_operation` varchar(50) NOT NULL COMMENT '审批操作，SUBMIT：提交，APPROVE：审批，REJECT：驳回，END：终止',
  `pend_approve_id` mediumtext COMMENT '待审核人id',
  `paper_attachment_id` mediumtext COMMENT '试卷附件',
  `approve_multi_setup` int DEFAULT NULL COMMENT '审批步骤',
  `approve_user_approve_type` varchar(30) DEFAULT NULL COMMENT '审批用户类别，ORDER：依次审批，ALL：会签（所有人必须审批），SOME：或签（一名审批人同意或拒绝即可）',
  `task_id` bigint DEFAULT NULL COMMENT '流程节点id',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `flow_log_idx` (`school_id`,`flow_id`) USING BTREE,
  KEY `flow_log_objectId_idx` (`object_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='流程流水表';

-- ----------------------------
-- Table structure for t_g_error
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_g_error` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `obj_id` bigint DEFAULT NULL COMMENT '实体id',
  `summary` mediumtext COMMENT '实时摘要信息',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='全局异常错误信息表';

-- ----------------------------
-- Table structure for t_m_mq_message
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_m_mq_message` (
  `id` varchar(50) NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `topic` varchar(100) NOT NULL COMMENT '消息topic',
  `tag` varchar(100) NOT NULL COMMENT '消息tag',
  `body` mediumtext COMMENT '消息内容',
  `type` varchar(50) NOT NULL COMMENT '消息类型',
  `obj_id` varchar(50) NOT NULL COMMENT '关联业务id',
  `obj_name` varchar(100) DEFAULT NULL COMMENT '关联业务名称',
  `ack` tinyint NOT NULL COMMENT '消息ack',
  `sequence` int DEFAULT NULL COMMENT '消息序号',
  `properties` varchar(1000) DEFAULT NULL COMMENT '扩展类型',
  `create_time` bigint NOT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `timestamp` bigint NOT NULL COMMENT '时间戳',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='mq消息';

-- ----------------------------
-- Table structure for t_r_basic_info
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_r_basic_info` (
  `id` bigint NOT NULL COMMENT '主键',
  `culture_program_id` bigint DEFAULT NULL COMMENT '培养方案id',
  `exam_id` bigint DEFAULT NULL COMMENT '考试id',
  `course_id` bigint DEFAULT NULL COMMENT '课程id',
  `course_code` varchar(100) NOT NULL COMMENT '课程编码',
  `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
  `course_en_name` varchar(100) DEFAULT NULL COMMENT '课程英文名称',
  `paper_number` varchar(100) DEFAULT NULL COMMENT '试卷编码',
  `course_type` varchar(100) DEFAULT NULL COMMENT '课程性质',
  `credit` varchar(50) DEFAULT NULL COMMENT '学分',
  `period` varchar(50) DEFAULT NULL COMMENT '学时',
  `college` varchar(200) DEFAULT NULL COMMENT '开课学院',
  `profession` varchar(200) DEFAULT NULL COMMENT '开课专业',
  `evaluation_mode` varchar(100) DEFAULT NULL COMMENT '考核方式',
  `open_time` varchar(100) DEFAULT NULL COMMENT '开课时间',
  `teaching_object` varchar(1000) DEFAULT NULL COMMENT '授课对象',
  `selection_count` int DEFAULT NULL COMMENT '选课人数',
  `participant_count` int DEFAULT NULL COMMENT '参评人数',
  `course_degree` double DEFAULT NULL COMMENT '课程目标达成度期望值',
  `teacher` varchar(100) DEFAULT NULL COMMENT '任课老师',
  `director` varchar(100) DEFAULT NULL COMMENT '评价责任人',
  `participant` varchar(100) DEFAULT NULL COMMENT '评价参与人',
  `finish_points` mediumtext COMMENT '达成情况',
  `requirement_points` mediumtext COMMENT '课程支撑毕业要求达成情况评价',
  `course_suggest` mediumtext COMMENT '课程持续改进',
  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `course_evaluation_spread` mediumtext COMMENT '课程目标考核分布',
  `course_evaluation_result` mediumtext COMMENT '课程考核成绩评价结果',
  `course_evaluation_result_detail` mediumtext COMMENT '课程考核成绩评价明细结果',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `t_r_basic_info_unique` (`culture_program_id`,`course_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='报告基本情况表';

-- ----------------------------
-- Table structure for t_r_exam_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_r_exam_student` (
  `id` bigint NOT NULL COMMENT '主键',
  `r_basic_info_id` bigint NOT NULL COMMENT '报告id',
  `name` varchar(100) DEFAULT NULL COMMENT '考生姓名',
  `student_code` varchar(100) DEFAULT NULL COMMENT '学号',
  `administrative_class` varchar(100) DEFAULT NULL COMMENT '行政班级',
  `score` double DEFAULT NULL COMMENT '学生成绩',
  `result_detail` mediumtext COMMENT '考生课程考核成绩评价明细结果',
  PRIMARY KEY (`id`) USING BTREE,
    KEY `idx_1` (`r_basic_info_id`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='报告考生表';

-- ----------------------------
-- Table structure for t_s_auth
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_s_auth` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `access_key` varchar(255) DEFAULT NULL COMMENT 'accessKey',
  `access_secret` varchar(255) DEFAULT NULL COMMENT 'accessSecret',
  `description` text COMMENT '离线授权证书',
  `type` varchar(16) NOT NULL COMMENT '授权类型',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  `expire_time` bigint DEFAULT NULL COMMENT '过期时间',
  `file` mediumblob COMMENT '文件数据',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='激活授权配置表';

-- ----------------------------
-- Table structure for t_school_privilege
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_school_privilege` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `privilege_id` bigint NOT NULL COMMENT '菜单权限id',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校菜单权限表';

-- ----------------------------
-- Table structure for t_school_role
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_school_role` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `role_id` bigint NOT NULL COMMENT '菜单权限id',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校角色权限表';

-- ----------------------------
-- Table structure for t_sync_exam_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_sync_exam_log` (
  `id` bigint NOT NULL,
  `school_id` bigint DEFAULT NULL COMMENT '学校ID',
  `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
  `exam_id` bigint DEFAULT NULL COMMENT '云阅卷考试ID',
  `third_relate_id` int DEFAULT NULL COMMENT '云阅卷考试ID',
  `exam_name` varchar(100) DEFAULT NULL COMMENT '云阅卷考试名称',
  `status` varchar(20) DEFAULT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
  `result` varchar(20) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
  `start_time` bigint DEFAULT NULL COMMENT '同步开始时间',
  `end_time` bigint DEFAULT NULL COMMENT '结束同步时间',
  `summary` mediumtext,
  `total_courses` int DEFAULT NULL COMMENT '总课程数',
  `total_exam_tasks` int DEFAULT NULL COMMENT '总命题任务数',
  `total_students` int DEFAULT NULL COMMENT '总考生数',
  `success_students` int DEFAULT NULL COMMENT '成功人数',
  `fail_students` int DEFAULT NULL COMMENT '失败人数',
  `error_file_path` varchar(500) DEFAULT NULL COMMENT '错误日志文件地址',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='同步考试日志表';

-- ----------------------------
-- Table structure for t_sync_exam_student_score
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_sync_exam_student_score` (
  `id` bigint NOT NULL COMMENT '主键',
  `school_id` bigint DEFAULT NULL COMMENT '学校id',
  `org_id` bigint DEFAULT NULL COMMENT '机构id',
  `semester_id` bigint DEFAULT NULL COMMENT '学期id',
  `major_name` varchar(100) DEFAULT NULL COMMENT '专业id',
  `clazz_id` bigint DEFAULT NULL COMMENT '班级id',
  `exam_id` bigint DEFAULT NULL COMMENT '云阅卷考试id',
  `third_relate_id` int DEFAULT NULL COMMENT '云阅卷考试ID',
  `exam_code` varchar(100) DEFAULT NULL COMMENT '云阅卷考试标识',
  `exam_number` varchar(100) DEFAULT NULL COMMENT '准考证号',
  `student_code` varchar(100) DEFAULT NULL COMMENT '学号',
  `name` varchar(100) NOT NULL COMMENT '姓名',
  `paper_number` varchar(45) DEFAULT NULL COMMENT '试卷编号',
  `subject_code` varchar(100) DEFAULT NULL COMMENT '科目代码',
  `subject_name` varchar(100) DEFAULT NULL COMMENT '科目名称',
  `paper_type` varchar(50) DEFAULT NULL COMMENT '试卷类型',
  `college` varchar(100) DEFAULT NULL COMMENT '学院',
  `clazz_name` varchar(100) DEFAULT NULL COMMENT '班级',
  `teacher` varchar(100) DEFAULT NULL COMMENT '教师',
  `status` tinyint DEFAULT NULL COMMENT '考生状态，1-正常，2-缺考(包含未上传)，3-违纪',
  `sheet_urls` mediumtext COMMENT '原卷url',
  `local_sheet_urls` mediumtext COMMENT '从云阅卷下载下来的原图url',
  `total_score` double DEFAULT NULL COMMENT '总分',
  `objective_score` double DEFAULT NULL COMMENT '客观题分数',
  `subjective_score` double DEFAULT NULL COMMENT '主观题分数',
  `sync_data` mediumtext COMMENT '同步数据json',
  `trajectory_urls` varchar(500) DEFAULT NULL COMMENT '轨迹图地址',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `score_schoolId_idx` (`school_id`,`semester_id`,`org_id`,`major_name`,`clazz_id`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='同步考生成绩表';

-- ----------------------------
-- Table structure for t_sync_stmms_exam
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_sync_stmms_exam` (
  `id` bigint NOT NULL,
  `school_id` bigint DEFAULT NULL COMMENT '学校ID',
  `org_code` varchar(45) DEFAULT NULL COMMENT '机构代码',
  `exam_id` int DEFAULT NULL COMMENT '云阅卷ID',
  `exam_name` varchar(45) DEFAULT NULL COMMENT '云阅卷考试名称',
  `create_id` bigint DEFAULT NULL,
  `create_time` bigint DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='云阅卷考试表';

-- ----------------------------
-- Table structure for teach_clazz
-- ----------------------------
CREATE TABLE IF NOT EXISTS `teach_clazz` (
  `id` bigint NOT NULL COMMENT '教学班表主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `teach_course_id` bigint NOT NULL,
  `basic_teach_clazz_id` bigint NOT NULL,
  `user_id` bigint DEFAULT NULL COMMENT '用户id',
  `clazz_name` varchar(50) NOT NULL COMMENT '教学课程名称',
  `belong_teach_course_id` bigint DEFAULT NULL COMMENT '分配班级时属于的教学课程id',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='教学班表';

-- ----------------------------
-- Table structure for teach_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `teach_course` (
  `id` bigint NOT NULL,
  `school_id` bigint NOT NULL COMMENT '学校id',
  `exam_id` bigint NOT NULL COMMENT '考试id',
  `course_code` varchar(20) NOT NULL COMMENT '课程编号',
  `user_id` bigint NOT NULL COMMENT '任课教师id',
  `enable` tinyint(1) DEFAULT NULL COMMENT '是否删除',
  `weight_setting` tinyint(1) DEFAULT NULL COMMENT '权重设置',
  `weight_setting_sign` bigint DEFAULT NULL COMMENT '课程权重设置标识',
  `dimension_sign` bigint DEFAULT NULL COMMENT '知识点标识',
  `default_rate` decimal(6,2) DEFAULT NULL COMMENT '默认占比',
  `custom_rate` decimal(6,2) DEFAULT NULL COMMENT '自定义占比',
  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `teach_course_unique` (`school_id`,`exam_id`,`course_code`,`user_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='教学课程表';

-- ----------------------------
-- Table structure for teach_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `teach_student` (
  `id` bigint NOT NULL COMMENT '教学学生关系表主键',
  `school_id` bigint NOT NULL COMMENT '学校id',
  `student_id` bigint NOT NULL COMMENT '学生id',
  `teach_clazz_id` bigint NOT NULL COMMENT '教学班级id',
  `teach_course_id` bigint NOT NULL COMMENT '教学课程id（冗余）',
  `user_id` bigint NOT NULL COMMENT '用户id（冗余）',
  `create_id` bigint DEFAULT NULL COMMENT '创建人',
  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
  `update_id` bigint DEFAULT NULL COMMENT '更新人',
  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `teach_student_unique` (`school_id`,`student_id`,`teach_clazz_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='教学学生关系表';

-- ----------------------------
-- Function structure for getRootChildId
-- ----------------------------
DROP FUNCTION IF EXISTS `getRootChildId`;
delimiter ;;
CREATE FUNCTION `getRootChildId`(rootId bigint)
    RETURNS mediumtext CHARSET utf8mb4
  DETERMINISTIC
BEGIN
    DECLARE ptemp MEDIUMTEXT;
    DECLARE ctemp MEDIUMTEXT;
    SET ptemp = '#';
    SET ctemp = cast(rootId as CHAR);
    WHILE ctemp IS NOT NULL DO
      SET ptemp = concat(ptemp, ',', ctemp);
SELECT group_concat(id) INTO ctemp FROM sys_org WHERE FIND_IN_SET(parent_id, ctemp) > 0;
END WHILE;
RETURN ptemp;
END
;;
delimiter ;
